@@ -23,7 +23,6 @@ LOG = log.getLogger(__name__)
 
 
 def urlmap_factory(loader, global_conf, **local_conf):
-    LOG.warning(_LW('manila.api.openstack.urlmap:urlmap_factory '
-                    'is deprecated. '
-                    'Please use manila.api.urlmap:urlmap_factory instead.'))
+    LOG.warn(_LW('manila.api.openstack.urlmap:urlmap_factory is deprecated. '
+                 'Please use manila.api.urlmap:urlmap_factory instead.'))
     urlmap.urlmap_factory(loader, global_conf, **local_conf)
