@@ -14,8 +14,9 @@
 #    under the License.
 
 import re
-from urllib.request import parse_http_list
+import urllib2
 
+from oslo_log import log
 import paste.urlmap
 
 from manila.api.openstack import wsgi
@@ -27,6 +28,8 @@ _option_header_piece_re = re.compile(
     r'(?:=\s*([^;]+|%s))?\s*' %
     (_quoted_string_re, _quoted_string_re))
 
+LOG = log.getLogger(__name__)
+
 
 def unquote_header_value(value):
     """Unquotes a header value.
@@ -62,7 +65,7 @@ def parse_list_header(value):
     :return: :class:`list`
     """
     result = []
-    for item in parse_http_list(value):
+    for item in urllib2.parse_http_list(value):
         if item[:1] == item[-1:] == '"':
             item = unquote_header_value(item[1:-1])
         result.append(item)
