@@ -19,13 +19,13 @@ Module dedicated functions/classes dealing with rate limiting requests.
 
 import collections
 import copy
+import httplib
 import math
 import re
 import time
 
 from oslo_serialization import jsonutils
 from oslo_utils import importutils
-from six.moves import http_client
 import webob.dec
 import webob.exc
 
@@ -33,7 +33,7 @@ from manila.api.openstack import wsgi
 from manila.api.views import limits as limits_views
 from manila.i18n import _
 from manila import quota
-from manila.wsgi import common as base_wsgi
+from manila import wsgi as base_wsgi
 
 QUOTAS = quota.QUOTAS
 
@@ -45,22 +45,19 @@ PER_HOUR = 60 * 60
 PER_DAY = 60 * 60 * 24
 
 
-class LimitsController(wsgi.Controller):
+class LimitsController(object):
     """Controller for accessing limits in the OpenStack API."""
 
     def index(self, req):
         """Return all global and rate limit information."""
         context = req.environ['manila.context']
         quotas = QUOTAS.get_project_quotas(context, context.project_id,
-                                           usages=True)
-        abs_limits = {'in_use': {}, 'limit': {}}
-        for k, v in quotas.items():
-            abs_limits['limit'][k] = v['limit']
-            abs_limits['in_use'][k] = v['in_use']
+                                           usages=False)
+        abs_limits = dict((k, v['limit']) for k, v in quotas.items())
         rate_limits = req.environ.get("manila.limits", [])
 
         builder = self._get_view_builder(req)
-        return builder.build(req, rate_limits, abs_limits)
+        return builder.build(rate_limits, abs_limits)
 
     def _get_view_builder(self, req):
         return limits_views.ViewBuilder()
@@ -80,7 +77,7 @@ class Limit(object):
         60 * 60 * 24: "DAY",
     }
 
-    UNIT_MAP = {v: k for k, v in UNITS.items()}
+    UNIT_MAP = dict([(v, k) for k, v in UNITS.items()])
 
     def __init__(self, verb, uri, regex, value, unit):
         """Initialize a new `Limit`.
@@ -108,11 +105,9 @@ class Limit(object):
         self.water_level = 0
         self.capacity = self.unit
         self.request_value = float(self.capacity) / float(self.value)
-        msg = (_("Only %(value)s %(verb)s request(s) can be "
-               "made to %(uri)s every %(unit_string)s.") %
-               {'value': self.value, 'verb': self.verb,
-                'uri': self.uri, 'unit_string': self.unit_string})
-        self.error_message = msg
+        msg = _("Only %(value)s %(verb)s request(s) can be "
+                "made to %(uri)s every %(unit_string)s.")
+        self.error_message = msg % self.__dict__
 
     def __call__(self, verb, url):
         """Represents a call to this limit from a relevant request.
@@ -170,7 +165,6 @@ class Limit(object):
             "resetTime": int(self.next_request or self._get_time()),
         }
 
-
 # "Limit" format is a dictionary with the HTTP verb, human-readable URI,
 # a regular-expression to match, value and unit of measure (PER_DAY, etc.)
 
@@ -412,7 +406,7 @@ class WsgiLimiterProxy(object):
         body = jsonutils.dumps({"verb": verb, "path": path})
         headers = {"Content-Type": "application/json"}
 
-        conn = http_client.HTTPConnection(self.limiter_address)
+        conn = httplib.HTTPConnection(self.limiter_address)
 
         if username:
             conn.request("POST", "/%s" % (username), body, headers)
