@@ -13,9 +13,8 @@
 #    License for the specific language governing permissions and limitations
 #    under the License.
 
-from http import client as http_client
-
 from oslo_log import log
+import six
 import webob
 from webob import exc
 
@@ -25,101 +24,81 @@ from manila.common import constants
 from manila.db import api as db_api
 from manila import exception
 from manila.i18n import _
+from manila import policy
 from manila import share
 
+RESOURCE_NAME = 'share_server'
+RESOURCES_NAME = 'share_servers'
 LOG = log.getLogger(__name__)
 
 
 class ShareServerController(wsgi.Controller):
     """The Share Server API controller for the OpenStack API."""
 
-    _view_builder_class = share_servers_views.ViewBuilder
-    resource_name = 'share_server'
-
     def __init__(self):
         self.share_api = share.API()
+        self._view_builder_class = share_servers_views.ViewBuilder
         super(ShareServerController, self).__init__()
 
-    @wsgi.Controller.authorize
     def index(self, req):
         """Returns a list of share servers."""
 
         context = req.environ['manila.context']
+        policy.check_policy(context, RESOURCE_NAME, 'index')
 
         search_opts = {}
         search_opts.update(req.GET)
+
         share_servers = db_api.share_server_get_all(context)
         for s in share_servers:
-            try:
-                share_network = db_api.share_network_get(
-                    context, s.share_network_id)
-                s.project_id = share_network['project_id']
-                if share_network['name']:
-                    s.share_network_name = share_network['name']
-                else:
-                    s.share_network_name = share_network['id']
-            except exception.ShareNetworkNotFound:
-                # NOTE(dviroel): The share-network may already be deleted while
-                # the share-server is in 'deleting' state. In this scenario,
-                # we will return some empty values.
-                LOG.debug("Unable to retrieve share network details for share "
-                          "server %(server)s, the network %(network)s was "
-                          "not found.",
-                          {'server': s.id, 'network': s.share_network_id})
-                s.project_id = ''
-                s.share_network_name = ''
+            s.project_id = s.share_network['project_id']
+            if s.share_network['name']:
+                s.share_network_name = s.share_network['name']
+            else:
+                s.share_network_name = s.share_network_id
         if search_opts:
-            for k, v in search_opts.items():
+            for k, v in six.iteritems(search_opts):
                 share_servers = [s for s in share_servers if
                                  (hasattr(s, k) and
                                   s[k] == v or k == 'share_network' and
-                                  v in [s.share_network_name,
-                                        s.share_network_id] or
-                                  k == 'share_network_subnet_id' and
-                                  v in s.share_network_subnet_ids)]
-        return self._view_builder.build_share_servers(req, share_servers)
+                                  v in [s.share_network['name'],
+                                        s.share_network['id']])]
+        return self._view_builder.build_share_servers(share_servers)
 
-    @wsgi.Controller.authorize
     def show(self, req, id):
         """Return data about the requested share server."""
         context = req.environ['manila.context']
+        policy.check_policy(context, RESOURCE_NAME, 'show')
         try:
             server = db_api.share_server_get(context, id)
-            share_network = db_api.share_network_get(
-                context, server['share_network_id'])
-            server.project_id = share_network['project_id']
-            if share_network['name']:
-                server.share_network_name = share_network['name']
+            server.project_id = server.share_network["project_id"]
+            if server.share_network['name']:
+                server.share_network_name = server.share_network['name']
             else:
-                server.share_network_name = share_network['id']
+                server.share_network_name = server.share_network_id
         except exception.ShareServerNotFound as e:
-            raise exc.HTTPNotFound(explanation=e.msg)
-        except exception.ShareNetworkNotFound:
-            msg = _("Share server could not be found. Its associated share "
-                    "network %s does not exist.") % server['share_network_id']
-            raise exc.HTTPNotFound(explanation=msg)
-        return self._view_builder.build_share_server(req, server)
+            raise exc.HTTPNotFound(explanation=six.text_type(e))
+        return self._view_builder.build_share_server(server)
 
-    @wsgi.Controller.authorize
     def details(self, req, id):
         """Return details for requested share server."""
         context = req.environ['manila.context']
+        policy.check_policy(context, RESOURCE_NAME, 'details')
         try:
-            share_server = db_api.share_server_get(context, id)
+            db_api.share_server_get(context, id)
         except exception.ShareServerNotFound as e:
-            raise exc.HTTPNotFound(explanation=e.msg)
+            raise exc.HTTPNotFound(explanation=six.text_type(e))
+        details = db_api.share_server_backend_details_get(context, id)
+        return self._view_builder.build_share_server_details(details)
 
-        return self._view_builder.build_share_server_details(
-            share_server['backend_details'])
-
-    @wsgi.Controller.authorize
     def delete(self, req, id):
         """Delete specified share server."""
         context = req.environ['manila.context']
+        policy.check_policy(context, RESOURCE_NAME, 'delete')
         try:
             share_server = db_api.share_server_get(context, id)
         except exception.ShareServerNotFound as e:
-            raise exc.HTTPNotFound(explanation=e.msg)
+            raise exc.HTTPNotFound(explanation=six.text_type(e))
         allowed_statuses = [constants.STATUS_ERROR, constants.STATUS_ACTIVE]
         if share_server['status'] not in allowed_statuses:
             data = {
@@ -133,8 +112,8 @@ class ShareServerController(wsgi.Controller):
         try:
             self.share_api.delete_share_server(context, share_server)
         except exception.ShareServerInUse as e:
-            raise exc.HTTPConflict(explanation=e.msg)
-        return webob.Response(status_int=http_client.ACCEPTED)
+            raise exc.HTTPConflict(explanation=six.text_type(e))
+        return webob.Response(status_int=202)
 
 
 def create_resource():
