@@ -20,10 +20,6 @@ class ViewBuilder(common.ViewBuilder):
     """Model a server API response as a python dictionary."""
 
     _collection_name = 'snapshots'
-    _detail_version_modifiers = [
-        "add_provider_location_field",
-        "add_project_and_user_ids",
-    ]
 
     def summary_list(self, request, snapshots):
         """Show a list of share snapshots without many details."""
@@ -45,35 +41,21 @@ class ViewBuilder(common.ViewBuilder):
 
     def detail(self, request, snapshot):
         """Detailed view of a single share snapshot."""
-        snapshot_dict = {
-            'id': snapshot.get('id'),
-            'share_id': snapshot.get('share_id'),
-            'share_size': snapshot.get('share_size'),
-            'created_at': snapshot.get('created_at'),
-            'status': snapshot.get('aggregate_status'),
-            'name': snapshot.get('display_name'),
-            'description': snapshot.get('display_description'),
-            'size': snapshot.get('size'),
-            'share_proto': snapshot.get('share_proto'),
-            'links': self._get_links(request, snapshot['id']),
+        return {
+            'snapshot': {
+                'id': snapshot.get('id'),
+                'share_id': snapshot.get('share_id'),
+                'share_size': snapshot.get('share_size'),
+                'created_at': snapshot.get('created_at'),
+                'status': snapshot.get('status'),
+                'name': snapshot.get('display_name'),
+                'description': snapshot.get('display_description'),
+                'size': snapshot.get('size'),
+                'share_proto': snapshot.get('share_proto'),
+                'links': self._get_links(request, snapshot['id'])
+            }
         }
 
-        self.update_versioned_resource_dict(request, snapshot_dict, snapshot)
-
-        return {'snapshot': snapshot_dict}
-
-    @common.ViewBuilder.versioned_method("2.12")
-    def add_provider_location_field(self, context, snapshot_dict, snapshot):
-        # NOTE(xyang): Only retrieve provider_location for admin.
-        if context.is_admin:
-            snapshot_dict['provider_location'] = snapshot.get(
-                'provider_location')
-
-    @common.ViewBuilder.versioned_method("2.17")
-    def add_project_and_user_ids(self, context, snapshot_dict, snapshot):
-        snapshot_dict['user_id'] = snapshot.get('user_id')
-        snapshot_dict['project_id'] = snapshot.get('project_id')
-
     def _list_view(self, func, request, snapshots):
         """Provide a view for a list of share snapshots."""
         snapshots_list = [func(request, snapshot)['snapshot']
