@@ -19,61 +19,75 @@
 
 import copy
 
-from oslo_context import context
-from oslo_db.sqlalchemy import enginefacade
+from oslo_context import context as common_context
+from oslo_log import log
 from oslo_utils import timeutils
+import six
 
 from manila.i18n import _
+from manila.i18n import _LW
+from manila.openstack.common import local
 from manila import policy
 
+LOG = log.getLogger(__name__)
 
-@enginefacade.transaction_context_provider
-class RequestContext(context.RequestContext):
+
+class RequestContext(object):
     """Security context and request information.
 
     Represents the user taking a given action within the system.
 
     """
 
-    def __init__(self, user_id=None, project_id=None, is_admin=None,
-                 read_deleted="no", project_name=None, remote_address=None,
-                 timestamp=None, quota_class=None, service_catalog=None,
-                 **kwargs):
+    def __init__(self, user_id, project_id, is_admin=None, read_deleted="no",
+                 roles=None, remote_address=None, timestamp=None,
+                 request_id=None, auth_token=None, overwrite=True,
+                 quota_class=None, service_catalog=None, **kwargs):
         """Initialize RequestContext.
 
         :param read_deleted: 'no' indicates deleted records are hidden, 'yes'
             indicates deleted records are visible, 'only' indicates that
             *only* deleted records are visible.
 
-        :param kwargs: Extra arguments passed transparently to
-            oslo_context.RequestContext.
+        :param overwrite: Set to False to ensure that the greenthread local
+            copy of the index is not overwritten.
+
+        :param kwargs: Extra arguments that might be present, but we ignore
+            because they possibly came in from older rpc messages.
         """
-        kwargs.setdefault('user_id', user_id)
-        kwargs.setdefault('project_id', project_id)
+        if kwargs:
+            LOG.warn(_LW('Arguments dropped when creating context: %s'),
+                     str(kwargs))
 
-        super(RequestContext, self).__init__(is_admin=is_admin, **kwargs)
-
-        self.project_name = project_name
+        self.user_id = user_id
+        self.project_id = project_id
+        self.roles = roles or []
+        self.is_admin = is_admin
         if self.is_admin is None:
-            self.is_admin = policy.check_is_admin(self)
+            self.is_admin = policy.check_is_admin(self.roles)
         elif self.is_admin and 'admin' not in self.roles:
             self.roles.append('admin')
-        # a "service" user's token will contain "service_roles"
-        self.is_service = kwargs.get('service_roles') or False
         self.read_deleted = read_deleted
         self.remote_address = remote_address
         if not timestamp:
             timestamp = timeutils.utcnow()
-        elif isinstance(timestamp, str):
-            timestamp = timeutils.parse_isotime(timestamp)
+        if isinstance(timestamp, six.string_types):
+            timestamp = timeutils.parse_strtime(timestamp)
         self.timestamp = timestamp
-        self.quota_class = quota_class
         if service_catalog:
             self.service_catalog = [s for s in service_catalog
                                     if s.get('type') in ('compute', 'volume')]
         else:
             self.service_catalog = []
 
+        if not request_id:
+            request_id = common_context.generate_request_id()
+        self.request_id = request_id
+        self.auth_token = auth_token
+        self.quota_class = quota_class
+        if overwrite or not hasattr(local.store, 'context'):
+            self.update_store()
+
     def _get_read_deleted(self):
         return self._read_deleted
 
@@ -89,57 +103,53 @@ class RequestContext(context.RequestContext):
     read_deleted = property(_get_read_deleted, _set_read_deleted,
                             _del_read_deleted)
 
+    def update_store(self):
+        local.store.context = self
+
     def to_dict(self):
-        values = super(RequestContext, self).to_dict()
-        values['user_id'] = self.user_id
-        values['project_id'] = self.project_id
-        values['project_name'] = self.project_name
-        values['domain_id'] = self.domain_id
-        values['read_deleted'] = self.read_deleted
-        values['remote_address'] = self.remote_address
-        values['timestamp'] = self.timestamp.isoformat()
-        values['quota_class'] = self.quota_class
-        values['service_catalog'] = self.service_catalog
-        values['request_id'] = self.request_id
-        return values
+        return {'user_id': self.user_id,
+                'project_id': self.project_id,
+                'is_admin': self.is_admin,
+                'read_deleted': self.read_deleted,
+                'roles': self.roles,
+                'remote_address': self.remote_address,
+                'timestamp': timeutils.strtime(self.timestamp),
+                'request_id': self.request_id,
+                'auth_token': self.auth_token,
+                'quota_class': self.quota_class,
+                'tenant': self.tenant,
+                'service_catalog': self.service_catalog,
+                'user': self.user}
 
     @classmethod
     def from_dict(cls, values):
-        return cls(
-            user_id=values.get('user_id'),
-            project_id=values.get('project_id'),
-            project_name=values.get('project_name'),
-            domain_id=values.get('domain_id'),
-            read_deleted=values.get('read_deleted', 'no'),
-            remote_address=values.get('remote_address'),
-            timestamp=values.get('timestamp'),
-            quota_class=values.get('quota_class'),
-            service_catalog=values.get('service_catalog'),
-            request_id=values.get('request_id'),
-            is_admin=values.get('is_admin'),
-            roles=values.get('roles'),
-            auth_token=values.get('auth_token'),
-            user_domain_id=values.get('user_domain_id'),
-            project_domain_id=values.get('project_domain_id')
-        )
+        return cls(**values)
 
     def elevated(self, read_deleted=None, overwrite=False):
         """Return a version of this context with admin flag set."""
-        ctx = copy.deepcopy(self)
-        ctx.is_admin = True
+        context = copy.deepcopy(self)
+        context.is_admin = True
 
-        if 'admin' not in ctx.roles:
-            ctx.roles.append('admin')
+        if 'admin' not in context.roles:
+            context.roles.append('admin')
 
         if read_deleted is not None:
-            ctx.read_deleted = read_deleted
+            context.read_deleted = read_deleted
 
-        return ctx
+        return context
 
-    def to_policy_values(self):
-        policy = super(RequestContext, self).to_policy_values()
-        policy['is_admin'] = self.is_admin
-        return policy
+    # NOTE(sirp): the openstack/common version of RequestContext uses
+    # tenant/user whereas the Manila version uses project_id/user_id. We need
+    # this shim in order to use context-aware code from openstack/common, like
+    # logging, until we make the switch to using openstack/common's version of
+    # RequestContext.
+    @property
+    def tenant(self):
+        return self.project_id
+
+    @property
+    def user(self):
+        return self.user_id
 
 
 def get_admin_context(read_deleted="no"):
