@@ -25,29 +25,31 @@ revision = '38e632621e5a'
 down_revision = '211836bf835c'
 
 from alembic import op
-from oslo_log import log
+
+from manila.i18n import _LI
+from manila.openstack.common import log as logging
+
 from oslo_utils import strutils
 import sqlalchemy as sa
 from sqlalchemy.sql import table
 
-
-LOG = log.getLogger(__name__)
+LOG = logging.getLogger(__name__)
 
 
 def upgrade():
-    LOG.info("Renaming column name shares.volume_type_id to "
-             "shares.share_type.id")
+    LOG.info(_LI("Renaming column name shares.volume_type_id to "
+             "shares.share_type.id"))
     op.alter_column("shares", "volume_type_id",
                     new_column_name="share_type_id",
                     type_=sa.String(length=36))
 
-    LOG.info("Renaming volume_types table to share_types")
+    LOG.info(_LI("Renaming volume_types table to share_types"))
     op.rename_table("volume_types", "share_types")
     op.drop_constraint('vt_name_uc', 'share_types', type_='unique')
     op.create_unique_constraint('st_name_uc', 'share_types',
                                 ['name', 'deleted'])
 
-    LOG.info("Creating share_type_extra_specs table")
+    LOG.info(_LI("Creating share_type_extra_specs table"))
     st_es = op.create_table(
         'share_type_extra_specs',
         sa.Column('created_at', sa.DateTime),
@@ -60,18 +62,18 @@ def upgrade():
                   nullable=False),
         sa.Column('spec_key', sa.String(length=255)),
         sa.Column('spec_value', sa.String(length=255)),
-        mysql_engine='InnoDB', mysql_charset='utf8')
+        mysql_engine='InnoDB')
 
-    LOG.info("Migrating volume_type_extra_specs to "
-             "share_type_extra_specs")
+    LOG.info(_LI("Migrating volume_type_extra_specs to "
+                 "share_type_extra_specs"))
     _copy_records(destination_table=st_es, up_migration=True)
 
-    LOG.info("Dropping volume_type_extra_specs table")
+    LOG.info(_LI("Dropping volume_type_extra_specs table"))
     op.drop_table("volume_type_extra_specs")
 
 
 def downgrade():
-    LOG.info("Creating volume_type_extra_specs table")
+    LOG.info(_LI("Creating volume_type_extra_specs table"))
     vt_es = op.create_table(
         'volume_type_extra_specs',
         sa.Column('created_at', sa.DateTime),
@@ -85,21 +87,21 @@ def downgrade():
         sa.Column('value', sa.String(length=255)),
         mysql_engine='InnoDB')
 
-    LOG.info("Migrating share_type_extra_specs to "
-             "volume_type_extra_specs")
+    LOG.info(_LI("Migrating share_type_extra_specs to "
+             "volume_type_extra_specs"))
     _copy_records(destination_table=vt_es, up_migration=False)
 
-    LOG.info("Dropping share_type_extra_specs table")
+    LOG.info(_LI("Dropping share_type_extra_specs table"))
     op.drop_table("share_type_extra_specs")
 
-    LOG.info("Renaming share_types table to volume_types")
+    LOG.info(_LI("Renaming share_types table to volume_types"))
     op.drop_constraint('st_name_uc', 'share_types', type_='unique')
     op.create_unique_constraint('vt_name_uc', 'share_types',
                                 ['name', 'deleted'])
     op.rename_table("share_types", "volume_types")
 
-    LOG.info("Renaming column name shares.share_type_id to "
-             "shares.volume_type.id")
+    LOG.info(_LI("Renaming column name shares.share_type_id to "
+             "shares.volume_type.id"))
     op.alter_column("shares", "share_type_id",
                     new_column_name="volume_type_id",
                     type_=sa.String(length=36))
@@ -114,7 +116,7 @@ def _copy_records(destination_table, up_migration=True):
         sa.Column('created_at', sa.DateTime),
         sa.Column('updated_at', sa.DateTime),
         sa.Column('deleted_at', sa.DateTime),
-        sa.Column('deleted', sa.Boolean if up_migration else sa.Integer),
+        sa.Column('deleted', sa.Integer if up_migration else sa.Boolean),
         sa.Column('id', sa.Integer, primary_key=True, nullable=False),
         sa.Column(data_from[0] + '_type_id', sa.String(length=36)),
         sa.Column(data_from[1] + 'key', sa.String(length=255)),
@@ -125,12 +127,13 @@ def _copy_records(destination_table, up_migration=True):
         if up_migration:
             deleted = strutils.int_from_bool_as_string(es.deleted)
         else:
-            deleted = strutils.bool_from_string(es.deleted, default=True)
+            deleted = strutils.bool_from_string(es.deleted)
         extra_specs.append({
             'created_at': es.created_at,
             'updated_at': es.updated_at,
             'deleted_at': es.deleted_at,
             'deleted': deleted,
+            'id': es.id,
             data_to[0] + '_type_id': getattr(es, data_from[0] + '_type_id'),
             data_to[1] + 'key': getattr(es, data_from[1] + 'key'),
             data_to[1] + 'value': getattr(es, data_from[1] + 'value'),
