@@ -51,13 +51,12 @@ This module provides Manager, a base class for managers.
 
 """
 
-
-from eventlet import greenpool
 from oslo_config import cfg
 from oslo_log import log
-from oslo_service import periodic_task
+import six
 
 from manila.db import base
+from manila.i18n import _LE
 from manila.scheduler import rpcapi as scheduler_rpcapi
 from manila import version
 
@@ -65,12 +64,69 @@ CONF = cfg.CONF
 LOG = log.getLogger(__name__)
 
 
-class PeriodicTasks(periodic_task.PeriodicTasks):
-    def __init__(self):
-        super(PeriodicTasks, self).__init__(CONF)
+def periodic_task(*args, **kwargs):
+    """Decorator to indicate that a method is a periodic task.
+
+    This decorator can be used in two ways:
+
+        1. Without arguments '@periodic_task', this will be run on every tick
+           of the periodic scheduler.
+
+        2. With arguments, @periodic_task(ticks_between_runs=N), this will be
+           run on every N ticks of the periodic scheduler.
+    """
+    def decorator(f):
+        f._periodic_task = True
+        f._ticks_between_runs = kwargs.pop('ticks_between_runs', 0)
+        return f
+
+    # NOTE(sirp): The `if` is necessary to allow the decorator to be used with
+    # and without parens.
+    #
+    # In the 'with-parens' case (with kwargs present), this function needs to
+    # return a decorator function since the interpreter will invoke it like:
+    #
+    #   periodic_task(*args, **kwargs)(f)
+    #
+    # In the 'without-parens' case, the original function will be passed
+    # in as the first argument, like:
+    #
+    #   periodic_task(f)
+    if kwargs:
+        return decorator
+    else:
+        return decorator(args[0])
 
 
-class Manager(base.Base, PeriodicTasks):
+class ManagerMeta(type):
+    def __init__(cls, names, bases, dict_):
+        """Metaclass that allows us to collect decorated periodic tasks."""
+        super(ManagerMeta, cls).__init__(names, bases, dict_)
+
+        # NOTE(sirp): if the attribute is not present then we must be the base
+        # class, so, go ahead an initialize it. If the attribute is present,
+        # then we're a subclass so make a copy of it so we don't step on our
+        # parent's toes.
+        try:
+            cls._periodic_tasks = cls._periodic_tasks[:]
+        except AttributeError:
+            cls._periodic_tasks = []
+
+        try:
+            cls._ticks_to_skip = cls._ticks_to_skip.copy()
+        except AttributeError:
+            cls._ticks_to_skip = {}
+
+        for value in cls.__dict__.values():
+            if getattr(value, '_periodic_task', False):
+                task = value
+                name = task.__name__
+                cls._periodic_tasks.append((name, task))
+                cls._ticks_to_skip[name] = task._ticks_between_runs
+
+
+@six.add_metaclass(ManagerMeta)
+class Manager(base.Base):
 
     @property
     def RPC_API_VERSION(self):
@@ -84,7 +140,7 @@ class Manager(base.Base, PeriodicTasks):
         https://wiki.openstack.org/wiki/Oslo/Messaging#API_Version_Negotiation
         """
         if not hasattr(self, '_target'):
-            import oslo_messaging as messaging
+            from oslo import messaging
             self._target = messaging.Target(version=self.RPC_API_VERSION)
         return self._target
 
@@ -93,32 +149,39 @@ class Manager(base.Base, PeriodicTasks):
             host = CONF.host
         self.host = host
         self.additional_endpoints = []
-        self.availability_zone = CONF.storage_availability_zone
         super(Manager, self).__init__(db_driver)
 
     def periodic_tasks(self, context, raise_on_error=False):
         """Tasks to be run at a periodic interval."""
-        return self.run_periodic_tasks(context, raise_on_error=raise_on_error)
+        for task_name, task in self._periodic_tasks:
+            full_task_name = '.'.join([self.__class__.__name__, task_name])
 
-    def init_host(self, service_id=None):
+            ticks_to_skip = self._ticks_to_skip[task_name]
+            if ticks_to_skip > 0:
+                LOG.debug("Skipping %(full_task_name)s, %(ticks_to_skip)s"
+                          " ticks left until next run",
+                          {'full_task_name': full_task_name,
+                           'ticks_to_skip': ticks_to_skip})
+                self._ticks_to_skip[task_name] -= 1
+                continue
+
+            self._ticks_to_skip[task_name] = task._ticks_between_runs
+            LOG.debug("Running periodic task %(full_task_name)s",
+                      {'full_task_name': full_task_name})
+
+            try:
+                task(self, context)
+            except Exception as e:
+                if raise_on_error:
+                    raise
+                LOG.exception(_LE("Error during %(full_task_name)s: %(e)s"),
+                              {'full_task_name': full_task_name, 'e': e})
+
+    def init_host(self):
         """Handle initialization if this is a standalone service.
 
-        A hook point for services to execute tasks before the services are made
-        available (i.e. showing up on RPC and starting to accept RPC calls) to
-        other components.  Child classes should override this method.
+        Child classes should override this method.
 
-        :param service_id: ID of the service where the manager is running.
-        """
-        pass
-
-    def init_host_with_rpc(self, service_id=None):
-        """A hook for service to do jobs after RPC is ready.
-
-        Like init_host(), this method is a hook where services get a chance
-        to execute tasks that *need* RPC. Child classes should override
-        this method.
-
-        :param service_id: ID of the service where the manager is running.
         """
         pass
 
@@ -131,15 +194,6 @@ class Manager(base.Base, PeriodicTasks):
             config[key] = CONF.get(key, None)
         return config
 
-    def is_service_ready(self):
-        """Method indicating if service is ready.
-
-        This method should be overridden by subclasses which will return False
-        when the back end is not ready yet.
-
-        """
-        return True
-
 
 class SchedulerDependentManager(Manager):
     """Periodically send capability updates to the Scheduler services.
@@ -155,17 +209,13 @@ class SchedulerDependentManager(Manager):
         self.last_capabilities = None
         self.service_name = service_name
         self.scheduler_rpcapi = scheduler_rpcapi.SchedulerAPI()
-        self._tp = greenpool.GreenPool()
         super(SchedulerDependentManager, self).__init__(host, db_driver)
 
-    def _add_to_threadpool(self, func, *args, **kwargs):
-        self._tp.spawn_n(func, *args, **kwargs)
-
     def update_service_capabilities(self, capabilities):
         """Remember these capabilities to send on next periodic update."""
         self.last_capabilities = capabilities
 
-    @periodic_task.periodic_task
+    @periodic_task
     def _publish_service_capabilities(self, context):
         """Pass data back to the scheduler at a periodic interval."""
         if self.last_capabilities:
