@@ -22,6 +22,8 @@ import six
 
 from manila import exception
 from manila.i18n import _
+from manila.i18n import _LE
+from manila.i18n import _LW
 from manila.network.linux import ip_lib
 from manila.network.linux import ovs_lib
 from manila import utils
@@ -143,7 +145,7 @@ class OVSInterfaceDriver(LinuxInterfaceDriver):
 
         if not ip_lib.device_exists(device_name,
                                     namespace=namespace):
-            LOG.info("Device %s does not exist - creating ....", device_name)
+
             tap_name = self._get_tap_name(device_name)
             self._ovs_add_port(bridge, tap_name, port_id, mac_address)
             ns_dev.link.set_address(mac_address)
@@ -154,10 +156,7 @@ class OVSInterfaceDriver(LinuxInterfaceDriver):
                 namespace_obj.add_device_to_namespace(ns_dev)
 
         else:
-            LOG.info("Device %s already exists.", device_name)
-            if ns_dev.link.address != mac_address:
-                LOG.warning("Reset mac address to %s", mac_address)
-                ns_dev.link.set_address(mac_address)
+            LOG.warn(_LW("Device %s already exists"), device_name)
         ns_dev.link.set_up()
 
     @device_name_synchronized
@@ -173,7 +172,7 @@ class OVSInterfaceDriver(LinuxInterfaceDriver):
         try:
             ovs.delete_port(tap_name)
         except RuntimeError:
-            LOG.error("Failed unplugging interface '%s'",
+            LOG.error(_LE("Failed unplugging interface '%s'"),
                       device_name)
 
 
@@ -202,7 +201,7 @@ class BridgeInterfaceDriver(LinuxInterfaceDriver):
         else:
             ns_veth = ip.device(device_name)
             root_veth = ip.device(tap_name)
-            LOG.warning("Device %s already exists.", device_name)
+            LOG.warn(_LW("Device %s already exists"), device_name)
 
         root_veth.link.set_up()
         ns_veth.link.set_up()
@@ -215,5 +214,5 @@ class BridgeInterfaceDriver(LinuxInterfaceDriver):
             device.link.delete()
             LOG.debug("Unplugged interface '%s'", device_name)
         except RuntimeError:
-            LOG.error("Failed unplugging interface '%s'",
+            LOG.error(_LE("Failed unplugging interface '%s'"),
                       device_name)
