@@ -17,36 +17,38 @@ import re
 
 from oslo_log import log
 
+from manila.i18n import _LE
 from manila import utils
 
 LOG = log.getLogger(__name__)
 
 
-class OVSBridge(object):
+class OVSBridge:
     def __init__(self, br_name):
         self.br_name = br_name
         self.re_id = self.re_compile_id()
 
     def re_compile_id(self):
-        external = r'external_ids\s*'
-        mac = r'attached-mac="(?P<vif_mac>([a-fA-F\d]{2}:){5}([a-fA-F\d]{2}))"'
-        iface = r'iface-id="(?P<vif_id>[^"]+)"'
-        name = r'name\s*:\s"(?P<port_name>[^"]*)"'
-        port = r'ofport\s*:\s(?P<ofport>-?\d+)'
-        _re = (r'%(external)s:\s{ ( %(mac)s,? | %(iface)s,? | . )* }'
-               r' \s+ %(name)s \s+ %(port)s' % {'external': external,
-                                                'mac': mac,
-                                                'iface': iface, 'name': name,
-                                                'port': port})
+        external = 'external_ids\s*'
+        mac = 'attached-mac="(?P<vif_mac>([a-fA-F\d]{2}:){5}([a-fA-F\d]{2}))"'
+        iface = 'iface-id="(?P<vif_id>[^"]+)"'
+        name = 'name\s*:\s"(?P<port_name>[^"]*)"'
+        port = 'ofport\s*:\s(?P<ofport>-?\d+)'
+        _re = ('%(external)s:\s{ ( %(mac)s,? | %(iface)s,? | . )* }'
+               ' \s+ %(name)s \s+ %(port)s' % {'external': external,
+                                               'mac': mac,
+                                               'iface': iface, 'name': name,
+                                               'port': port})
         return re.compile(_re, re.M | re.X)
 
     def run_vsctl(self, args):
         full_args = ["ovs-vsctl", "--timeout=2"] + args
         try:
             return utils.execute(*full_args, run_as_root=True)
-        except Exception:
-            LOG.exception("Unable to execute %(cmd)s.",
-                          {'cmd': full_args})
+        except Exception as e:
+            LOG.error(_LE("Unable to execute %(cmd)s. Exception: "
+                          "%(exception)s"),
+                      {'cmd': full_args, 'exception': e})
 
     def reset_bridge(self):
         self.run_vsctl(["--", "--if-exists", "del-br", self.br_name])
