@@ -22,85 +22,45 @@ from oslo_config import cfg
 from oslo_log import log
 from oslo_utils import importutils
 from oslo_utils import timeutils
+import six
 
 from manila import db
 from manila import exception
+from manila.i18n import _LE
 
 LOG = log.getLogger(__name__)
 
-QUOTA_GROUP = 'quota'
-
 quota_opts = [
-    cfg.IntOpt('shares',
+    cfg.IntOpt('quota_shares',
                default=50,
-               help='Number of shares allowed per project.',
-               deprecated_group='DEFAULT',
-               deprecated_name='quota_shares'),
-    cfg.IntOpt('snapshots',
+               help='Number of shares allowed per project.'),
+    cfg.IntOpt('quota_snapshots',
                default=50,
-               help='Number of share snapshots allowed per project.',
-               deprecated_group='DEFAULT',
-               deprecated_name='quota_snapshots'),
-    cfg.IntOpt('gigabytes',
+               help='Number of share snapshots allowed per project.'),
+    cfg.IntOpt('quota_gigabytes',
                default=1000,
-               help='Number of share gigabytes allowed per project.',
-               deprecated_group='DEFAULT',
-               deprecated_name='quota_gigabytes'),
-    cfg.IntOpt('per_share_gigabytes',
-               default=-1,
-               help='Max size allowed per share, in gigabytes.',
-               deprecated_group='DEFAULT',
-               deprecated_name='quota_per_share_gigabytes'),
-    cfg.IntOpt('snapshot_gigabytes',
+               help='Number of share gigabytes allowed per project.'),
+    cfg.IntOpt('quota_snapshot_gigabytes',
                default=1000,
-               help='Number of snapshot gigabytes allowed per project.',
-               deprecated_group='DEFAULT',
-               deprecated_name='quota_snapshot_gigabytes'),
-    cfg.IntOpt('share_networks',
+               help='Number of snapshot gigabytes allowed per project.'),
+    cfg.IntOpt('quota_share_networks',
                default=10,
-               help='Number of share-networks allowed per project.',
-               deprecated_group='DEFAULT',
-               deprecated_name='quota_share_networks'),
-    cfg.IntOpt('share_replicas',
-               default=100,
-               help='Number of share-replicas allowed per project.',
-               deprecated_group='DEFAULT',
-               deprecated_name='quota_share_replicas'),
-    cfg.IntOpt('replica_gigabytes',
-               default=1000,
-               help='Number of replica gigabytes allowed per project.',
-               deprecated_group='DEFAULT',
-               deprecated_name='quota_replica_gigabytes'),
-    cfg.IntOpt('share_groups',
-               default=50,
-               help='Number of share groups allowed.',
-               deprecated_group='DEFAULT',
-               deprecated_name='quota_share_groups'),
-    cfg.IntOpt('share_group_snapshots',
-               default=50,
-               help='Number of share group snapshots allowed.',
-               deprecated_group='DEFAULT',
-               deprecated_name='quota_share_group_snapshots'),
+               help='Number of share-networks allowed per project.'),
     cfg.IntOpt('reservation_expire',
                default=86400,
-               help='Number of seconds until a reservation expires.',
-               deprecated_group='DEFAULT'),
+               help='Number of seconds until a reservation expires.'),
     cfg.IntOpt('until_refresh',
                default=0,
-               help='Count of reservations until usage is refreshed.',
-               deprecated_group='DEFAULT'),
+               help='Count of reservations until usage is refreshed.'),
     cfg.IntOpt('max_age',
                default=0,
-               help='Number of seconds between subsequent usage refreshes.',
-               deprecated_group='DEFAULT'),
-    cfg.StrOpt('driver',
+               help='Number of seconds between subsequent usage refreshes.'),
+    cfg.StrOpt('quota_driver',
                default='manila.quota.DbQuotaDriver',
-               help='Default driver to use for quota checks.',
-               deprecated_group='DEFAULT',
-               deprecated_name='quota_driver'), ]
+               help='Default driver to use for quota checks.'), ]
 
 CONF = cfg.CONF
-CONF.register_opts(quota_opts, QUOTA_GROUP)
+CONF.register_opts(quota_opts)
 
 
 class DbQuotaDriver(object):
@@ -110,6 +70,15 @@ class DbQuotaDriver(object):
     quota information.  The default driver utilizes the local
     database.
     """
+    def get_by_project_and_user(self, context, project_id, user_id, resource):
+        """Get a specific quota by project and user."""
+
+        return db.quota_get(context, project_id, user_id, resource)
+
+    def get_by_project(self, context, project_id, resource):
+        """Get a specific quota by project."""
+
+        return db.quota_get(context, project_id, resource)
 
     def get_by_class(self, context, quota_class, resource):
         """Get a specific quota by quota class."""
@@ -128,6 +97,7 @@ class DbQuotaDriver(object):
         for resource in resources.values():
             quotas[resource.name] = default_quotas.get(resource.name,
                                                        resource.default)
+
         return quotas
 
     def get_class_quotas(self, context, resources, quota_class,
@@ -240,7 +210,8 @@ class DbQuotaDriver(object):
                                     remains=remains)
 
     def get_user_quotas(self, context, resources, project_id, user_id,
-                        quota_class=None, defaults=True, usages=True):
+                        quota_class=None, defaults=True,
+                        usages=True):
         """Retrieve quotas for user and project.
 
         Given a list of resources, retrieve the quotas for the given
@@ -262,11 +233,11 @@ class DbQuotaDriver(object):
         :param usages: If True, the current in_use and reserved counts
                        will also be returned.
         """
-        user_quotas = db.quota_get_all_by_project_and_user(
-            context, project_id, user_id)
+        user_quotas = db.quota_get_all_by_project_and_user(context,
+                                                           project_id, user_id)
         # Use the project quota for default user quota.
         proj_quotas = db.quota_get_all_by_project(context, project_id)
-        for key, value in proj_quotas.items():
+        for key, value in six.iteritems(proj_quotas):
             if key not in user_quotas.keys():
                 user_quotas[key] = value
         user_usages = None
@@ -277,47 +248,8 @@ class DbQuotaDriver(object):
                                     user_quotas, quota_class,
                                     defaults=defaults, usages=user_usages)
 
-    def get_share_type_quotas(self, context, resources, project_id,
-                              share_type_id, quota_class=None, defaults=True,
-                              usages=True):
-        """Retrieve quotas for share_type and project.
-
-        Given a list of resources, retrieve the quotas for the given
-        share_type and project.
-
-        :param context: The request context, for access checks.
-        :param resources: A dictionary of the registered resources.
-        :param project_id: The UUID of the project to return quotas for.
-        :param share_type: UUID/name of a share type to return quotas for.
-        :param quota_class: If project_id != context.project_id, the
-                            quota class cannot be determined.  This
-                            parameter allows it to be specified.  It
-                            will be ignored if project_id ==
-                            context.project_id.
-        :param defaults: If True, the quota class value (or the
-                         default value, if there is no value from the
-                         quota class) will be reported if there is no
-                         specific value for the resource.
-        :param usages: If True, the current in_use and reserved counts
-                       will also be returned.
-        """
-        st_quotas = db.quota_get_all_by_project_and_share_type(
-            context, project_id, share_type_id)
-        # Use the project quota for default share_type quota.
-        project_quotas = db.quota_get_all_by_project(context, project_id)
-        for key, value in project_quotas.items():
-            if key not in st_quotas.keys():
-                st_quotas[key] = value
-        st_usages = None
-        if usages:
-            st_usages = db.quota_usage_get_all_by_project_and_share_type(
-                context, project_id, share_type_id)
-        return self._process_quotas(
-            context, resources, project_id, st_quotas, quota_class,
-            defaults=defaults, usages=st_usages)
-
     def get_settable_quotas(self, context, resources, project_id,
-                            user_id=None, share_type_id=None):
+                            user_id=None):
         """Retrieve range of settable quotas.
 
         Given a list of resources, retrieve the range of settable quotas for
@@ -327,34 +259,30 @@ class DbQuotaDriver(object):
         :param resources: A dictionary of the registered resources.
         :param project_id: The ID of the project to return quotas for.
         :param user_id: The ID of the user to return quotas for.
-        :param share_type_id: The UUID of the share_type to return quotas for.
         """
         settable_quotas = {}
-        project_quotas = self.get_project_quotas(
-            context, resources, project_id, remains=True)
-        if user_id or share_type_id:
-            if user_id:
-                subquotas = self.get_user_quotas(
-                    context, resources, project_id, user_id)
-            else:
-                subquotas = self.get_share_type_quotas(
-                    context, resources, project_id, share_type_id)
-            for key, value in subquotas.items():
-                settable_quotas[key] = {
-                    "minimum": value['in_use'] + value['reserved'],
-                    "maximum": project_quotas[key]["limit"],
-                }
+        project_quotas = self.get_project_quotas(context, resources,
+                                                 project_id, remains=True)
+        if user_id:
+            user_quotas = self.get_user_quotas(context, resources,
+                                               project_id, user_id)
+            setted_quotas = db.quota_get_all_by_project_and_user(
+                context, project_id, user_id)
+            for key, value in user_quotas.items():
+                maximum = (project_quotas[key]['remains'] +
+                           setted_quotas.get(key, 0))
+                settable_quotas[key] = dict(
+                    minimum=value['in_use'] + value['reserved'],
+                    maximum=maximum)
         else:
             for key, value in project_quotas.items():
-                minimum = max(
-                    int(value['limit'] - value['remains']),
-                    int(value['in_use'] + value['reserved'])
-                )
-                settable_quotas[key] = {"minimum": minimum, "maximum": -1}
+                minimum = max(int(value['limit'] - value['remains']),
+                              int(value['in_use'] + value['reserved']))
+                settable_quotas[key] = dict(minimum=minimum, maximum=-1)
         return settable_quotas
 
     def _get_quotas(self, context, resources, keys, has_sync, project_id=None,
-                    user_id=None, share_type_id=None):
+                    user_id=None):
         """Retrieve quotas for a resource.
 
         A helper method which retrieves the quotas for the specific
@@ -373,18 +301,17 @@ class DbQuotaDriver(object):
                            common user's tenant.
         :param user_id: Specify the user_id if current context
                         is admin and admin wants to impact on
-                        common user. (Special case: user operates on
-                        resource, owned/created by different user)
+                        common user.
         """
 
         # Filter resources
         if has_sync:
-            sync_filt = lambda x: hasattr(x, 'sync')  # noqa: E731
+            sync_filt = lambda x: hasattr(x, 'sync')
         else:
-            sync_filt = lambda x: not hasattr(x, 'sync')  # noqa: E731
+            sync_filt = lambda x: not hasattr(x, 'sync')
         desired = set(keys)
-        sub_resources = {k: v for k, v in resources.items()
-                         if k in desired and sync_filt(v)}
+        sub_resources = dict((k, v) for k, v in resources.items()
+                             if k in desired and sync_filt(v))
 
         # Make sure we accounted for all of them...
         if len(keys) != len(sub_resources):
@@ -396,11 +323,6 @@ class DbQuotaDriver(object):
             quotas = self.get_user_quotas(context, sub_resources,
                                           project_id, user_id,
                                           context.quota_class, usages=False)
-        elif share_type_id:
-            # Grab and return the quotas (without usages)
-            quotas = self.get_share_type_quotas(
-                context, sub_resources, project_id, share_type_id,
-                context.quota_class, usages=False)
         else:
             # Grab and return the quotas (without usages)
             quotas = self.get_project_quotas(context, sub_resources,
@@ -408,9 +330,10 @@ class DbQuotaDriver(object):
                                              context.quota_class,
                                              usages=False)
 
-        return {k: v['limit'] for k, v in quotas.items()}
+        return dict((k, v['limit']) for k, v in quotas.items())
 
-    def limit_check(self, context, resources, values, project_id=None):
+    def limit_check(self, context, resources, values, project_id=None,
+                    user_id=None):
         """Check simple quota limits.
 
         For limits--those quotas for which there is no usage
@@ -433,6 +356,9 @@ class DbQuotaDriver(object):
         :param project_id: Specify the project_id if current context
                            is admin and admin wants to impact on
                            common user's tenant.
+        :param user_id: Specify the user_id if current context
+                        is admin and admin wants to impact on
+                        common user.
         """
 
         # Ensure no value is less than zero
@@ -443,20 +369,28 @@ class DbQuotaDriver(object):
         # If project_id is None, then we use the project_id in context
         if project_id is None:
             project_id = context.project_id
+        # If user id is None, then we use the user_id in context
+        if user_id is None:
+            user_id = context.user_id
 
+        # Get the applicable quotas
         quotas = self._get_quotas(context, resources, values.keys(),
                                   has_sync=False, project_id=project_id)
+        user_quotas = self._get_quotas(context, resources, values.keys(),
+                                       has_sync=False, project_id=project_id,
+                                       user_id=user_id)
+
         # Check the quotas and construct a list of the resources that
         # would be put over limit by the desired values
         overs = [key for key, val in values.items()
-                 if quotas[key] >= 0 and quotas[key] < val]
+                 if (quotas[key] >= 0 and quotas[key] < val) or
+                 (user_quotas[key] >= 0 and user_quotas[key] < val)]
         if overs:
             raise exception.OverQuota(overs=sorted(overs), quotas=quotas,
                                       usages={})
 
     def reserve(self, context, resources, deltas, expire=None,
-                project_id=None, user_id=None, share_type_id=None,
-                overquota_allowed=False):
+                project_id=None, user_id=None):
         """Check quotas and reserve resources.
 
         For counting quotas--those quotas for which there is a usage
@@ -491,14 +425,13 @@ class DbQuotaDriver(object):
                            common user's tenant.
         :param user_id: Specify the user_id if current context
                         is admin and admin wants to impact on
-                        common user. (Special case: user operates on
-                        resource, owned/created by different user)
+                        common user.
         """
 
         # Set up the reservation expiration
         if expire is None:
-            expire = CONF.quota.reservation_expire
-        if isinstance(expire, int):
+            expire = CONF.reservation_expire
+        if isinstance(expire, (int, long)):
             expire = datetime.timedelta(seconds=expire)
         if isinstance(expire, datetime.timedelta):
             expire = timeutils.utcnow() + expire
@@ -508,7 +441,7 @@ class DbQuotaDriver(object):
         # If project_id is None, then we use the project_id in context
         if project_id is None:
             project_id = context.project_id
-        # If user_id is None, then we use the user_id in context
+        # If user_id is None, then we use the project_id in context
         if user_id is None:
             user_id = context.user_id
 
@@ -516,31 +449,23 @@ class DbQuotaDriver(object):
         # NOTE(Vek): We're not worried about races at this point.
         #            Yes, the admin may be in the process of reducing
         #            quotas, but that's a pretty rare thing.
-        quotas = self._get_quotas(
-            context, resources, deltas, has_sync=True, project_id=project_id)
-        user_quotas = self._get_quotas(
-            context, resources, deltas, has_sync=True,
-            project_id=project_id, user_id=user_id)
-        if share_type_id:
-            share_type_quotas = self._get_quotas(
-                context, resources, deltas, has_sync=True,
-                project_id=project_id, share_type_id=share_type_id)
-        else:
-            share_type_quotas = {}
+        quotas = self._get_quotas(context, resources, deltas.keys(),
+                                  has_sync=True, project_id=project_id)
+        user_quotas = self._get_quotas(context, resources, deltas.keys(),
+                                       has_sync=True, project_id=project_id,
+                                       user_id=user_id)
 
         # NOTE(Vek): Most of the work here has to be done in the DB
         #            API, because we have to do it in a transaction,
         #            which means access to the session.  Since the
         #            session isn't available outside the DBAPI, we
         #            have to do the work there.
-        return db.quota_reserve(
-            context, resources, quotas, user_quotas, share_type_quotas,
-            deltas, expire, CONF.quota.until_refresh, CONF.quota.max_age,
-            project_id=project_id, user_id=user_id,
-            share_type_id=share_type_id, overquota_allowed=overquota_allowed)
+        return db.quota_reserve(context, resources, quotas, user_quotas,
+                                deltas, expire,
+                                CONF.until_refresh, CONF.max_age,
+                                project_id=project_id, user_id=user_id)
 
-    def commit(self, context, reservations, project_id=None, user_id=None,
-               share_type_id=None):
+    def commit(self, context, reservations, project_id=None, user_id=None):
         """Commit reservations.
 
         :param context: The request context, for access checks.
@@ -551,8 +476,7 @@ class DbQuotaDriver(object):
                            common user's tenant.
         :param user_id: Specify the user_id if current context
                         is admin and admin wants to impact on
-                        common user. (Special case: user operates on
-                        resource, owned/created by different user)
+                        common user.
         """
         # If project_id is None, then we use the project_id in context
         if project_id is None:
@@ -561,12 +485,10 @@ class DbQuotaDriver(object):
         if user_id is None:
             user_id = context.user_id
 
-        db.reservation_commit(
-            context, reservations, project_id=project_id, user_id=user_id,
-            share_type_id=share_type_id)
+        db.reservation_commit(context, reservations, project_id=project_id,
+                              user_id=user_id)
 
-    def rollback(self, context, reservations, project_id=None, user_id=None,
-                 share_type_id=None):
+    def rollback(self, context, reservations, project_id=None, user_id=None):
         """Roll back reservations.
 
         :param context: The request context, for access checks.
@@ -577,8 +499,7 @@ class DbQuotaDriver(object):
                            common user's tenant.
         :param user_id: Specify the user_id if current context
                         is admin and admin wants to impact on
-                        common user. (Special case: user operates on
-                        resource, owned/created by different user)
+                        common user.
         """
         # If project_id is None, then we use the project_id in context
         if project_id is None:
@@ -587,9 +508,8 @@ class DbQuotaDriver(object):
         if user_id is None:
             user_id = context.user_id
 
-        db.reservation_rollback(
-            context, reservations, project_id=project_id, user_id=user_id,
-            share_type_id=share_type_id)
+        db.reservation_rollback(context, reservations, project_id=project_id,
+                                user_id=user_id)
 
     def usage_reset(self, context, resources):
         """Reset usage records.
@@ -647,21 +567,6 @@ class DbQuotaDriver(object):
 
         db.quota_destroy_all_by_project_and_user(context, project_id, user_id)
 
-    def destroy_all_by_project_and_share_type(self, context, project_id,
-                                              share_type_id):
-        """Destroy metadata associated with a project and share_type.
-
-        Destroy all quotas, usages, and reservations associated with a
-        project and share_type.
-
-        :param context: The request context, for access checks.
-        :param project_id: The ID of the project.
-        :param share_type_id: The UUID of the share type.
-        """
-
-        db.quota_destroy_all_by_share_type(context, share_type_id,
-                                           project_id=project_id)
-
     def expire(self, context):
         """Expire reservations.
 
@@ -689,11 +594,59 @@ class BaseResource(object):
         self.name = name
         self.flag = flag
 
+    def quota(self, driver, context, **kwargs):
+        """Obtain quota for a resource.
+
+        Given a driver and context, obtain the quota for this
+        resource.
+
+        :param driver: A quota driver.
+        :param context: The request context.
+        :param project_id: The project to obtain the quota value for.
+                           If not provided, it is taken from the
+                           context.  If it is given as None, no
+                           project-specific quota will be searched
+                           for.
+        :param quota_class: The quota class corresponding to the
+                            project, or for which the quota is to be
+                            looked up.  If not provided, it is taken
+                            from the context.  If it is given as None,
+                            no quota class-specific quota will be
+                            searched for.  Note that the quota class
+                            defaults to the value in the context,
+                            which may not correspond to the project if
+                            project_id is not the same as the one in
+                            the context.
+        """
+
+        # Get the project ID
+        project_id = kwargs.get('project_id', context.project_id)
+
+        # Ditto for the quota class
+        quota_class = kwargs.get('quota_class', context.quota_class)
+
+        # Look up the quota for the project
+        if project_id:
+            try:
+                return driver.get_by_project(context, project_id, self.name)
+            except exception.ProjectQuotaNotFound:
+                pass
+
+        # Try for the quota class
+        if quota_class:
+            try:
+                return driver.get_by_class(context, quota_class, self.name)
+            except exception.QuotaClassNotFound:
+                pass
+
+        # OK, return the default
+        return self.default
+
     @property
     def default(self):
         """Return the default value of the quota."""
 
-        return CONF.quota[self.flag] if self.flag else -1
+        return CONF[self.flag] if self.flag else -1
 
 
 class ReservableResource(BaseResource):
@@ -728,8 +681,7 @@ class ReservableResource(BaseResource):
         """
 
         super(ReservableResource, self).__init__(name, flag=flag)
-        if sync:
-            self.sync = sync
+        self.sync = sync
 
 
 class AbsoluteResource(BaseResource):
@@ -792,8 +744,8 @@ class QuotaEngine(object):
         if self.__driver:
             return self.__driver
         if not self._driver_cls:
-            self._driver_cls = CONF.quota.driver
-        if isinstance(self._driver_cls, str):
+            self._driver_cls = CONF.quota_driver
+        if isinstance(self._driver_cls, six.string_types):
             self._driver_cls = importutils.import_object(self._driver_cls)
         self.__driver = self._driver_cls
         return self.__driver
@@ -812,6 +764,17 @@ class QuotaEngine(object):
         for resource in resources:
             self.register_resource(resource)
 
+    def get_by_project_and_user(self, context, project_id, user_id, resource):
+        """Get a specific quota by project and user."""
+
+        return self._driver.get_by_project_and_user(context, project_id,
+                                                    user_id, resource)
+
+    def get_by_project(self, context, project_id, resource):
+        """Get a specific quota by project."""
+
+        return self._driver.get_by_project(context, project_id, resource)
+
     def get_by_class(self, context, quota_class, resource):
         """Get a specific quota by quota class."""
 
@@ -863,28 +826,6 @@ class QuotaEngine(object):
                                             defaults=defaults,
                                             usages=usages)
 
-    def get_share_type_quotas(self, context, project_id, share_type_id,
-                              quota_class=None, defaults=True, usages=True):
-        """Retrieve the quotas for the given user and project.
-
-        :param context: The request context, for access checks.
-        :param project_id: The ID of the project to return quotas for.
-        :param share_type_id: The UUID of the user to return quotas for.
-        :param quota_class: If project_id != context.project_id, the
-                            quota class cannot be determined.  This
-                            parameter allows it to be specified.
-        :param defaults: If True, the quota class value (or the
-                         default value, if there is no value from the
-                         quota class) will be reported if there is no
-                         specific value for the resource.
-        :param usages: If True, the current in_use and reserved counts
-                       will also be returned.
-        """
-
-        return self._driver.get_share_type_quotas(
-            context, self._resources, project_id, share_type_id,
-            quota_class=quota_class, defaults=defaults, usages=usages)
-
     def get_project_quotas(self, context, project_id, quota_class=None,
                            defaults=True, usages=True, remains=False):
         """Retrieve the quotas for the given project.
@@ -911,8 +852,7 @@ class QuotaEngine(object):
                                                usages=usages,
                                                remains=remains)
 
-    def get_settable_quotas(self, context, project_id, user_id=None,
-                            share_type_id=None):
+    def get_settable_quotas(self, context, project_id, user_id=None):
         """Get settable quotas.
 
         Given a list of resources, retrieve the range of settable quotas for
@@ -922,12 +862,11 @@ class QuotaEngine(object):
         :param resources: A dictionary of the registered resources.
         :param project_id: The ID of the project to return quotas for.
         :param user_id: The ID of the user to return quotas for.
-        :param share_type_id: The UUID of the share_type to return quotas for.
         """
 
-        return self._driver.get_settable_quotas(
-            context, self._resources, project_id, user_id=user_id,
-            share_type_id=share_type_id)
+        return self._driver.get_settable_quotas(context, self._resources,
+                                                project_id,
+                                                user_id=user_id)
 
     def count(self, context, resource, *args, **kwargs):
         """Count a resource.
@@ -948,7 +887,7 @@ class QuotaEngine(object):
 
         return res.count(context, *args, **kwargs)
 
-    def limit_check(self, context, project_id=None, **values):
+    def limit_check(self, context, project_id=None, user_id=None, **values):
         """Check simple quota limits.
 
         For limits--those quotas for which there is no usage
@@ -971,13 +910,16 @@ class QuotaEngine(object):
         :param project_id: Specify the project_id if current context
                            is admin and admin wants to impact on
                            common user's tenant.
+        :param user_id: Specify the user_id if current context
+                        is admin and admin wants to impact on
+                        common user.
         """
 
         return self._driver.limit_check(context, self._resources, values,
-                                        project_id=project_id)
+                                        project_id=project_id, user_id=user_id)
 
     def reserve(self, context, expire=None, project_id=None, user_id=None,
-                share_type_id=None, overquota_allowed=False, **deltas):
+                **deltas):
         """Check quotas and reserve resources.
 
         For counting quotas--those quotas for which there is a usage
@@ -1012,21 +954,16 @@ class QuotaEngine(object):
                            common user's tenant.
         """
 
-        reservations = self._driver.reserve(
-            context, self._resources, deltas,
-            expire=expire,
-            project_id=project_id,
-            user_id=user_id,
-            share_type_id=share_type_id,
-            overquota_allowed=overquota_allowed
-        )
+        reservations = self._driver.reserve(context, self._resources, deltas,
+                                            expire=expire,
+                                            project_id=project_id,
+                                            user_id=user_id)
 
         LOG.debug("Created reservations %s", reservations)
 
         return reservations
 
-    def commit(self, context, reservations, project_id=None, user_id=None,
-               share_type_id=None):
+    def commit(self, context, reservations, project_id=None, user_id=None):
         """Commit reservations.
 
         :param context: The request context, for access checks.
@@ -1038,21 +975,19 @@ class QuotaEngine(object):
         """
 
         try:
-            self._driver.commit(
-                context, reservations, project_id=project_id,
-                user_id=user_id, share_type_id=share_type_id)
+            self._driver.commit(context, reservations, project_id=project_id,
+                                user_id=user_id)
         except Exception:
             # NOTE(Vek): Ignoring exceptions here is safe, because the
             # usage resynchronization and the reservation expiration
             # mechanisms will resolve the issue.  The exception is
             # logged, however, because this is less than optimal.
-            LOG.exception("Failed to commit reservations %s",
+            LOG.exception(_LE("Failed to commit reservations %s"),
                           reservations)
             return
         LOG.debug("Committed reservations %s", reservations)
 
-    def rollback(self, context, reservations, project_id=None, user_id=None,
-                 share_type_id=None):
+    def rollback(self, context, reservations, project_id=None, user_id=None):
         """Roll back reservations.
 
         :param context: The request context, for access checks.
@@ -1064,15 +999,14 @@ class QuotaEngine(object):
         """
 
         try:
-            self._driver.rollback(
-                context, reservations, project_id=project_id,
-                user_id=user_id, share_type_id=share_type_id)
+            self._driver.rollback(context, reservations, project_id=project_id,
+                                  user_id=user_id)
         except Exception:
             # NOTE(Vek): Ignoring exceptions here is safe, because the
             # usage resynchronization and the reservation expiration
             # mechanisms will resolve the issue.  The exception is
             # logged, however, because this is less than optimal.
-            LOG.exception("Failed to roll back reservations %s",
+            LOG.exception(_LE("Failed to roll back reservations %s"),
                           reservations)
             return
         LOG.debug("Rolled back reservations %s", reservations)
@@ -1109,21 +1043,6 @@ class QuotaEngine(object):
         self._driver.destroy_all_by_project_and_user(context,
                                                      project_id, user_id)
 
-    def destroy_all_by_project_and_share_type(self, context, project_id,
-                                              share_type_id):
-        """Destroy metadata associated with a project and share_type.
-
-        Destroy all quotas, usages, and reservations associated with a
-        project and share_type.
-
-        :param context: The request context, for access checks.
-        :param project_id: The ID of the project.
-        :param share_type_id: The UUID of the share_type.
-        """
-
-        self._driver.destroy_all_by_project_and_share_type(
-            context, project_id, share_type_id)
-
     def destroy_all_by_project(self, context, project_id):
         """Destroy metadata associated with a project.
 
@@ -1156,23 +1075,13 @@ QUOTAS = QuotaEngine()
 
 
 resources = [
-    ReservableResource('shares', '_sync_shares', 'shares'),
-    ReservableResource('snapshots', '_sync_snapshots', 'snapshots'),
-    ReservableResource('gigabytes', '_sync_gigabytes', 'gigabytes'),
-    ReservableResource('per_share_gigabytes', None,
-                       'per_share_gigabytes'),
+    ReservableResource('shares', '_sync_shares', 'quota_shares'),
+    ReservableResource('snapshots', '_sync_snapshots', 'quota_snapshots'),
+    ReservableResource('gigabytes', '_sync_gigabytes', 'quota_gigabytes'),
     ReservableResource('snapshot_gigabytes', '_sync_snapshot_gigabytes',
-                       'snapshot_gigabytes'),
+                       'quota_snapshot_gigabytes'),
     ReservableResource('share_networks', '_sync_share_networks',
-                       'share_networks'),
-    ReservableResource('share_groups', '_sync_share_groups',
-                       'share_groups'),
-    ReservableResource('share_group_snapshots', '_sync_share_group_snapshots',
-                       'share_group_snapshots'),
-    ReservableResource('share_replicas', '_sync_share_replicas',
-                       'share_replicas'),
-    ReservableResource('replica_gigabytes', '_sync_replica_gigabytes',
-                       'replica_gigabytes'),
+                       'quota_share_networks'),
 ]
 
 
