@@ -1,7 +1,6 @@
 # Copyright (c) 2011 OpenStack, LLC.
 # Copyright (c) 2015 Rushil Chugh
 # Copyright (c) 2015 Clinton Knight
-# Copyright (c) 2015 EMC Corporation
 # All Rights Reserved.
 #
 #    Licensed under the Apache License, Version 2.0 (the "License"); you may
@@ -20,72 +19,46 @@
 Manage hosts in the current zone.
 """
 
-import collections
 import re
+import UserDict
 
 from oslo_config import cfg
 from oslo_log import log
 from oslo_utils import timeutils
+import six
 
 from manila import db
 from manila import exception
-from manila.scheduler.filters import base_host as base_host_filter
-from manila.scheduler import utils as scheduler_utils
-from manila.scheduler.weighers import base_host as base_host_weigher
+from manila.i18n import _LI, _LW
+from manila.openstack.common.scheduler import filters
+from manila.openstack.common.scheduler import weights
 from manila.share import utils as share_utils
 from manila import utils
 
-
 host_manager_opts = [
     cfg.ListOpt('scheduler_default_filters',
                 default=[
-                    'OnlyHostFilter',
                     'AvailabilityZoneFilter',
                     'CapacityFilter',
-                    'CapabilitiesFilter',
-                    'DriverFilter',
-                    'ShareReplicationFilter',
-                    'CreateFromSnapshotFilter',
-                    'AffinityFilter',
-                    'AntiAffinityFilter',
+                    'CapabilitiesFilter'
                 ],
                 help='Which filter class names to use for filtering hosts '
                      'when not specified in the request.'),
     cfg.ListOpt('scheduler_default_weighers',
                 default=[
-                    'CapacityWeigher',
-                    'GoodnessWeigher',
-                    'HostAffinityWeigher',
+                    'CapacityWeigher'
                 ],
-                help='Which weigher class names to use for weighing hosts.'),
-    cfg.ListOpt(
-        'scheduler_default_share_group_filters',
-        default=[
-            'AvailabilityZoneFilter',
-            'ConsistentSnapshotFilter',
-        ],
-        help='Which filter class names to use for filtering hosts '
-             'creating share group when not specified in the request.'),
-    cfg.ListOpt(
-        'scheduler_default_extend_filters',
-        default=[
-            'CapacityFilter',
-            'DriverFilter',
-        ],
-        help='Which filter class names to use for filtering hosts '
-             'extending share when not specified in the request.'),
+                help='Which weigher class names to use for weighing hosts.')
 ]
 
 CONF = cfg.CONF
 CONF.register_opts(host_manager_opts)
-CONF.import_opt('max_over_subscription_ratio', 'manila.share.driver')
 
 LOG = log.getLogger(__name__)
 
 
-class ReadOnlyDict(collections.UserDict):
+class ReadOnlyDict(UserDict.IterableUserDict):
     """A read-only dict."""
-
     def __init__(self, source=None):
         self.data = {}
         self.update(source)
@@ -108,7 +81,7 @@ class ReadOnlyDict(collections.UserDict):
     def update(self, source=None):
         if source is None:
             return
-        elif isinstance(source, collections.UserDict):
+        elif isinstance(source, UserDict.UserDict):
             self.data = source.data
         elif isinstance(source, type({})):
             self.data = source
@@ -129,47 +102,18 @@ class HostState(object):
         self.vendor_name = None
         self.driver_version = 0
         self.storage_protocol = None
-        self.qos = False
+        self.QoS_support = False
         # Mutable available resources.
         # These will change as resources are virtually "consumed".
         self.total_capacity_gb = 0
         self.free_capacity_gb = None
         self.reserved_percentage = 0
-        self.reserved_snapshot_percentage = 0
-        self.reserved_share_extend_percentage = 0
-        self.allocated_capacity_gb = 0
-        # NOTE(xyang): The apparent allocated space indicating how much
-        # capacity has been provisioned. This could be the sum of sizes
-        # of all shares on a backend, which could be greater than or
-        # equal to the allocated_capacity_gb.
-        self.provisioned_capacity_gb = 0
-        self.max_over_subscription_ratio = 1.0
-        self.thin_provisioning = False
         self.driver_handles_share_servers = False
-        self.snapshot_support = True
-        self.create_share_from_snapshot_support = True
-        self.revert_to_snapshot_support = False
-        self.mount_snapshot_support = False
-        self.dedupe = False
-        self.compression = False
-        self.replication_type = None
-        self.replication_domain = None
-        self.ipv4_support = None
-        self.ipv6_support = None
-        self.security_service_update_support = False
-        self.network_allocation_update_support = False
-        self.share_server_multiple_subnet_support = False
-        self.mount_point_name_support = False
-        self.share_replicas_migration_support = False
-        self.encryption_support = None
 
         # PoolState for all pools
         self.pools = {}
         self.updated = None
 
-        # Share Group capabilities
-        self.sg_consistent_snapshot_support = None
-
     def update_capabilities(self, capabilities=None, service=None):
         # Read-only capability dicts
 
@@ -180,56 +124,50 @@ class HostState(object):
             service = {}
         self.service = ReadOnlyDict(service)
 
-    def update_from_share_capability(
-            self, capability, service=None, context=None):
+    def update_from_share_capability(self, capability, service=None):
         """Update information about a host from its share_node info.
 
         'capability' is the status info reported by share backend, a typical
-        capability looks like this::
+        capability looks like this:
 
-            capability = {
-                'share_backend_name': 'Local NFS',    #\
-                'vendor_name': 'OpenStack',           #  backend level
-                'driver_version': '1.0',              #  mandatory/fixed
-                'storage_protocol': 'NFS',            #/ stats&capabilities
+        capability = {
+            'share_backend_name': 'Local NFS',    #\
+            'vendor_name': 'OpenStack',           #  backend level
+            'driver_version': '1.0',              #  mandatory/fixed
+            'storage_protocol': 'NFS',            #/ stats&capabilities
 
-                'active_shares': 10,                  #\
-                'IOPS_provisioned': 30000,            #  optional custom
-                'fancy_capability_1': 'eat',          #  stats & capabilities
-                'fancy_capability_2': 'drink',        #/
+            'active_shares': 10,                  #\
+            'IOPS_provisioned': 30000,            #  optional custom
+            'fancy_capability_1': 'eat',          #  stats & capabilities
+            'fancy_capability_2': 'drink',        #/
 
-                'pools':[
-                  {
-                     'pool_name': '1st pool',               #\
-                     'total_capacity_gb': 500,              #  mandatory stats
-                     'free_capacity_gb': 230,               #   for pools
-                     'allocated_capacity_gb': 270,          # |
-                     'qos': 'False',                        # |
-                     'reserved_percentage': 0,              # |
-                     'reserved_snapshot_percentage': 0,     # |
-                     'reserved_share_extend_percentage': 0, #/
+            'pools': [
+                {'pool_name': '1st pool',         #\
+                 'total_capacity_gb': 500,        #  mandatory stats for
+                 'free_capacity_gb': 230,         #  pools
+                 'allocated_capacity_gb': 270,    # |
+                 'QoS_support': 'False',          # |
+                 'reserved_percentage': 0,        #/
 
-                     'dying_disks': 100,              #\
-                     'super_hero_1': 'spider-man',    #  optional custom
-                     'super_hero_2': 'flash',         #  stats &
-                     'super_hero_3': 'neoncat',       #  capabilities
-                     'super_hero_4': 'green lantern', #/
-                   },
-                  {
-                     'pool_name': '2nd pool',
-                     'total_capacity_gb': 1024,
-                     'free_capacity_gb': 1024,
-                     'allocated_capacity_gb': 0,
-                     'qos': 'False',
-                     'reserved_percentage': 0,
-                     'reserved_snapshot_percentage': 0,
-                     'reserved_share_extend_percentage': 0,
+                 'dying_disks': 100,              #\
+                 'super_hero_1': 'spider-man',    #  optional custom
+                 'super_hero_2': 'flash',         #  stats & capabilities
+                 'super_hero_3': 'neoncat'        #/
+                 },
+                {'pool_name': '2nd pool',
+                 'total_capacity_gb': 1024,
+                 'free_capacity_gb': 1024,
+                 'allocated_capacity_gb': 0,
+                 'QoS_support': 'False',
+                 'reserved_percentage': 0,
 
-                     'dying_disks': 200,
-                     'super_hero_1': 'superman',
-                     'super_hero_2': 'Hulk',
-                  }]
-            }
+                 'dying_disks': 200,
+                 'super_hero_1': 'superman',
+                 'super_hero_2': ' ',
+                 'super_hero_2': 'Hulk',
+                 }
+            ]
+        }
         """
         self.update_capabilities(capability, service)
 
@@ -241,9 +179,9 @@ class HostState(object):
             self.update_backend(capability)
 
             # Update pool level info
-            self.update_pools(capability, service, context=context)
+            self.update_pools(capability, service)
 
-    def update_pools(self, capability, service, context=None):
+    def update_pools(self, capability, service):
         """Update storage pools information from backend reported info."""
         if not capability:
             return
@@ -261,8 +199,7 @@ class HostState(object):
                     # Add new pool
                     cur_pool = PoolState(self.host, pool_cap, pool_name)
                     self.pools[pool_name] = cur_pool
-                cur_pool.update_from_share_capability(
-                    pool_cap, service, context=context)
+                cur_pool.update_from_share_capability(pool_cap, service)
 
                 active_pools.add(pool_name)
         elif pools is None:
@@ -289,8 +226,7 @@ class HostState(object):
                     self._append_backend_info(capability)
                     self.pools[pool_name] = single_pool
 
-            single_pool.update_from_share_capability(
-                capability, service, context=context)
+            single_pool.update_from_share_capability(capability, service)
             active_pools.add(pool_name)
 
         # Remove non-active pools from self.pools
@@ -321,65 +257,9 @@ class HostState(object):
         if not pool_cap.get('storage_protocol'):
             pool_cap['storage_protocol'] = self.storage_protocol
 
-        if 'driver_handles_share_servers' not in pool_cap:
-            pool_cap['driver_handles_share_servers'] = (
-                self.driver_handles_share_servers)
-
-        if 'snapshot_support' not in pool_cap:
-            pool_cap['snapshot_support'] = self.snapshot_support
-
-        if 'create_share_from_snapshot_support' not in pool_cap:
-            pool_cap['create_share_from_snapshot_support'] = (
-                self.create_share_from_snapshot_support)
-
-        if 'revert_to_snapshot_support' not in pool_cap:
-            pool_cap['revert_to_snapshot_support'] = (
-                self.revert_to_snapshot_support)
-
-        if 'mount_snapshot_support' not in pool_cap:
-            pool_cap['mount_snapshot_support'] = self.mount_snapshot_support
-
-        if 'dedupe' not in pool_cap:
-            pool_cap['dedupe'] = self.dedupe
-
-        if 'compression' not in pool_cap:
-            pool_cap['compression'] = self.compression
-
-        if not pool_cap.get('replication_type'):
-            pool_cap['replication_type'] = self.replication_type
-
-        if not pool_cap.get('replication_domain'):
-            pool_cap['replication_domain'] = self.replication_domain
-
-        if 'sg_consistent_snapshot_support' not in pool_cap:
-            pool_cap['sg_consistent_snapshot_support'] = (
-                self.sg_consistent_snapshot_support)
-
-        if 'security_service_update_support' not in pool_cap:
-            pool_cap['security_service_update_support'] = (
-                self.security_service_update_support)
-
-        if 'network_allocation_update_support' not in pool_cap:
-            pool_cap['network_allocation_update_support'] = (
-                self.network_allocation_update_support)
-
-        if 'share_server_multiple_subnet_support' not in pool_cap:
-            pool_cap['share_server_multiple_subnet_support'] = (
-                self.share_server_multiple_subnet_support)
-
-        if 'share_replicas_migration_support' not in pool_cap:
-            pool_cap['share_replicas_migration_support'] = (
-                self.share_replicas_migration_support)
-
-        if 'encryption_support' not in pool_cap:
-            pool_cap['encryption_support'] = (
-                self.encryption_support)
-
-        if self.ipv4_support is not None:
-            pool_cap['ipv4_support'] = self.ipv4_support
-
-        if self.ipv6_support is not None:
-            pool_cap['ipv6_support'] = self.ipv6_support
+        if not pool_cap.get('driver_handles_share_servers'):
+            pool_cap['driver_handles_share_servers'] = \
+                self.driver_handles_share_servers
 
     def update_backend(self, capability):
         self.share_backend_name = capability.get('share_backend_name')
@@ -388,48 +268,19 @@ class HostState(object):
         self.storage_protocol = capability.get('storage_protocol')
         self.driver_handles_share_servers = capability.get(
             'driver_handles_share_servers')
-        self.snapshot_support = capability.get('snapshot_support')
-        self.create_share_from_snapshot_support = capability.get(
-            'create_share_from_snapshot_support')
-        self.revert_to_snapshot_support = capability.get(
-            'revert_to_snapshot_support', False)
-        self.mount_snapshot_support = capability.get(
-            'mount_snapshot_support', False)
         self.updated = capability['timestamp']
-        self.replication_type = capability.get('replication_type')
-        self.replication_domain = capability.get('replication_domain')
-        self.sg_consistent_snapshot_support = capability.get(
-            'share_group_stats', {}).get('consistent_snapshot_support')
-        if capability.get('ipv4_support') is not None:
-            self.ipv4_support = capability['ipv4_support']
-        if capability.get('ipv6_support') is not None:
-            self.ipv6_support = capability['ipv6_support']
-        self.security_service_update_support = capability.get(
-            'security_service_update_support', False)
-        self.network_allocation_update_support = capability.get(
-            'network_allocation_update_support', False)
-        self.share_server_multiple_subnet_support = capability.get(
-            'share_server_multiple_subnet_support', False)
-        self.share_replicas_migration_support = capability.get(
-            'share_replicas_migration_support', False)
-        self.encryption_support = capability.get('encryption_support', None)
 
     def consume_from_share(self, share):
         """Incrementally update host state from an share."""
-        if self.provisioned_capacity_gb is not None:
-            self.provisioned_capacity_gb += share['size']
-
-        self.allocated_capacity_gb += share['size']
-
-        if (isinstance(self.free_capacity_gb, str)
-                and self.free_capacity_gb != 'unknown'):
-            raise exception.InvalidCapacity(
-                name='free_capacity_gb',
-                value=self.free_capacity_gb
-            )
-
-        if self.free_capacity_gb != 'unknown':
-            self.free_capacity_gb -= share['size']
+        share_gb = share['size']
+        if self.free_capacity_gb == 'infinite':
+            # There's virtually infinite space on back-end
+            pass
+        elif self.free_capacity_gb == 'unknown':
+            # Unable to determine the actual free space on back-end
+            pass
+        else:
+            self.free_capacity_gb -= share_gb
         self.updated = timeutils.utcnow()
 
     def __repr__(self):
@@ -441,7 +292,6 @@ class HostState(object):
 
 
 class PoolState(HostState):
-
     def __init__(self, host, capabilities, pool_name):
         new_host = share_utils.append_host(host, pool_name)
         super(PoolState, self).__init__(new_host, capabilities)
@@ -449,13 +299,7 @@ class PoolState(HostState):
         # No pools in pool
         self.pools = None
 
-    def _estimate_provisioned_capacity(self, host_name, context=None):
-        """Estimate provisioned capacity from share sizes on backend."""
-        return db.share_instance_sizes_sum_by_host(context, host_name)
-
-    @utils.synchronized("update_from_share_capability")
-    def update_from_share_capability(
-            self, capability, service=None, context=None):
+    def update_from_share_capability(self, capability, service=None):
         """Update information about a pool from its share_node info."""
         self.update_capabilities(capability, service)
         if capability:
@@ -467,54 +311,8 @@ class PoolState(HostState):
             self.free_capacity_gb = capability['free_capacity_gb']
             self.allocated_capacity_gb = capability.get(
                 'allocated_capacity_gb', 0)
-            self.qos = capability.get('qos', False)
+            self.QoS_support = capability.get('QoS_support', False)
             self.reserved_percentage = capability['reserved_percentage']
-            self.reserved_snapshot_percentage = (
-                capability['reserved_snapshot_percentage'])
-            self.reserved_share_extend_percentage = (
-                capability['reserved_share_extend_percentage'])
-            self.thin_provisioning = scheduler_utils.thin_provisioning(
-                capability.get('thin_provisioning', False))
-            # NOTE(xyang): provisioned_capacity_gb is the apparent total
-            # capacity of all the shares created on a backend, which is
-            # greater than or equal to allocated_capacity_gb, which is the
-            # apparent total capacity of all the shares created on a backend
-            # in Manila.
-            # NOTE(nidhimittalhada): If 'provisioned_capacity_gb' is not set,
-            # then calculating 'provisioned_capacity_gb' from share sizes
-            # on host, as per information available in manila database.
-            # NOTE(jose-castro-leon): Only calculate provisioned_capacity_gb
-            # on thin provisioned pools
-            self.provisioned_capacity_gb = capability.get(
-                'provisioned_capacity_gb')
-
-            if self.thin_provisioning and self.provisioned_capacity_gb is None:
-                self.provisioned_capacity_gb = (
-                    self._estimate_provisioned_capacity(self.host,
-                                                        context=context))
-
-            self.max_over_subscription_ratio = capability.get(
-                'max_over_subscription_ratio',
-                CONF.max_over_subscription_ratio)
-            self.dedupe = capability.get(
-                'dedupe', False)
-            self.compression = capability.get(
-                'compression', False)
-            self.replication_type = capability.get(
-                'replication_type', self.replication_type)
-            self.replication_domain = capability.get(
-                'replication_domain')
-            self.sg_consistent_snapshot_support = capability.get(
-                'sg_consistent_snapshot_support')
-            self.security_service_update_support = capability.get(
-                'security_service_update_support', False)
-            self.network_allocation_update_support = capability.get(
-                'network_allocation_update_support', False)
-            self.share_server_multiple_subnet_support = capability.get(
-                'share_server_multiple_subnet_support', False)
-            self.share_replicas_migration_support = capability.get(
-                'share_replicas_migration_support', False)
-            self.encryption_support = capability.get('encryption_support')
 
     def update_pools(self, capability):
         # Do nothing, since we don't have pools within pool, yet
@@ -529,11 +327,11 @@ class HostManager(object):
     def __init__(self):
         self.service_states = {}  # { <host>: {<service>: {cap k : v}}}
         self.host_state_map = {}
-        self.filter_handler = base_host_filter.HostFilterHandler(
-            'manila.scheduler.filters')
+        self.filter_handler = filters.HostFilterHandler('manila.scheduler.'
+                                                        'filters')
         self.filter_classes = self.filter_handler.get_all_classes()
-        self.weight_handler = base_host_weigher.HostWeightHandler(
-            'manila.scheduler.weighers')
+        self.weight_handler = weights.HostWeightHandler('manila.scheduler.'
+                                                        'weights')
         self.weight_classes = self.weight_handler.get_all_classes()
 
     def _choose_host_filters(self, filter_cls_names):
@@ -605,16 +403,11 @@ class HostManager(object):
                           weigher_class_names=None):
         """Weigh the hosts."""
         weigher_classes = self._choose_host_weighers(weigher_class_names)
-        weight_properties['server_pools_mapping'] = {}
-        for backend, info in self.service_states.items():
-            weight_properties['server_pools_mapping'].update(
-                info.get('server_pools_mapping', {}))
         return self.weight_handler.get_weighed_objects(weigher_classes,
                                                        hosts,
                                                        weight_properties)
 
-    def update_service_capabilities(self, service_name, host,
-                                    capabilities, timestamp):
+    def update_service_capabilities(self, service_name, host, capabilities):
         """Update the per-service capabilities based on this notification."""
         if service_name not in ('share',):
             LOG.debug('Ignoring %(service_name)s service update '
@@ -624,40 +417,29 @@ class HostManager(object):
 
         # Copy the capabilities, so we don't modify the original dict
         capability_copy = dict(capabilities)
-        timestamp = timestamp or timeutils.utcnow()
-        capability_copy["timestamp"] = timestamp  # Reported time
-
-        capab_old = self.service_states.get(host, {"timestamp": 0})
-        # Ignore older updates
-        if capab_old['timestamp'] and timestamp < capab_old['timestamp']:
-            LOG.info('Ignoring old capability report from %s.', host)
-            return
-
+        capability_copy["timestamp"] = timeutils.utcnow()  # Reported time
         self.service_states[host] = capability_copy
 
         LOG.debug("Received %(service_name)s service update from "
-                  "%(host)s: %(cap)s",
+                  "%(host)s: %(cap)s" %
                   {'service_name': service_name, 'host': host,
                    'cap': capabilities})
 
-    def _update_host_state_map(self, context, consider_disabled=False):
+    def _update_host_state_map(self, context):
+
         # Get resource usage across the available share nodes:
         topic = CONF.share_topic
-        share_services = db.service_get_all_by_topic(
-            context,
-            topic,
-            consider_disabled=consider_disabled,
-        )
+        share_services = db.service_get_all_by_topic(context, topic)
 
-        active_hosts = set()
         for service in share_services:
             host = service['host']
 
             # Warn about down services and remove them from host_state_map
-            is_down = not utils.service_is_up(service)
-            is_disabled = (not consider_disabled and service['disabled'])
-            if is_down or is_disabled:
-                LOG.warning("Share service is down. (host: %s).", host)
+            if not utils.service_is_up(service) or service['disabled']:
+                LOG.warn(_LW("Share service is down. (host: %s)") % host)
+                if self.host_state_map.pop(host, None):
+                    LOG.info(_LI("Removing non-active host: %s from "
+                                 "scheduler cache.") % host)
                 continue
 
             # Create and register host_state if not in host_state_map
@@ -667,22 +449,14 @@ class HostManager(object):
                 host_state = self.host_state_cls(
                     host,
                     capabilities=capabilities,
-                    service=dict(service.items()))
+                    service=dict(six.iteritems(service)))
                 self.host_state_map[host] = host_state
 
             # Update capabilities and attributes in host_state
             host_state.update_from_share_capability(
-                capabilities, service=dict(service.items()), context=context)
-            active_hosts.add(host)
+                capabilities, service=dict(six.iteritems(service)))
 
-        # remove non-active hosts from host_state_map
-        nonactive_hosts = set(self.host_state_map.keys()) - active_hosts
-        for host in nonactive_hosts:
-            LOG.info("Removing non-active host: %(host)s from "
-                     "scheduler cache.", {'host': host})
-            self.host_state_map.pop(host, None)
-
-    def get_all_host_states_share(self, context, consider_disabled=False):
+    def get_all_host_states_share(self, context):
         """Returns a dict of all the hosts the HostManager knows about.
 
         Each of the consumable resources in HostState are
@@ -692,10 +466,7 @@ class HostManager(object):
           {'192.168.1.100': HostState(), ...}
         """
 
-        self._update_host_state_map(
-            context,
-            consider_disabled=consider_disabled,
-        )
+        self._update_host_state_map(context)
 
         # Build a pool_state map and return that map instead of host_state_map
         all_pools = {}
@@ -706,12 +477,12 @@ class HostManager(object):
                 pool_key = '.'.join([host, pool.pool_name])
                 all_pools[pool_key] = pool
 
-        return all_pools.values()
+        return six.itervalues(all_pools)
 
-    def get_pools(self, context, filters=None, cached=False):
+    def get_pools(self, context, filters=None):
         """Returns a dict of all pools on all hosts HostManager knows about."""
-        if not cached or not self.host_state_map:
-            self._update_host_state_map(context)
+
+        self._update_host_state_map(context)
 
         all_pools = []
         for host, host_state in self.host_state_map.items():
@@ -721,9 +492,9 @@ class HostManager(object):
                     host, pool.pool_name)
                 host_name = share_utils.extract_host(
                     fully_qualified_pool_name, level='host')
-                backend_name = (share_utils.extract_host(
-                    fully_qualified_pool_name, level='backend').split('@')[1]
-                    if '@' in fully_qualified_pool_name else None)
+                backend_name = share_utils.extract_host(
+                    fully_qualified_pool_name, level='backend').split('@')[1] \
+                    if '@' in fully_qualified_pool_name else None
                 pool_name = share_utils.extract_host(
                     fully_qualified_pool_name, level='pool')
 
@@ -752,14 +523,10 @@ class HostManager(object):
         if not filter_dict:
             return True
 
-        for filter_key, filter_value in filter_dict.items():
+        for filter_key, filter_value in six.iteritems(filter_dict):
             if filter_key not in dict_to_check:
                 return False
-            if filter_key == 'capabilities':
-                if not scheduler_utils.capabilities_satisfied(
-                        dict_to_check.get(filter_key), filter_value):
-                    return False
-            elif not re.match(filter_value, dict_to_check.get(filter_key)):
+            if not re.match(filter_value, dict_to_check.get(filter_key)):
                 return False
 
         return True
