@@ -12,12 +12,10 @@
 #    WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
 #    License for the specific language governing permissions and limitations
 #    under the License.
-
 import types
 
 from oslo_config import cfg
 from oslo_log import log
-from oslo_utils import fnmatch
 from oslo_utils import timeutils
 
 CONF = cfg.CONF
@@ -43,7 +41,7 @@ def log_enter_exit(func):
         return func
 
     def inner(self, *args, **kwargs):
-        LOG.debug("Entering %(cls)s.%(method)s.",
+        LOG.debug("Entering %(cls)s.%(method)s",
                   {'cls': self.__class__.__name__,
                    'method': func.__name__})
         start = timeutils.utcnow()
@@ -51,7 +49,7 @@ def log_enter_exit(func):
         end = timeutils.utcnow()
         LOG.debug("Exiting %(cls)s.%(method)s. "
                   "Spent %(duration)s sec. "
-                  "Return %(return)s.",
+                  "Return %(return)s",
                   {'cls': self.__class__.__name__,
                    'duration': timeutils.delta_seconds(start, end),
                    'method': func.__name__,
@@ -59,25 +57,3 @@ def log_enter_exit(func):
         return ret
 
     return inner
-
-
-def do_match_any(full, matcher_list):
-    """Finds items that match any of the matchers.
-
-    :param full: Full item list
-    :param matcher_list: The list of matchers. Each matcher supports
-                         Unix shell-style wildcards
-    :return: The matched items set and the unmatched items set
-    """
-    matched = set()
-    not_matched = set()
-
-    full = set([item.strip() for item in full])
-    matcher_list = set([item.strip() for item in matcher_list])
-
-    for matcher in matcher_list:
-        for item in full:
-            if fnmatch.fnmatchcase(item, matcher):
-                matched.add(item)
-    not_matched = full - matched
-    return matched, not_matched
