@@ -17,7 +17,7 @@
 
 Manila share is a directory in HDFS. And this share does not use
 service VM instance (share server). The instance directly talks
-to the HDFS cluster.
+to the the HDFS cluster.
 
 The initial version only supports single namenode and flat network.
 
@@ -32,34 +32,37 @@ import socket
 
 from oslo_concurrency import processutils
 from oslo_config import cfg
-from oslo_log import log
 from oslo_utils import units
+import six
 
 from manila import exception
 from manila.i18n import _
+from manila.openstack.common import log as logging
 from manila.share import driver
-from manila import ssh_utils
 from manila import utils
 
-LOG = log.getLogger(__name__)
+LOG = logging.getLogger(__name__)
 
 hdfs_native_share_opts = [
-    cfg.HostAddressOpt('hdfs_namenode_ip',
-                       help='The IP of the HDFS namenode.'),
-    cfg.PortOpt('hdfs_namenode_port',
-                default=9000,
-                help='The port of HDFS namenode service.'),
-    cfg.PortOpt('hdfs_ssh_port',
-                default=22,
-                help='HDFS namenode SSH port.'),
+    cfg.StrOpt('hdfs_namenode_ip',
+               default=None,
+               help='The IP of the HDFS namenode.'),
+    cfg.IntOpt('hdfs_namenode_port',
+               default=9000,
+               help='The port of HDFS namenode service.'),
+    cfg.IntOpt('hdfs_ssh_port',
+               default=22,
+               help='HDFS namenode SSH port.'),
     cfg.StrOpt('hdfs_ssh_name',
+               default=None,
                help='HDFS namenode ssh login name.'),
     cfg.StrOpt('hdfs_ssh_pw',
-               secret=True,
+               default=None,
                help='HDFS namenode SSH login password, '
                     'This parameter is not necessary, if '
                     '\'hdfs_ssh_private_key\' is configured.'),
     cfg.StrOpt('hdfs_ssh_private_key',
+               default=None,
                help='Path to HDFS namenode SSH private '
                     'key for login.'),
 ]
@@ -77,8 +80,9 @@ class HDFSNativeShareDriver(driver.ExecuteMixin, driver.ShareDriver):
         1.0 - Initial Version
     """
 
-    def __init__(self, *args, **kwargs):
+    def __init__(self, db, *args, **kwargs):
         super(HDFSNativeShareDriver, self).__init__(False, *args, **kwargs)
+        self.db = db
         self.configuration.append_config_values(hdfs_native_share_opts)
         self.backend_name = self.configuration.safe_get(
             'share_backend_name') or 'HDFS-Native'
@@ -97,14 +101,14 @@ class HDFSNativeShareDriver(driver.ExecuteMixin, driver.ShareDriver):
         else:
             self._hdfs_execute = self._hdfs_remote_execute
 
-        self._hdfs_bin = 'hdfs'
+        self._hdfs_bin = self._get_hdfs_bin_path()
         self._hdfs_base_path = (
             'hdfs://' + self.configuration.hdfs_namenode_ip + ':'
-            + str(self.configuration.hdfs_namenode_port))
+            + six.text_type(self.configuration.hdfs_namenode_port))
 
     def _hdfs_local_execute(self, *cmd, **kwargs):
         if 'run_as_root' not in kwargs:
-            kwargs.update({'run_as_root': False})
+            kwargs.update({'run_as_root': True})
 
         return utils.execute(*cmd, **kwargs)
 
@@ -126,14 +130,14 @@ class HDFSNativeShareDriver(driver.ExecuteMixin, driver.ShareDriver):
             min_size = self.configuration.ssh_min_pool_conn
             max_size = self.configuration.ssh_max_pool_conn
 
-            ssh_pool = ssh_utils.SSHPool(host,
-                                         hdfs_ssh_port,
-                                         ssh_conn_timeout,
-                                         hdfs_ssh_name,
-                                         password=password,
-                                         privatekey=privatekey,
-                                         min_size=min_size,
-                                         max_size=max_size)
+            ssh_pool = utils.SSHPool(host,
+                                     hdfs_ssh_port,
+                                     ssh_conn_timeout,
+                                     hdfs_ssh_name,
+                                     password=password,
+                                     privatekey=privatekey,
+                                     min_size=min_size,
+                                     max_size=max_size)
             ssh = ssh_pool.create()
             self.ssh_connections[host] = (ssh_pool, ssh)
         else:
@@ -152,26 +156,25 @@ class HDFSNativeShareDriver(driver.ExecuteMixin, driver.ShareDriver):
         except Exception as e:
             msg = (_('Error running SSH command: %(cmd)s. '
                      'Error: %(excmsg)s.') %
-                   {'cmd': command, 'excmsg': str(e)})
+                   {'cmd': command, 'excmsg': six.text_type(e)})
             LOG.error(msg)
             raise exception.HDFSException(msg)
 
-    def _set_share_size(self, share, size=None):
-        share_dir = '/' + share['name']
-
-        if not size:
-            sizestr = str(share['size']) + 'g'
-        else:
-            sizestr = str(size) + 'g'
-
+    def _get_hdfs_bin_path(self):
         try:
-            self._hdfs_execute(self._hdfs_bin, 'dfsadmin',
-                               '-setSpaceQuota', sizestr, share_dir)
+            (out, __) = self._hdfs_execute('locate', '/bin/hdfs')
         except exception.ProcessExecutionError as e:
-            msg = (_('Failed to set space quota for the '
-                     'share %(sharename)s. Error: %(excmsg)s.') %
-                   {'sharename': share['name'],
-                    'excmsg': str(e)})
+            msg = (_('Can not get the execution path of hdfs. '
+                     'Error: %(excmsg)s.') %
+                   {'excmsg': six.text_type(e)})
+            LOG.error(msg)
+            raise exception.HDFSException(msg)
+
+        lines = out.splitlines()
+        if lines and lines[0].endswith('/bin/hdfs'):
+            return lines[0]
+        else:
+            msg = _('Can not get the execution path of hdfs.')
             LOG.error(msg)
             raise exception.HDFSException(msg)
 
@@ -183,6 +186,7 @@ class HDFSNativeShareDriver(driver.ExecuteMixin, driver.ShareDriver):
             raise exception.HDFSException(msg)
 
         share_dir = '/' + share['name']
+        sizestr = six.text_type(share['size']) + 'g'
 
         try:
             self._hdfs_execute(self._hdfs_bin, 'dfs',
@@ -191,12 +195,20 @@ class HDFSNativeShareDriver(driver.ExecuteMixin, driver.ShareDriver):
             msg = (_('Failed to create directory in hdfs for the '
                      'share %(sharename)s. Error: %(excmsg)s.') %
                    {'sharename': share['name'],
-                    'excmsg': str(e)})
+                    'excmsg': six.text_type(e)})
             LOG.error(msg)
             raise exception.HDFSException(msg)
 
-        # set share size
-        self._set_share_size(share)
+        try:
+            self._hdfs_execute(self._hdfs_bin, 'dfsadmin',
+                               '-setSpaceQuota', sizestr, share_dir)
+        except exception.ProcessExecutionError as e:
+            msg = (_('Failed to set space quota for the '
+                     'share %(sharename)s. Error: %(excmsg)s.') %
+                   {'sharename': share['name'],
+                    'excmsg': six.text_type(e)})
+            LOG.error(msg)
+            raise exception.HDFSException(msg)
 
         try:
             self._hdfs_execute(self._hdfs_bin, 'dfsadmin',
@@ -205,7 +217,7 @@ class HDFSNativeShareDriver(driver.ExecuteMixin, driver.ShareDriver):
             msg = (_('Failed to allow snapshot for the '
                      'share %(sharename)s. Error: %(excmsg)s.') %
                    {'sharename': share['name'],
-                    'excmsg': str(e)})
+                    'excmsg': six.text_type(e)})
             LOG.error(msg)
             raise exception.HDFSException(msg)
 
@@ -228,31 +240,22 @@ class HDFSNativeShareDriver(driver.ExecuteMixin, driver.ShareDriver):
         return self._get_share_path(share)
 
     def create_share_from_snapshot(self, context, share, snapshot,
-                                   share_server=None, parent_share=None):
+                                   share_server=None):
         """Creates a snapshot."""
         self._create_share(share)
         share_path = '/' + share['name']
         snapshot_path = self._get_snapshot_path(snapshot)
 
+        cmd = [self._hdfs_bin, 'dfs', '-cp', '-r',
+               snapshot_path, share_path]
         try:
-            # check if the directory is empty
-            (out, __) = self._hdfs_execute(
-                self._hdfs_bin, 'dfs', '-ls', snapshot_path)
-            # only copy files when the snapshot directory is not empty
-            if out:
-                copy_path = snapshot_path + "/*"
-
-                cmd = [self._hdfs_bin, 'dfs', '-cp',
-                       copy_path, share_path]
-
-                self._hdfs_execute(*cmd)
-
+            self._hdfs_execute(*cmd)
         except exception.ProcessExecutionError as e:
             msg = (_('Failed to create share %(sharename)s from '
                      'snapshot %(snapshotname)s. Error: %(excmsg)s.') %
                    {'sharename': share['name'],
                     'snapshotname': snapshot['name'],
-                    'excmsg': str(e)})
+                    'excmsg': six.text_type(e)})
             LOG.error(msg)
             raise exception.HDFSException(msg)
 
@@ -272,7 +275,7 @@ class HDFSNativeShareDriver(driver.ExecuteMixin, driver.ShareDriver):
                      'the share %(sharename)s. Error: %(excmsg)s.') %
                    {'snapshotname': snapshot_name,
                     'sharename': snapshot['share_name'],
-                    'excmsg': str(e)})
+                    'excmsg': six.text_type(e)})
             LOG.error(msg)
             raise exception.HDFSException(msg)
 
@@ -287,7 +290,7 @@ class HDFSNativeShareDriver(driver.ExecuteMixin, driver.ShareDriver):
             msg = (_('Failed to delete share %(sharename)s. '
                      'Error: %(excmsg)s.') %
                    {'sharename': share['name'],
-                    'excmsg': str(e)})
+                    'excmsg': six.text_type(e)})
             LOG.error(msg)
             raise exception.HDFSException(msg)
 
@@ -303,7 +306,7 @@ class HDFSNativeShareDriver(driver.ExecuteMixin, driver.ShareDriver):
             msg = (_('Failed to delete snapshot %(snapshotname)s. '
                      'Error: %(excmsg)s.') %
                    {'snapshotname': snapshot['name'],
-                    'excmsg': str(e)})
+                    'excmsg': six.text_type(e)})
             LOG.error(msg)
             raise exception.HDFSException(msg)
 
@@ -344,7 +347,7 @@ class HDFSNativeShareDriver(driver.ExecuteMixin, driver.ShareDriver):
                      'Error: %(excmsg)s.') %
                    {'sharename': share['name'],
                     'username': access['access_to'],
-                    'excmsg': str(e)})
+                    'excmsg': six.text_type(e)})
             LOG.error(msg)
             raise exception.HDFSException(msg)
 
@@ -363,26 +366,28 @@ class HDFSNativeShareDriver(driver.ExecuteMixin, driver.ShareDriver):
                      'Error: %(excmsg)s.') %
                    {'sharename': share['name'],
                     'username': access['access_to'],
-                    'excmsg': str(e)})
+                    'excmsg': six.text_type(e)})
             LOG.error(msg)
             raise exception.HDFSException(msg)
 
-    def extend_share(self, share, new_size, share_server=None):
-        """Extend share storage."""
-        self._set_share_size(share, new_size)
-
     def _check_hdfs_state(self):
         try:
             (out, __) = self._hdfs_execute(self._hdfs_bin, 'fsck', '/')
         except exception.ProcessExecutionError as e:
-            msg = (_('Failed to check hdfs state. Error: %(excmsg)s.') %
-                   {'excmsg': str(e)})
+            msg = _('Failed to check the utility of hdfs.')
             LOG.error(msg)
             raise exception.HDFSException(msg)
-        if 'HEALTHY' in out:
-            return True
-        else:
+        lines = out.splitlines()
+        try:
+            hdfs_state = lines[1].split()[1]
+        except (IndexError, ValueError) as e:
+            msg = (_('Failed to check hdfs state. Error: %(excmsg)s.') %
+                   {'excmsg': six.text_type(e)})
+            LOG.error(msg)
+            raise exception.HDFSException(msg)
+        if hdfs_state.upper() != 'HEALTHY':
             return False
+        return True
 
     def check_for_setup_error(self):
         """Return an error if the prerequisites are met."""
@@ -406,7 +411,7 @@ class HDFSNativeShareDriver(driver.ExecuteMixin, driver.ShareDriver):
         except exception.ProcessExecutionError as e:
             msg = (_('Failed to check available capacity for hdfs.'
                      'Error: %(excmsg)s.') %
-                   {'excmsg': str(e)})
+                   {'excmsg': six.text_type(e)})
             LOG.error(msg)
             raise exception.HDFSException(msg)
 
@@ -417,7 +422,7 @@ class HDFSNativeShareDriver(driver.ExecuteMixin, driver.ShareDriver):
         except (IndexError, ValueError) as e:
             msg = (_('Failed to get hdfs capacity info. '
                      'Error: %(excmsg)s.') %
-                   {'excmsg': str(e)})
+                   {'excmsg': six.text_type(e)})
             LOG.error(msg)
             raise exception.HDFSException(msg)
         return total, free
@@ -428,13 +433,7 @@ class HDFSNativeShareDriver(driver.ExecuteMixin, driver.ShareDriver):
         data = dict(share_backend_name=self.backend_name,
                     storage_protocol='HDFS',
                     reserved_percentage=self.configuration.
-                    reserved_share_percentage,
-                    reserved_snapshot_percentage=self.configuration.
-                    reserved_share_from_snapshot_percentage
-                    or self.configuration.reserved_share_percentage,
-                    reserved_share_extend_percentage=self.configuration.
-                    reserved_share_extend_percentage
-                    or self.configuration.reserved_share_percentage)
+                    reserved_share_percentage)
 
         total, free = self._get_available_capacity()
 
