@@ -18,52 +18,26 @@ This 'mediator' de-couples the 3PAR focused client from the OpenStack focused
 driver.
 """
 
-from oslo_log import log
 from oslo_utils import importutils
 from oslo_utils import units
 import six
 
 from manila import exception
-from manila.i18n import _, _LI, _LW
+from manila.i18n import _
+from manila.openstack.common import log as logging
 
 hp3parclient = importutils.try_import("hp3parclient")
 if hp3parclient:
     from hp3parclient import file_client
 
 
-LOG = log.getLogger(__name__)
-MIN_CLIENT_VERSION = (3, 2, 1)
-MIN_SMB_CA_VERSION = (3, 2, 2)
+LOG = logging.getLogger(__name__)
 DENY = '-'
 ALLOW = '+'
-OPEN_STACK_MANILA = 'OpenStack Manila'
-FULL = 1
-THIN = 2
-DEDUPE = 6
-ENABLED = 1
-DISABLED = 2
-CACHE = 'cache'
-CONTINUOUS_AVAIL = 'continuous_avail'
-ACCESS_BASED_ENUM = 'access_based_enum'
-SMB_EXTRA_SPECS_MAP = {
-    CACHE: CACHE,
-    CONTINUOUS_AVAIL: 'ca',
-    ACCESS_BASED_ENUM: 'abe',
-}
+OPEN_STACK_MANILA_FSHARE = 'OpenStack Manila fshare'
 
 
 class HP3ParMediator(object):
-    """3PAR client-facing code for the 3PAR driver.
-
-    Version history:
-        1.0.00 - Begin Liberty development (post-Kilo)
-        1.0.01 - Report thin/dedup/hp_flash_cache capabilities
-        1.0.02 - Add share server/share network support
-        1.0.03 - Use hp3par prefix for share types and capabilities
-
-    """
-
-    VERSION = "1.0.03"
 
     def __init__(self, **kwargs):
 
@@ -80,28 +54,13 @@ class HP3ParMediator(object):
 
         self.ssh_conn_timeout = kwargs.get('ssh_conn_timeout')
         self._client = None
-        self.client_version = None
-
-    @staticmethod
-    def no_client():
-        return hp3parclient is None
 
     def do_setup(self):
 
-        if self.no_client():
+        if hp3parclient is None:
             msg = _('You must install hp3parclient before using the 3PAR '
                     'driver.')
-            LOG.error(msg)
-            raise exception.HP3ParInvalidClient(message=msg)
-
-        self.client_version = hp3parclient.version_tuple
-        if self.client_version < MIN_CLIENT_VERSION:
-            msg = (_('Invalid hp3parclient version found (%(found)s). '
-                     'Version %(minimum)s or greater required.') %
-                   {'found': '.'.join(map(six.text_type, self.client_version)),
-                    'minimum': '.'.join(map(six.text_type,
-                                            MIN_CLIENT_VERSION))})
-            LOG.error(msg)
+            LOG.exception(msg)
             raise exception.HP3ParInvalidClient(message=msg)
 
         try:
@@ -135,121 +94,30 @@ class HP3ParMediator(object):
             LOG.exception(msg)
             raise exception.ShareBackendException(message=msg)
 
-        LOG.info(_LI("HP3ParMediator %(version)s, "
-                     "hp3parclient %(client_version)s"),
-                 {"version": self.VERSION,
-                  "client_version": hp3parclient.get_version_string()})
-
-        try:
-            wsapi_version = self._client.getWsApiVersion()['build']
-            LOG.info(_LI("3PAR WSAPI %s"), wsapi_version)
-        except Exception as e:
-            msg = (_('Failed to get 3PAR WSAPI version: %s') %
-                   six.text_type(e))
-            LOG.exception(msg)
-            raise exception.ShareBackendException(message=msg)
-
         if self.hp3par_debug:
-            self._client.debug_rest(True)  # Includes SSH debug (setSSH above)
-
-    def _wsapi_login(self):
-        try:
-            self._client.login(self.hp3par_username, self.hp3par_password)
-        except Exception as e:
-            msg = (_("Failed to Login to 3PAR (%(url)s) as %(user)s "
-                     "because: %(err)s") %
-                   {'url': self.hp3par_api_url,
-                    'user': self.hp3par_username,
-                    'err': six.text_type(e)})
-            LOG.error(msg)
-            raise exception.ShareBackendException(msg=msg)
-
-    def _wsapi_logout(self):
-        try:
-            self._client.http.unauthenticate()
-        except Exception as e:
-            msg = _LW("Failed to Logout from 3PAR (%(url)s) because %(err)s")
-            LOG.warning(msg, {'url': self.hp3par_api_url,
-                              'err': six.text_type(e)})
-            # don't raise exception on logout()
-
-    def get_provisioned_gb(self, fpg):
-        total_mb = 0
-        try:
-            result = self._client.getfsquota(fpg=fpg)
-        except Exception as e:
-            result = {'message': six.text_type(e)}
-
-        error_msg = result.get('message')
-        if error_msg:
-            message = (_('Error while getting fsquotas for FPG '
-                         '%(fpg)s: %(msg)s') %
-                       {'fpg': fpg, 'msg': error_msg})
-            LOG.error(message)
-            raise exception.ShareBackendException(msg=message)
-
-        for fsquota in result['members']:
-            total_mb += float(fsquota['hardBlock'])
-        return total_mb / units.Ki
-
-    def get_fpg_status(self, fpg):
-        """Get capacity and capabilities for FPG."""
+            self._client.ssh.set_debug_flag(True)
 
+    def get_capacity(self, fpg):
         try:
             result = self._client.getfpg(fpg)
         except Exception as e:
             msg = (_('Failed to get capacity for fpg %(fpg)s: %(e)s') %
                    {'fpg': fpg, 'e': six.text_type(e)})
-            LOG.error(msg)
-            raise exception.ShareBackendException(msg=msg)
+            LOG.exception(msg)
+            raise exception.ShareBackendException(message=msg)
 
         if result['total'] != 1:
             msg = (_('Failed to get capacity for fpg %s.') % fpg)
-            LOG.error(msg)
-            raise exception.ShareBackendException(msg=msg)
-
-        member = result['members'][0]
-        total_capacity_gb = float(member['capacityKiB']) / units.Mi
-        free_capacity_gb = float(member['availCapacityKiB']) / units.Mi
-
-        volumes = member['vvs']
-        if isinstance(volumes, list):
-            volume = volumes[0]  # Use first name from list
+            LOG.exception(msg)
+            raise exception.ShareBackendException(message=msg)
         else:
-            volume = volumes  # There is just a name
-
-        self._wsapi_login()
-        try:
-            volume_info = self._client.getVolume(volume)
-            volume_set = self._client.getVolumeSet(fpg)
-        finally:
-            self._wsapi_logout()
-
-        provisioning_type = volume_info['provisioningType']
-        if provisioning_type not in (THIN, FULL, DEDUPE):
-            msg = (_('Unexpected provisioning type for FPG %(fpg)s: '
-                     '%(ptype)s.') % {'fpg': fpg, 'ptype': provisioning_type})
-            LOG.error(msg)
-            raise exception.ShareBackendException(msg=msg)
-
-        dedupe = provisioning_type == DEDUPE
-        thin_provisioning = provisioning_type in (THIN, DEDUPE)
-
-        flash_cache_policy = volume_set.get('flashCachePolicy', DISABLED)
-        hp3par_flash_cache = flash_cache_policy == ENABLED
-
-        status = {
-            'total_capacity_gb': total_capacity_gb,
-            'free_capacity_gb': free_capacity_gb,
-            'thin_provisioning': thin_provisioning,
-            'dedupe': dedupe,
-            'hp3par_flash_cache': hp3par_flash_cache,
-        }
-
-        if thin_provisioning:
-            status['provisioned_capacity_gb'] = self.get_provisioned_gb(fpg)
-
-        return status
+            member = result['members'][0]
+            total_capacity_gb = int(member['capacityKiB']) / units.Mi
+            free_capacity_gb = int(member['availCapacityKiB']) / units.Mi
+            return {
+                'total_capacity_gb': total_capacity_gb,
+                'free_capacity_gb': free_capacity_gb
+            }
 
     @staticmethod
     def ensure_supported_protocol(share_proto):
@@ -259,7 +127,7 @@ class HP3ParMediator(object):
         if protocol not in ['smb', 'nfs']:
             message = (_('Invalid protocol. Expected nfs or smb. Got %s.') %
                        protocol)
-            LOG.error(message)
+            LOG.exception(message)
             raise exception.InvalidInput(message)
         return protocol
 
@@ -279,71 +147,8 @@ class HP3ParMediator(object):
         else:
             return 'osf-%s' % uid
 
-    @staticmethod
-    def _get_nfs_options(extra_specs, readonly):
-        """Validate the NFS extra_specs and return the options to use."""
-
-        nfs_options = extra_specs.get('hp3par:nfs_options')
-        if nfs_options:
-            options = nfs_options.split(',')
-        else:
-            options = []
-
-        # rw, ro, and (no)root_squash (in)secure options are not allowed in
-        # extra_specs because they will be forcibly set below.
-        # no_subtree_check and fsid are not allowed per 3PAR support.
-        # Other strings will be allowed to be sent to the 3PAR which will do
-        # further validation.
-        options_not_allowed = ['ro', 'rw',
-                               'no_root_squash', 'root_squash',
-                               'secure', 'insecure',
-                               'no_subtree_check', 'fsid']
-
-        invalid_options = [
-            option for option in options if option in options_not_allowed
-        ]
-
-        if invalid_options:
-            raise exception.InvalidInput(_('Invalid hp3par:nfs_options in '
-                                           'extra-specs. The following '
-                                           'options are not allowed: %s') %
-                                         invalid_options)
-
-        options.append('ro' if readonly else 'rw')
-        options.append('no_root_squash')
-        options.append('insecure')
-
-        return ','.join(options)
-
-    def _build_createfshare_kwargs(self, protocol, fpg, fstore, readonly,
-                                   sharedir, extra_specs, comment):
-        createfshare_kwargs = dict(fpg=fpg,
-                                   fstore=fstore,
-                                   sharedir=sharedir,
-                                   comment=comment)
-        if protocol == 'nfs':
-            createfshare_kwargs['clientip'] = '127.0.0.1'
-            options = self._get_nfs_options(extra_specs, readonly)
-            createfshare_kwargs['options'] = options
-        else:
-            createfshare_kwargs['allowip'] = '127.0.0.1'
-
-            if self.client_version < MIN_SMB_CA_VERSION:
-                smb_opts = (ACCESS_BASED_ENUM, CACHE)
-            else:
-                smb_opts = (ACCESS_BASED_ENUM, CONTINUOUS_AVAIL, CACHE)
-
-            for smb_opt in smb_opts:
-                opt_value = extra_specs.get('hp3par:smb_%s' % smb_opt)
-                if opt_value:
-                    opt_key = SMB_EXTRA_SPECS_MAP[smb_opt]
-                    createfshare_kwargs[opt_key] = opt_value
-        return createfshare_kwargs
-
-    def create_share(self, project_id, share_id, share_proto, extra_specs,
-                     fpg, vfs,
-                     fstore=None, sharedir=None, readonly=False, size=None,
-                     comment=OPEN_STACK_MANILA):
+    def create_share(self, project_id, share_id, share_proto, fpg, vfs,
+                     fstore=None, sharedir=None, readonly=False, size=None):
         """Create the share and return its path.
 
         This method can create a share when called by the driver or when
@@ -353,7 +158,6 @@ class HP3ParMediator(object):
         :param project_id: The tenant ID.
         :param share_id: The share-id with or without osf- prefix.
         :param share_proto: The protocol (to map to smb or nfs)
-        :param extra_specs: The share type extra-specs
         :param fpg: The file provisioning group
         :param vfs:  The virtual file system
         :param fstore:  (optional) The file store.  When provided, an existing
@@ -367,32 +171,16 @@ class HP3ParMediator(object):
         protocol = self.ensure_supported_protocol(share_proto)
         share_name = self.ensure_prefix(share_id)
 
-        if not (sharedir or self.hp3par_fstore_per_share):
-            sharedir = share_name
-
-        if fstore:
-            use_existing_fstore = True
-        else:
-            use_existing_fstore = False
+        if not fstore:
             if self.hp3par_fstore_per_share:
                 fstore = share_name
             else:
                 fstore = self.ensure_prefix(project_id, protocol)
 
-        createfshare_kwargs = self._build_createfshare_kwargs(protocol,
-                                                              fpg,
-                                                              fstore,
-                                                              readonly,
-                                                              sharedir,
-                                                              extra_specs,
-                                                              comment)
-
-        if not use_existing_fstore:
-
             try:
                 result = self._client.createfstore(
                     vfs, fstore, fpg=fpg,
-                    comment=comment)
+                    comment='OpenStack Manila fstore')
                 LOG.debug("createfstore result=%s", result)
             except Exception as e:
                 msg = (_('Failed to create fstore %(fstore)s: %(e)s') %
@@ -428,13 +216,28 @@ class HP3ParMediator(object):
                     LOG.exception(msg)
                     raise exception.ShareBackendException(msg)
 
+        if not (sharedir or self.hp3par_fstore_per_share):
+            sharedir = share_name
+
         try:
+            if protocol == 'nfs':
+                if readonly:
+                    options = 'ro,no_root_squash,insecure'
+                else:
+                    options = 'rw,no_root_squash,insecure'
 
-            result = self._client.createfshare(protocol,
-                                               vfs,
-                                               share_name,
-                                               **createfshare_kwargs)
-
+                result = self._client.createfshare(
+                    protocol, vfs, share_name,
+                    fpg=fpg, fstore=fstore, sharedir=sharedir,
+                    clientip='127.0.0.1',
+                    options=options,
+                    comment=OPEN_STACK_MANILA_FSHARE)
+            else:
+                result = self._client.createfshare(
+                    protocol, vfs, share_name,
+                    fpg=fpg, fstore=fstore, sharedir=sharedir,
+                    allowip='127.0.0.1',
+                    comment=OPEN_STACK_MANILA_FSHARE)
             LOG.debug("createfshare result=%s", result)
 
         except Exception as e:
@@ -460,7 +263,7 @@ class HP3ParMediator(object):
             msg = (_('Failed to get fshare %(share_name)s after creating it. '
                      'Expected to get 1 fshare.  Got %(total)s.') %
                    {'share_name': share_name, 'total': result['total']})
-            LOG.error(msg)
+            LOG.exception(msg)
             raise exception.ShareBackendException(msg)
 
         if protocol == 'nfs':
@@ -468,10 +271,9 @@ class HP3ParMediator(object):
         else:
             return result['members'][0]['shareName']
 
-    def create_share_from_snapshot(self, share_id, share_proto, extra_specs,
+    def create_share_from_snapshot(self, share_id, share_proto,
                                    orig_project_id, orig_share_id, orig_proto,
-                                   snapshot_id, fpg, vfs,
-                                   comment=OPEN_STACK_MANILA):
+                                   snapshot_id, fpg, vfs):
 
         protocol = self.ensure_supported_protocol(share_proto)
         snapshot_tag = self.ensure_prefix(snapshot_id)
@@ -492,7 +294,7 @@ class HP3ParMediator(object):
                        'fpg': fpg,
                        'vfs': vfs,
                        'tag': snapshot_tag})
-            LOG.error(msg)
+            LOG.exception(msg)
             raise exception.ShareBackendException(msg)
 
         fstore = snapshot['fstoreName']
@@ -508,13 +310,11 @@ class HP3ParMediator(object):
             orig_project_id,
             share_name,
             protocol,
-            extra_specs,
             fpg,
             vfs,
             fstore=fstore,
             sharedir=sharedir,
             readonly=True,
-            comment=comment,
         )
 
     def delete_share(self, project_id, share_id, share_proto, fpg, vfs):
@@ -594,7 +394,7 @@ class HP3ParMediator(object):
             msg = (_('Failed to create snapshot for FPG/VFS/fshare '
                      '%(fpg)s/%(vfs)s/%(fshare)s: Failed to find fshare.') %
                    {'fpg': fpg, 'vfs': vfs, 'fshare': orig_share_id})
-            LOG.error(msg)
+            LOG.exception(msg)
             raise exception.ShareBackendException(msg)
 
         sharedir = fshare.get('shareDir')
@@ -603,7 +403,7 @@ class HP3ParMediator(object):
                      '%(fpg)s/%(vfs)s/%(fshare)s: Share is a read-only '
                      'share of an existing snapshot.') %
                    {'fpg': fpg, 'vfs': vfs, 'fshare': orig_share_id})
-            LOG.error(msg)
+            LOG.exception(msg)
             raise exception.ShareBackendException(msg)
 
         fstore = fshare.get('fstoreName')
@@ -702,13 +502,13 @@ class HP3ParMediator(object):
         if access_type not in ('ip', 'user'):
             msg = (_("Invalid access type.  Expected 'ip' or 'user'.  "
                      "Actual '%s'.") % access_type)
-            LOG.error(msg)
+            LOG.exception(msg)
             raise exception.InvalidInput(msg)
 
         if protocol == 'nfs' and access_type != 'ip':
             msg = (_("Invalid NFS access type.  HP 3PAR NFS supports 'ip'. "
                      "Actual '%s'.") % access_type)
-            LOG.error(msg)
+            LOG.exception(msg)
             raise exception.HP3ParInvalid(msg)
 
         return protocol
@@ -837,88 +637,3 @@ class HP3ParMediator(object):
 
         self._change_access(DENY, project_id, share_id, share_proto,
                             access_type, access_to, fpg, vfs)
-
-    def fsip_exists(self, fsip):
-        """Try to get FSIP. Return True if it exists."""
-
-        vfs = fsip['vfs']
-        fpg = fsip['fspool']
-
-        try:
-            result = self._client.getfsip(vfs, fpg=fpg)
-            LOG.debug("getfsip result: %s", result)
-        except Exception as e:
-            LOG.exception(e)
-            msg = (_('Failed to get FSIPs for FPG/VFS %(fspool)s/%(vfs)s.') %
-                   fsip)
-            LOG.exception(msg)
-            raise exception.ShareBackendException(msg=msg)
-
-        for member in result['members']:
-            if all(item in member.items() for item in fsip.items()):
-                return True
-
-        return False
-
-    def create_fsip(self, ip, subnet, vlantag, fpg, vfs):
-
-        vlantag_str = six.text_type(vlantag) if vlantag else '0'
-
-        # Try to create it. It's OK if it already exists.
-        try:
-            result = self._client.createfsip(ip,
-                                             subnet,
-                                             vfs,
-                                             fpg=fpg,
-                                             vlantag=vlantag_str)
-            LOG.debug("createfsip result: %s", result)
-
-        except Exception as e:
-            LOG.exception(e)
-            msg = (_('Failed to create FSIP for %s') % ip)
-            LOG.exception(msg)
-            raise exception.ShareBackendException(msg=msg)
-
-        # Verify that it really exists.
-        fsip = {
-            'fspool': fpg,
-            'vfs': vfs,
-            'address': ip,
-            'prefixLen': subnet,
-            'vlanTag': vlantag_str,
-        }
-        if not self.fsip_exists(fsip):
-            msg = (_('Failed to get FSIP after creating it for '
-                     'FPG/VFS/IP/subnet/VLAN '
-                     '%(fspool)s/%(vfs)s/'
-                     '%(address)s/%(prefixLen)s/%(vlanTag)s.') % fsip)
-            LOG.error(msg)
-            raise exception.ShareBackendException(msg=msg)
-
-    def remove_fsip(self, ip, fpg, vfs):
-
-        if not (vfs and ip):
-            # If there is no VFS and/or IP, then there is no FSIP to remove.
-            return
-
-        try:
-            result = self._client.removefsip(vfs, ip, fpg=fpg)
-            LOG.debug("removefsip result: %s", result)
-
-        except Exception as e:
-            LOG.exception(e)
-            msg = (_('Failed to remove FSIP %s') % ip)
-            LOG.exception(msg)
-            raise exception.ShareBackendException(msg=msg)
-
-        # Verify that it really no longer exists.
-        fsip = {
-            'fspool': fpg,
-            'vfs': vfs,
-            'address': ip,
-        }
-        if self.fsip_exists(fsip):
-            msg = (_('Failed to remove FSIP for FPG/VFS/IP '
-                     '%(fspool)s/%(vfs)s/%(address)s.') % fsip)
-            LOG.error(msg)
-            raise exception.ShareBackendException(msg=msg)
