@@ -1,26 +1,9 @@
-#    Licensed under the Apache License, Version 2.0 (the "License"); you may
-#    not use this file except in compliance with the License. You may obtain
-#    a copy of the License at
-#
-#         http://www.apache.org/licenses/LICENSE-2.0
-#
-#    Unless required by applicable law or agreed to in writing, software
-#    distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
-#    WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
-#    License for the specific language governing permissions and limitations
-#    under the License.
-
-import inspect
-from unittest import mock
-
 import ddt
+import inspect
 import webob
 
-from manila.api.openstack import api_version_request as api_version
 from manila.api.openstack import wsgi
-from manila import context
 from manila import exception
-from manila import policy
 from manila import test
 from manila.tests.api import fakes
 
@@ -29,13 +12,13 @@ from manila.tests.api import fakes
 class RequestTest(test.TestCase):
     def test_content_type_missing(self):
         request = wsgi.Request.blank('/tests/123', method='POST')
-        request.body = "<body />".encode("utf-8")
-        self.assertIsNone(request.get_content_type())
+        request.body = "<body />"
+        self.assertEqual(None, request.get_content_type())
 
     def test_content_type_unsupported(self):
         request = wsgi.Request.blank('/tests/123', method='POST')
         request.headers["Content-Type"] = "text/html"
-        request.body = "asdf<br />".encode("utf-8")
+        request.body = "asdf<br />"
         self.assertRaises(exception.InvalidContentType,
                           request.get_content_type)
 
@@ -43,7 +26,7 @@ class RequestTest(test.TestCase):
         request = wsgi.Request.blank('/tests/123')
         request.headers["Content-Type"] = "application/json; charset=UTF-8"
         result = request.get_content_type()
-        self.assertEqual("application/json", result)
+        self.assertEqual(result, "application/json")
 
     def test_content_type_from_accept(self):
         content_type = 'application/json'
@@ -52,34 +35,34 @@ class RequestTest(test.TestCase):
 
         result = request.best_match_content_type()
 
-        self.assertEqual(content_type, result)
+        self.assertEqual(result, content_type)
 
     def test_content_type_from_accept_best(self):
         request = wsgi.Request.blank('/tests/123')
         request.headers["Accept"] = "application/xml, application/json"
         result = request.best_match_content_type()
-        self.assertEqual("application/json", result)
+        self.assertEqual(result, "application/json")
 
         request = wsgi.Request.blank('/tests/123')
         request.headers["Accept"] = ("application/json; q=0.3, "
                                      "application/xml; q=0.9")
         result = request.best_match_content_type()
-        self.assertEqual("application/json", result)
+        self.assertEqual(result, "application/json")
 
     def test_content_type_from_query_extension(self):
         request = wsgi.Request.blank('/tests/123.json')
         result = request.best_match_content_type()
-        self.assertEqual("application/json", result)
+        self.assertEqual(result, "application/json")
 
         request = wsgi.Request.blank('/tests/123.invalid')
         result = request.best_match_content_type()
-        self.assertEqual("application/json", result)
+        self.assertEqual(result, "application/json")
 
     def test_content_type_accept_default(self):
         request = wsgi.Request.blank('/tests/123.unsupported')
         request.headers["Accept"] = "application/unsupported1"
         result = request.best_match_content_type()
-        self.assertEqual("application/json", result)
+        self.assertEqual(result, "application/json")
 
     def test_cache_and_retrieve_resources(self):
         request = wsgi.Request.blank('/foo')
@@ -142,133 +125,46 @@ class RequestTest(test.TestCase):
             {'id%s' % i: resources[i] for i in res_range},
             getattr(r, get_db_all_func)())
 
-    def test_set_api_version_request_exception(self):
-        min_version = api_version.APIVersionRequest('2.0')
-        max_version = api_version.APIVersionRequest('2.45')
-        self.mock_object(api_version, 'max_api_version',
-                         mock.Mock(return_value=max_version))
-        self.mock_object(api_version, 'min_api_version',
-                         mock.Mock(return_value=min_version))
-        headers = {'X-OpenStack-Manila-API-Version': '2.51'}
-        request = wsgi.Request.blank(
-            'https://openstack.acme.com/v2/shares', method='GET',
-            headers=headers, script_name='/v2/shares')
-
-        self.assertRaises(exception.InvalidGlobalAPIVersion,
-                          request.set_api_version_request)
-        self.assertEqual(api_version.APIVersionRequest('2.51'),
-                         request.api_version_request)
-
-    @ddt.data('', '/share', '/v1', '/v2/shares', '/v1.1/', '/share/v1',
-              '/shared-file-sytems/v2', '/share/v3.5/share-replicas',
-              '/shared-file-sytems/v2/shares/xyzzy/action')
-    def test_set_api_version_request(self, resource):
-        min_version = api_version.APIVersionRequest('2.0')
-        max_version = api_version.APIVersionRequest('3.0')
-        self.mock_object(api_version, 'max_api_version',
-                         mock.Mock(return_value=max_version))
-        self.mock_object(api_version, 'min_api_version',
-                         mock.Mock(return_value=min_version))
-        request = wsgi.Request.blank(
-            'https://openstack.acme.com%s' % resource, method='GET',
-            headers={'X-OpenStack-Manila-API-Version': '2.117'},
-            script_name=resource)
-
-        self.assertIsNone(request.set_api_version_request())
-
-        if not resource or not ('/v1' in resource or '/v2' in resource):
-            self.assertEqual(api_version.APIVersionRequest(),
-                             request.api_version_request)
-        elif 'v1' in resource:
-            self.assertEqual(api_version.APIVersionRequest('1.0'),
-                             request.api_version_request)
-        else:
-            self.assertEqual(api_version.APIVersionRequest('2.117'),
-                             request.api_version_request)
-
-    def test_set_api_version_request_no_version_header(self):
-        min_version = api_version.APIVersionRequest('2.0')
-        max_version = api_version.APIVersionRequest('2.45')
-        self.mock_object(api_version, 'max_api_version',
-                         mock.Mock(return_value=max_version))
-        self.mock_object(api_version, 'min_api_version',
-                         mock.Mock(return_value=min_version))
-        headers = {}
-        request = wsgi.Request.blank(
-            'https://openstack.acme.com/v2/shares', method='GET',
-            headers=headers, script_name='/v2/shares')
-
-        self.assertIsNone(request.set_api_version_request())
-
-        self.assertEqual(api_version.APIVersionRequest('2.0'),
-                         request.api_version_request)
-
-    @ddt.data(None, 'true', 'false')
-    def test_set_api_version_request_experimental_header(self, experimental):
-        min_version = api_version.APIVersionRequest('2.0')
-        max_version = api_version.APIVersionRequest('2.45')
-        self.mock_object(api_version, 'max_api_version',
-                         mock.Mock(return_value=max_version))
-        self.mock_object(api_version, 'min_api_version',
-                         mock.Mock(return_value=min_version))
-        headers = {'X-OpenStack-Manila-API-Version': '2.38'}
-        if experimental:
-            headers['X-OpenStack-Manila-API-Experimental'] = experimental
-        request = wsgi.Request.blank(
-            'https://openstack.acme.com/v2/shares', method='GET',
-            headers=headers, script_name='/v2/shares')
-
-        self.assertIsNone(request.set_api_version_request())
-
-        self.assertEqual(request.api_version_request,
-                         api_version.APIVersionRequest('2.38'))
-
-        expected_experimental = experimental == 'true' or False
-        self.assertEqual(expected_experimental,
-                         request.api_version_request.experimental)
-
 
 class ActionDispatcherTest(test.TestCase):
     def test_dispatch(self):
         serializer = wsgi.ActionDispatcher()
         serializer.create = lambda x: 'pants'
-        self.assertEqual('pants', serializer.dispatch({}, action='create'))
+        self.assertEqual(serializer.dispatch({}, action='create'), 'pants')
 
     def test_dispatch_action_None(self):
         serializer = wsgi.ActionDispatcher()
         serializer.create = lambda x: 'pants'
         serializer.default = lambda x: 'trousers'
-        self.assertEqual('trousers', serializer.dispatch({}, action=None))
+        self.assertEqual(serializer.dispatch({}, action=None), 'trousers')
 
     def test_dispatch_default(self):
         serializer = wsgi.ActionDispatcher()
         serializer.create = lambda x: 'pants'
         serializer.default = lambda x: 'trousers'
-        self.assertEqual('trousers', serializer.dispatch({}, action='update'))
+        self.assertEqual(serializer.dispatch({}, action='update'), 'trousers')
 
 
 class DictSerializerTest(test.TestCase):
     def test_dispatch_default(self):
         serializer = wsgi.DictSerializer()
-        self.assertEqual('', serializer.serialize({}, 'update'))
+        self.assertEqual(serializer.serialize({}, 'update'), '')
 
 
 class JSONDictSerializerTest(test.TestCase):
     def test_json(self):
         input_dict = dict(servers=dict(a=(2, 3)))
-        expected_json = '{"servers":{"a":[2,3]}}'.encode("utf-8")
+        expected_json = '{"servers":{"a":[2,3]}}'
         serializer = wsgi.JSONDictSerializer()
         result = serializer.serialize(input_dict)
-        result = result.replace(
-            '\n'.encode("utf-8"), ''.encode("utf-8")).replace(
-            ' '.encode("utf-8"), ''.encode("utf-8"))
-        self.assertEqual(expected_json, result)
+        result = result.replace('\n', '').replace(' ', '')
+        self.assertEqual(result, expected_json)
 
 
 class TextDeserializerTest(test.TestCase):
     def test_dispatch_default(self):
         deserializer = wsgi.TextDeserializer()
-        self.assertEqual({}, deserializer.deserialize({}, 'update'))
+        self.assertEqual(deserializer.deserialize({}, 'update'), {})
 
 
 class JSONDeserializerTest(test.TestCase):
@@ -291,7 +187,7 @@ class JSONDeserializerTest(test.TestCase):
             },
         }
         deserializer = wsgi.JSONDeserializer()
-        self.assertEqual(as_dict, deserializer.deserialize(data))
+        self.assertEqual(deserializer.deserialize(data), as_dict)
 
 
 class ResourceTest(test.TestCase):
@@ -303,8 +199,8 @@ class ResourceTest(test.TestCase):
         req = webob.Request.blank('/tests')
         app = fakes.TestRouter(Controller())
         response = req.get_response(app)
-        self.assertEqual('off'.encode("utf-8"), response.body)
-        self.assertEqual(200, response.status_int)
+        self.assertEqual(response.body, 'off')
+        self.assertEqual(response.status_int, 200)
 
     def test_resource_not_authorized(self):
         class Controller(object):
@@ -314,7 +210,7 @@ class ResourceTest(test.TestCase):
         req = webob.Request.blank('/tests')
         app = fakes.TestRouter(Controller())
         response = req.get_response(app)
-        self.assertEqual(403, response.status_int)
+        self.assertEqual(response.status_int, 403)
 
     def test_dispatch(self):
         class Controller(object):
@@ -326,7 +222,7 @@ class ResourceTest(test.TestCase):
         method, extensions = resource.get_method(None, 'index', None, '')
         actual = resource.dispatch(method, None, {'pants': 'off'})
         expected = 'off'
-        self.assertEqual(expected, actual)
+        self.assertEqual(actual, expected)
 
     def test_get_method_undefined_controller_action(self):
         class Controller(object):
@@ -375,7 +271,7 @@ class ResourceTest(test.TestCase):
                           '{"barAction": true}')
 
     def test_get_method_action_method(self):
-        class Controller(object):
+        class Controller():
             def action(self, req, pants=None):
                 return pants
 
@@ -405,7 +301,7 @@ class ResourceTest(test.TestCase):
 
         expected = {'action': 'update', 'id': 12}
 
-        self.assertEqual(expected, resource.get_action_args(env))
+        self.assertEqual(resource.get_action_args(env), expected)
 
     def test_get_body_bad_content(self):
         class Controller(object):
@@ -417,11 +313,11 @@ class ResourceTest(test.TestCase):
 
         request = wsgi.Request.blank('/', method='POST')
         request.headers['Content-Type'] = 'application/none'
-        request.body = 'foo'.encode("utf-8")
+        request.body = 'foo'
 
         content_type, body = resource.get_body(request)
-        self.assertIsNone(content_type)
-        self.assertEqual('', body)
+        self.assertEqual(content_type, None)
+        self.assertEqual(body, '')
 
     def test_get_body_no_content_type(self):
         class Controller(object):
@@ -432,11 +328,11 @@ class ResourceTest(test.TestCase):
         resource = wsgi.Resource(controller)
 
         request = wsgi.Request.blank('/', method='POST')
-        request.body = 'foo'.encode("utf-8")
+        request.body = 'foo'
 
         content_type, body = resource.get_body(request)
-        self.assertIsNone(content_type)
-        self.assertEqual('', body)
+        self.assertEqual(content_type, None)
+        self.assertEqual(body, '')
 
     def test_get_body_no_content_body(self):
         class Controller(object):
@@ -448,11 +344,11 @@ class ResourceTest(test.TestCase):
 
         request = wsgi.Request.blank('/', method='POST')
         request.headers['Content-Type'] = 'application/json'
-        request.body = ''.encode("utf-8")
+        request.body = ''
 
         content_type, body = resource.get_body(request)
-        self.assertIsNone(content_type)
-        self.assertEqual('', body)
+        self.assertEqual(content_type, None)
+        self.assertEqual(body, '')
 
     def test_get_body(self):
         class Controller(object):
@@ -464,11 +360,11 @@ class ResourceTest(test.TestCase):
 
         request = wsgi.Request.blank('/', method='POST')
         request.headers['Content-Type'] = 'application/json'
-        request.body = 'foo'.encode("utf-8")
+        request.body = 'foo'
 
         content_type, body = resource.get_body(request)
-        self.assertEqual('application/json', content_type)
-        self.assertEqual('foo'.encode("utf-8"), body)
+        self.assertEqual(content_type, 'application/json')
+        self.assertEqual(body, 'foo')
 
     def test_deserialize_badtype(self):
         class Controller(object):
@@ -499,7 +395,7 @@ class ResourceTest(test.TestCase):
         resource = wsgi.Resource(controller, json=JSONDeserializer)
 
         obj = resource.deserialize(controller.index, 'application/json', 'foo')
-        self.assertEqual('json', obj)
+        self.assertEqual(obj, 'json')
 
     def test_deserialize_decorator(self):
         class JSONDeserializer(object):
@@ -514,7 +410,7 @@ class ResourceTest(test.TestCase):
         resource = wsgi.Resource(controller, json=JSONDeserializer)
 
         obj = resource.deserialize(controller.index, 'application/json', 'foo')
-        self.assertEqual('json', obj)
+        self.assertEqual(obj, 'json')
 
     def test_register_actions(self):
         class Controller(object):
@@ -533,6 +429,7 @@ class ResourceTest(test.TestCase):
         controller = Controller()
         resource = wsgi.Resource(controller)
         self.assertEqual({}, resource.wsgi_actions)
+
         extended = ControllerExtended()
         resource.register_actions(extended)
         self.assertEqual({'fooAction': extended._action_foo,
@@ -579,8 +476,8 @@ class ResourceTest(test.TestCase):
         resource = wsgi.Resource(controller)
         resource.register_extensions(extended)
         method, extensions = resource.get_method(None, 'index', None, '')
-        self.assertEqual(controller.index, method)
-        self.assertEqual([extended.index], extensions)
+        self.assertEqual(method, controller.index)
+        self.assertEqual(extensions, [extended.index])
 
     def test_get_method_action_extensions(self):
         class Controller(wsgi.Controller):
@@ -603,8 +500,8 @@ class ResourceTest(test.TestCase):
         method, extensions = resource.get_method(None, 'action',
                                                  'application/json',
                                                  '{"fooAction": true}')
-        self.assertEqual(controller._action_foo, method)
-        self.assertEqual([extended._action_foo], extensions)
+        self.assertEqual(method, controller._action_foo)
+        self.assertEqual(extensions, [extended._action_foo])
 
     def test_get_method_action_whitelist_extensions(self):
         class Controller(wsgi.Controller):
@@ -628,12 +525,12 @@ class ResourceTest(test.TestCase):
         method, extensions = resource.get_method(None, 'create',
                                                  'application/json',
                                                  '{"create": true}')
-        self.assertEqual(extended._create, method)
-        self.assertEqual([], extensions)
+        self.assertEqual(method, extended._create)
+        self.assertEqual(extensions, [])
 
         method, extensions = resource.get_method(None, 'delete', None, None)
-        self.assertEqual(extended._delete, method)
-        self.assertEqual([], extensions)
+        self.assertEqual(method, extended._delete)
+        self.assertEqual(extensions, [])
 
     def test_pre_process_extensions_regular(self):
         class Controller(object):
@@ -655,9 +552,9 @@ class ResourceTest(test.TestCase):
 
         extensions = [extension1, extension2]
         response, post = resource.pre_process_extensions(extensions, None, {})
-        self.assertEqual([], called)
-        self.assertIsNone(response)
-        self.assertEqual([extension2, extension1], list(post))
+        self.assertEqual(called, [])
+        self.assertEqual(response, None)
+        self.assertEqual(list(post), [extension2, extension1])
 
     def test_pre_process_extensions_generator(self):
         class Controller(object):
@@ -672,21 +569,19 @@ class ResourceTest(test.TestCase):
         def extension1(req):
             called.append('pre1')
             resp_obj = yield
-            self.assertIsNone(resp_obj)
             called.append('post1')
 
         def extension2(req):
             called.append('pre2')
             resp_obj = yield
-            self.assertIsNone(resp_obj)
             called.append('post2')
 
         extensions = [extension1, extension2]
         response, post = resource.pre_process_extensions(extensions, None, {})
         post = list(post)
-        self.assertEqual(['pre1', 'pre2'], called)
-        self.assertIsNone(response)
-        self.assertEqual(2, len(post))
+        self.assertEqual(called, ['pre1', 'pre2'])
+        self.assertEqual(response, None)
+        self.assertEqual(len(post), 2)
         self.assertTrue(inspect.isgenerator(post[0]))
         self.assertTrue(inspect.isgenerator(post[1]))
 
@@ -696,7 +591,7 @@ class ResourceTest(test.TestCase):
             except StopIteration:
                 continue
 
-        self.assertEqual(['pre1', 'pre2', 'post2', 'post1'], called)
+        self.assertEqual(called, ['pre1', 'pre2', 'post2', 'post1'])
 
     def test_pre_process_extensions_generator_response(self):
         class Controller(object):
@@ -717,9 +612,9 @@ class ResourceTest(test.TestCase):
 
         extensions = [extension1, extension2]
         response, post = resource.pre_process_extensions(extensions, None, {})
-        self.assertEqual(['pre1'], called)
-        self.assertEqual('foo', response)
-        self.assertEqual([], post)
+        self.assertEqual(called, ['pre1'])
+        self.assertEqual(response, 'foo')
+        self.assertEqual(post, [])
 
     def test_post_process_extensions_regular(self):
         class Controller(object):
@@ -741,8 +636,8 @@ class ResourceTest(test.TestCase):
 
         response = resource.post_process_extensions([extension2, extension1],
                                                     None, None, {})
-        self.assertEqual([2, 1], called)
-        self.assertIsNone(response)
+        self.assertEqual(called, [2, 1])
+        self.assertEqual(response, None)
 
     def test_post_process_extensions_regular_response(self):
         class Controller(object):
@@ -764,30 +659,8 @@ class ResourceTest(test.TestCase):
 
         response = resource.post_process_extensions([extension2, extension1],
                                                     None, None, {})
-        self.assertEqual([2], called)
-        self.assertEqual('foo', response)
-
-    def test_post_process_extensions_version_not_found(self):
-        class Controller(object):
-            def index(self, req, pants=None):
-                return pants
-
-        controller = Controller()
-        resource = wsgi.Resource(controller)
-
-        called = []
-
-        def extension1(req, resp_obj):
-            called.append(1)
-            return 'bar'
-
-        def extension2(req, resp_obj):
-            raise exception.VersionNotFoundForAPIMethod(version='fake_version')
-
-        response = resource.post_process_extensions([extension2, extension1],
-                                                    None, None, {})
-        self.assertEqual([1], called)
-        self.assertEqual('bar', response)
+        self.assertEqual(called, [2])
+        self.assertEqual(response, 'foo')
 
     def test_post_process_extensions_generator(self):
         class Controller(object):
@@ -801,12 +674,10 @@ class ResourceTest(test.TestCase):
 
         def extension1(req):
             resp_obj = yield
-            self.assertIsNone(resp_obj)
             called.append(1)
 
         def extension2(req):
             resp_obj = yield
-            self.assertIsNone(resp_obj)
             called.append(2)
 
         ext1 = extension1(None)
@@ -817,8 +688,8 @@ class ResourceTest(test.TestCase):
         response = resource.post_process_extensions([ext2, ext1],
                                                     None, None, {})
 
-        self.assertEqual([2, 1], called)
-        self.assertIsNone(response)
+        self.assertEqual(called, [2, 1])
+        self.assertEqual(response, None)
 
     def test_post_process_extensions_generator_response(self):
         class Controller(object):
@@ -832,12 +703,10 @@ class ResourceTest(test.TestCase):
 
         def extension1(req):
             resp_obj = yield
-            self.assertIsNone(resp_obj)
             called.append(1)
 
         def extension2(req):
             resp_obj = yield
-            self.assertIsNone(resp_obj)
             called.append(2)
             yield 'foo'
 
@@ -849,66 +718,66 @@ class ResourceTest(test.TestCase):
         response = resource.post_process_extensions([ext2, ext1],
                                                     None, None, {})
 
-        self.assertEqual([2], called)
-        self.assertEqual('foo', response)
+        self.assertEqual(called, [2])
+        self.assertEqual(response, 'foo')
 
 
 class ResponseObjectTest(test.TestCase):
     def test_default_code(self):
         robj = wsgi.ResponseObject({})
-        self.assertEqual(200, robj.code)
+        self.assertEqual(robj.code, 200)
 
     def test_modified_code(self):
         robj = wsgi.ResponseObject({})
         robj._default_code = 202
-        self.assertEqual(202, robj.code)
+        self.assertEqual(robj.code, 202)
 
     def test_override_default_code(self):
         robj = wsgi.ResponseObject({}, code=404)
-        self.assertEqual(404, robj.code)
+        self.assertEqual(robj.code, 404)
 
     def test_override_modified_code(self):
         robj = wsgi.ResponseObject({}, code=404)
         robj._default_code = 202
-        self.assertEqual(404, robj.code)
+        self.assertEqual(robj.code, 404)
 
     def test_set_header(self):
         robj = wsgi.ResponseObject({})
         robj['Header'] = 'foo'
-        self.assertEqual({'header': 'foo'}, robj.headers)
+        self.assertEqual(robj.headers, {'header': 'foo'})
 
     def test_get_header(self):
         robj = wsgi.ResponseObject({})
         robj['Header'] = 'foo'
-        self.assertEqual('foo', robj['hEADER'])
+        self.assertEqual(robj['hEADER'], 'foo')
 
     def test_del_header(self):
         robj = wsgi.ResponseObject({})
         robj['Header'] = 'foo'
         del robj['hEADER']
-        self.assertNotIn('header', robj.headers)
+        self.assertFalse('header' in robj.headers)
 
     def test_header_isolation(self):
         robj = wsgi.ResponseObject({})
         robj['Header'] = 'foo'
         hdrs = robj.headers
         hdrs['hEADER'] = 'bar'
-        self.assertEqual('foo', robj['hEADER'])
+        self.assertEqual(robj['hEADER'], 'foo')
 
     def test_default_serializers(self):
         robj = wsgi.ResponseObject({})
-        self.assertEqual({}, robj.serializers)
+        self.assertEqual(robj.serializers, {})
 
     def test_bind_serializers(self):
         robj = wsgi.ResponseObject({}, json='foo')
         robj._bind_method_serializers(dict(xml='bar', json='baz'))
-        self.assertEqual(dict(xml='bar', json='foo'), robj.serializers)
+        self.assertEqual(robj.serializers, dict(xml='bar', json='foo'))
 
     def test_get_serializer(self):
         robj = wsgi.ResponseObject({}, json='json', xml='xml', atom='atom')
         for content_type, mtype in wsgi._MEDIA_TYPE_MAP.items():
             _mtype, serializer = robj.get_serializer(content_type)
-            self.assertEqual(mtype, serializer)
+            self.assertEqual(serializer, mtype)
 
     def test_get_serializer_defaults(self):
         robj = wsgi.ResponseObject({})
@@ -918,20 +787,20 @@ class ResponseObjectTest(test.TestCase):
                               robj.get_serializer, content_type)
             _mtype, serializer = robj.get_serializer(content_type,
                                                      default_serializers)
-            self.assertEqual(mtype, serializer)
+            self.assertEqual(serializer, mtype)
 
     def test_serialize(self):
         class JSONSerializer(object):
             def serialize(self, obj):
-                return 'json'.encode("utf-8")
+                return 'json'
 
         class XMLSerializer(object):
             def serialize(self, obj):
-                return 'xml'.encode("utf-8")
+                return 'xml'
 
         class AtomSerializer(object):
             def serialize(self, obj):
-                return 'atom'.encode("utf-8")
+                return 'atom'
 
         robj = wsgi.ResponseObject({}, code=202,
                                    json=JSONSerializer,
@@ -944,11 +813,11 @@ class ResponseObjectTest(test.TestCase):
             request = wsgi.Request.blank('/tests/123')
             response = robj.serialize(request, content_type)
 
-            self.assertEqual(content_type, response.headers['Content-Type'])
-            self.assertEqual('header1', response.headers['X-header1'])
-            self.assertEqual('header2', response.headers['X-header2'])
-            self.assertEqual(202, response.status_int)
-            self.assertEqual(mtype.encode("utf-8"), response.body)
+            self.assertEqual(response.headers['Content-Type'], content_type)
+            self.assertEqual(response.headers['X-header1'], 'header1')
+            self.assertEqual(response.headers['X-header2'], 'header2')
+            self.assertEqual(response.status_int, 202)
+            self.assertEqual(response.body, mtype)
 
 
 class ValidBodyTest(test.TestCase):
@@ -962,63 +831,19 @@ class ValidBodyTest(test.TestCase):
         self.assertTrue(self.controller.is_valid_body(body, 'foo'))
 
     def test_is_valid_body_none(self):
+        resource = wsgi.Resource(controller=None)
         self.assertFalse(self.controller.is_valid_body(None, 'foo'))
 
     def test_is_valid_body_empty(self):
+        resource = wsgi.Resource(controller=None)
         self.assertFalse(self.controller.is_valid_body({}, 'foo'))
 
     def test_is_valid_body_no_entity(self):
+        resource = wsgi.Resource(controller=None)
         body = {'bar': {}}
         self.assertFalse(self.controller.is_valid_body(body, 'foo'))
 
     def test_is_valid_body_malformed_entity(self):
+        resource = wsgi.Resource(controller=None)
         body = {'foo': 'bar'}
         self.assertFalse(self.controller.is_valid_body(body, 'foo'))
-
-
-class AuthorizeDecoratorTest(test.TestCase):
-    class FakeController(wsgi.Controller):
-        resource_name = 'fake_resource_name'
-
-        @wsgi.Controller.authorize
-        def fake_action_1(self, req):
-            pass
-
-        @wsgi.Controller.authorize('fake_action')
-        def fake_action_2(self, req):
-            pass
-
-    def setUp(self):
-        super(AuthorizeDecoratorTest, self).setUp()
-        self.controller = self.FakeController()
-        self.admin_context = context.get_admin_context()
-        self.user_context = fakes.FakeRequestContext
-        self.mock_policy_check = self.mock_object(policy, 'check_policy')
-
-    def test_authorize_decorator_no_args(self):
-        req = fakes.HTTPRequest.blank('/v2/fake/fake_id')
-        req.environ['manila.context'] = self.user_context
-
-        self.controller.fake_action_1(req)
-
-        self.mock_policy_check.assert_called_once_with(
-            self.user_context, self.controller.resource_name, 'fake_action_1')
-
-    def test_authorize_decorator_action_name(self):
-        req = fakes.HTTPRequest.blank('/v2/fake/fake_id')
-        req.environ['manila.context'] = self.admin_context
-
-        self.controller.fake_action_2(req)
-
-        self.mock_policy_check.assert_called_once_with(
-            self.admin_context, self.controller.resource_name, 'fake_action')
-
-    def test_authorize_exception(self):
-        req = fakes.HTTPRequest.blank('/v2/fake/fake_id')
-        req.environ['manila.context'] = self.admin_context
-        exc = exception.PolicyNotAuthorized(action='fake_action')
-
-        with mock.patch.object(policy, 'check_policy',
-                               mock.Mock(side_effect=exc)):
-            self.assertRaises(webob.exc.HTTPForbidden,
-                              self.controller.fake_action_2, req)
