@@ -14,10 +14,9 @@
 #    License for the specific language governing permissions and limitations
 #    under the License.
 
-from unittest import mock
-
 import ddt
 import iso8601
+import mock
 from oslo_config import cfg
 from oslo_serialization import jsonutils
 import webob
@@ -28,6 +27,7 @@ from manila import policy
 from manila import test
 
 CONF = cfg.CONF
+NS = "{http://docs.openstack.org/common/api/v1.0}"
 
 
 class ExtensionTestCase(test.TestCase):
@@ -58,7 +58,7 @@ class ExtensionControllerTest(ExtensionTestCase):
         names = [str(x['name']) for x in data['extensions']
                  if str(x['name']) in self.ext_list]
         names.sort()
-        self.assertEqual(self.ext_list, names)
+        self.assertEqual(names, self.ext_list)
 
         # Ensure all the timestamps are valid according to iso8601
         for ext in data['extensions']:
@@ -68,19 +68,18 @@ class ExtensionControllerTest(ExtensionTestCase):
         (fox_ext, ) = [
             x for x in data['extensions'] if x['alias'] == 'FOXNSOX']
         self.assertEqual(
-            {'name': 'Fox In Socks',
-             'updated': '2011-01-22T13:25:27-06:00',
-             'description': 'The Fox In Socks Extension.',
-             'alias': 'FOXNSOX',
-             'links': []},
-            fox_ext)
+            fox_ext, {'name': 'Fox In Socks',
+                      'updated': '2011-01-22T13:25:27-06:00',
+                      'description': 'The Fox In Socks Extension.',
+                      'alias': 'FOXNSOX',
+                      'links': []}, )
 
         for ext in data['extensions']:
             url = '/fake/extensions/%s' % ext['alias']
             request = webob.Request.blank(url)
             response = request.get_response(app)
             output = jsonutils.loads(response.body)
-            self.assertEqual(ext['alias'], output['extension']['alias'])
+            self.assertEqual(output['extension']['alias'], ext['alias'])
 
     def test_get_extension_json(self):
         app = router.APIRouter()
@@ -90,12 +89,12 @@ class ExtensionControllerTest(ExtensionTestCase):
 
         data = jsonutils.loads(response.body)
         self.assertEqual(
+            data['extension'],
             {"name": "Fox In Socks",
              "updated": "2011-01-22T13:25:27-06:00",
              "description": "The Fox In Socks Extension.",
              "alias": "FOXNSOX",
-             "links": []},
-            data['extension'])
+             "links": []})
 
     def test_get_non_existing_extension_json(self):
         app = router.APIRouter()
@@ -131,58 +130,3 @@ class ExtensionAuthorizeTestCase(test.TestCase):
 
         policy.enforce.assert_called_once_with(
             mock.ANY, mock.ANY, {'project_id': 'fake', 'user_id': 'fake'})
-
-
-class StubExtensionManager(object):
-    """Provides access to Tweedle Beetles."""
-
-    name = "Tweedle Beetle Extension"
-    alias = "TWDLBETL"
-
-    def __init__(self, resource_ext=None, action_ext=None, request_ext=None,
-                 controller_ext=None):
-        self.resource_ext = resource_ext
-        self.controller_ext = controller_ext
-        self.extra_resource_ext = None
-
-    def get_resources(self):
-        resource_exts = []
-        if self.resource_ext:
-            resource_exts.append(self.resource_ext)
-        if self.extra_resource_ext:
-            resource_exts.append(self.extra_resource_ext)
-        return resource_exts
-
-    def get_controller_extensions(self):
-        controller_extensions = []
-        if self.controller_ext:
-            controller_extensions.append(self.controller_ext)
-        return controller_extensions
-
-
-class ExtensionControllerIdFormatTest(test.TestCase):
-
-    def _bounce_id(self, test_id):
-
-        class BounceController(object):
-            def show(self, req, id):
-                return id
-        res_ext = extensions.ResourceExtension('bounce',
-                                               BounceController())
-        manager = StubExtensionManager(res_ext)
-        app = router.APIRouter(manager)
-        request = webob.Request.blank("/fake/bounce/%s" % test_id)
-        response = request.get_response(app)
-        return response.body
-
-    def test_id_with_xml_format(self):
-        result = self._bounce_id('foo.xml')
-        self.assertEqual('foo', result.decode('UTF-8'))
-
-    def test_id_with_json_format(self):
-        result = self._bounce_id('foo.json')
-        self.assertEqual('foo', result.decode('UTF-8'))
-
-    def test_id_with_bad_format(self):
-        result = self._bounce_id('foo.bad')
-        self.assertEqual('foo.bad', result.decode('UTF-8'))
