@@ -16,30 +16,31 @@
 """
 Tests dealing with HTTP rate-limiting.
 """
-import ddt
-import http.client as http_client
-import io
+
+import httplib
 
 from oslo_serialization import jsonutils
+import six
+from six import moves
 import webob
 
-from manila.api.openstack import api_version_request as api_version
 from manila.api.v1 import limits
 from manila.api import views
 import manila.context
 from manila import test
-from manila.tests.api import fakes
 
 
 TEST_LIMITS = [
     limits.Limit("GET", "/delayed", "^/delayed", 1, limits.PER_MINUTE),
     limits.Limit("POST", "*", ".*", 7, limits.PER_MINUTE),
-    limits.Limit("POST", "/shares", "^/shares", 3, limits.PER_MINUTE),
+    limits.Limit("POST", "/volumes", "^/volumes", 3, limits.PER_MINUTE),
     limits.Limit("PUT", "*", "", 10, limits.PER_MINUTE),
-    limits.Limit("PUT", "/shares", "^/shares", 5, limits.PER_MINUTE),
+    limits.Limit("PUT", "/volumes", "^/volumes", 5, limits.PER_MINUTE),
 ]
-SHARE_REPLICAS_LIMIT_MICROVERSION = "2.58"
-SHARE_GROUP_QUOTA_MICROVERSION = "2.40"
+NS = {
+    'atom': 'http://www.w3.org/2005/Atom',
+    'ns': 'http://docs.openstack.org/common/api/v1.0'
+}
 
 
 class BaseLimitTestSuite(test.TestCase):
@@ -52,13 +53,8 @@ class BaseLimitTestSuite(test.TestCase):
         self.absolute_limits = {}
 
         def stub_get_project_quotas(context, project_id, usages=True):
-            quotas = {}
-            for mapping_key in ('limit', 'in_use'):
-                for k, v in self.absolute_limits.get(mapping_key, {}).items():
-                    if k not in quotas:
-                        quotas[k] = {}
-                    quotas[k].update({mapping_key: v})
-            return quotas
+            return dict((k, dict(limit=v))
+                        for k, v in self.absolute_limits.items())
 
         self.mock_object(manila.quota.QUOTAS, "get_project_quotas",
                          stub_get_project_quotas)
@@ -68,20 +64,24 @@ class BaseLimitTestSuite(test.TestCase):
         return self.time
 
 
-@ddt.ddt
 class LimitsControllerTest(BaseLimitTestSuite):
     """Tests for `limits.LimitsController` class."""
 
     def setUp(self):
         """Run before each test."""
         super(LimitsControllerTest, self).setUp()
-        self.controller = limits.LimitsController()
+        self.controller = limits.create_resource()
 
-    def _get_index_request(self, accept_header="application/json",
-                           microversion=api_version.DEFAULT_API_VERSION):
+    def _get_index_request(self, accept_header="application/json"):
         """Helper to set routing arguments."""
-        request = fakes.HTTPRequest.blank('/limit', version=microversion)
+        request = webob.Request.blank("/")
         request.accept = accept_header
+        request.environ["wsgiorg.routing_args"] = (None, {
+            "action": "index",
+            "controller": "",
+        })
+        context = manila.context.RequestContext('testuser', 'testproject')
+        request.environ["manila.context"] = context
         return request
 
     def _populate_limits(self, request):
@@ -98,52 +98,26 @@ class LimitsControllerTest(BaseLimitTestSuite):
     def test_empty_index_json(self):
         """Test getting empty limit details in JSON."""
         request = self._get_index_request()
-        response = self.controller.index(request)
+        response = request.get_response(self.controller)
         expected = {
             "limits": {
                 "rate": [],
                 "absolute": {},
             },
         }
-        self.assertEqual(expected, response)
+        body = jsonutils.loads(response.body)
+        self.assertEqual(expected, body)
 
-    @ddt.data(api_version.DEFAULT_API_VERSION,
-              SHARE_REPLICAS_LIMIT_MICROVERSION)
-    def test_index_json(self, microversion):
+    def test_index_json(self):
         """Test getting limit details in JSON."""
-        request = self._get_index_request(microversion=microversion)
+        request = self._get_index_request()
         request = self._populate_limits(request)
         self.absolute_limits = {
-            'limit': {
-                'shares': 11,
-                'gigabytes': 22,
-                'snapshots': 33,
-                'snapshot_gigabytes': 44,
-                'share_networks': 55,
-            },
-            'in_use': {
-                'shares': 3,
-                'gigabytes': 4,
-                'snapshots': 5,
-                'snapshot_gigabytes': 6,
-                'share_networks': 7,
-            },
+            'gigabytes': 512,
+            'shares': 5,
+            'snapshots': 5
         }
-
-        if microversion == SHARE_GROUP_QUOTA_MICROVERSION:
-            self.absolute_limits['limit']['share_groups'] = 20
-            self.absolute_limits['limit']['share_group_snapshots'] = 20
-            self.absolute_limits['in_use']['share_groups'] = 3
-            self.absolute_limits['in_use']['share_group_snapshots'] = 3
-
-        if microversion == SHARE_REPLICAS_LIMIT_MICROVERSION:
-            self.absolute_limits['limit']['share_replicas'] = 20
-            self.absolute_limits['limit']['replica_gigabytes'] = 20
-            self.absolute_limits['in_use']['share_replicas'] = 3
-            self.absolute_limits['in_use']['replica_gigabytes'] = 3
-
-        response = self.controller.index(request)
-
+        response = request.get_response(self.controller)
         expected = {
             "limits": {
                 "rate": [
@@ -182,33 +156,14 @@ class LimitsControllerTest(BaseLimitTestSuite):
                     },
 
                 ],
-                "absolute": {
-                    "totalSharesUsed": 3,
-                    "totalShareGigabytesUsed": 4,
-                    "totalShareSnapshotsUsed": 5,
-                    "totalSnapshotGigabytesUsed": 6,
-                    "totalShareNetworksUsed": 7,
-                    "maxTotalShares": 11,
-                    "maxTotalShareGigabytes": 22,
-                    "maxTotalShareSnapshots": 33,
-                    "maxTotalSnapshotGigabytes": 44,
-                    "maxTotalShareNetworks": 55,
-                },
+                "absolute": {"maxTotalShareGigabytes": 512,
+                             "maxTotalShares": 5,
+                             "maxTotalShareSnapshots": 5,
+                             },
             },
         }
-        if microversion == SHARE_GROUP_QUOTA_MICROVERSION:
-            expected['limits']['absolute']["maxTotalShareGroups"] = 20
-            expected['limits']['absolute']["totalShareGroupsUsed"] = 3
-            expected['limits']['absolute']["maxTotalShareGroupSnapshots"] = 20
-            expected['limits']['absolute']["totalShareGroupSnapshots"] = 3
-
-        if microversion == SHARE_REPLICAS_LIMIT_MICROVERSION:
-            expected['limits']['absolute']["maxTotalShareReplicas"] = 20
-            expected['limits']['absolute']["totalShareReplicasUsed"] = 3
-            expected['limits']['absolute']["maxTotalReplicaGigabytes"] = 20
-            expected['limits']['absolute']["totalReplicaGigabytesUsed"] = 3
-        # body = jsonutils.loads(response.body)
-        self.assertEqual(expected, response)
+        body = jsonutils.loads(response.body)
+        self.assertEqual(expected, body)
 
     def _populate_limits_diff_regex(self, request):
         """Put limit info into a request."""
@@ -223,7 +178,7 @@ class LimitsControllerTest(BaseLimitTestSuite):
         """Test getting limit details in JSON."""
         request = self._get_index_request()
         request = self._populate_limits_diff_regex(request)
-        response = self.controller.index(request)
+        response = request.get_response(self.controller)
         expected = {
             "limits": {
                 "rate": [
@@ -258,18 +213,17 @@ class LimitsControllerTest(BaseLimitTestSuite):
                 "absolute": {},
             },
         }
-        self.assertEqual(expected, response)
+        body = jsonutils.loads(response.body)
+        self.assertEqual(expected, body)
 
     def _test_index_absolute_limits_json(self, expected):
         request = self._get_index_request()
-        response = self.controller.index(request)
-        self.assertEqual(expected, response['limits']['absolute'])
+        response = request.get_response(self.controller)
+        body = jsonutils.loads(response.body)
+        self.assertEqual(expected, body['limits']['absolute'])
 
     def test_index_ignores_extra_absolute_limits_json(self):
-        self.absolute_limits = {
-            'in_use': {'unknown_limit': 9000},
-            'limit': {'unknown_limit': 9001},
-        }
+        self.absolute_limits = {'unknown_limit': 9001}
         self._test_index_absolute_limits_json({})
 
 
@@ -311,16 +265,16 @@ class LimitMiddlewareTest(BaseLimitTestSuite):
 
         request = webob.Request.blank("/")
         response = request.get_response(self.app)
-        self.assertEqual(413, response.status_int)
+        self.assertEqual(response.status_int, 413)
 
-        self.assertIn('Retry-After', response.headers)
+        self.assertTrue('Retry-After' in response.headers)
         retry_after = int(response.headers['Retry-After'])
         self.assertAlmostEqual(retry_after, 60, 1)
 
         body = jsonutils.loads(response.body)
         expected = "Only 1 GET request(s) can be made to * every minute."
         value = body["overLimitFault"]["details"].strip()
-        self.assertEqual(expected, value)
+        self.assertEqual(value, expected)
 
 
 class LimitTest(BaseLimitTestSuite):
@@ -330,7 +284,7 @@ class LimitTest(BaseLimitTestSuite):
         """Test a limit handles 1 GET per second."""
         limit = limits.Limit("GET", "*", ".*", 1, 1)
         delay = limit("GET", "/anything")
-        self.assertIsNone(delay)
+        self.assertEqual(None, delay)
         self.assertEqual(0, limit.next_request)
         self.assertEqual(0, limit.last_request)
 
@@ -338,7 +292,7 @@ class LimitTest(BaseLimitTestSuite):
         """Test two calls to 1 GET per second limit."""
         limit = limits.Limit("GET", "*", ".*", 1, 1)
         delay = limit("GET", "/anything")
-        self.assertIsNone(delay)
+        self.assertEqual(None, delay)
 
         delay = limit("GET", "/anything")
         self.assertEqual(1, delay)
@@ -348,7 +302,7 @@ class LimitTest(BaseLimitTestSuite):
         self.time += 4
 
         delay = limit("GET", "/anything")
-        self.assertIsNone(delay)
+        self.assertEqual(None, delay)
         self.assertEqual(4, limit.next_request)
         self.assertEqual(4, limit.last_request)
 
@@ -388,37 +342,36 @@ class ParseLimitsTest(BaseLimitTestSuite):
     def test_multiple_rules(self):
         """Test that parse_limits() handles multiple rules correctly."""
         try:
-            lim = limits.Limiter.parse_limits(
-                '(get, *, .*, 20, minute);'
-                '(PUT, /foo*, /foo.*, 10, hour);'
-                '(POST, /bar*, /bar.*, 5, second);'
-                '(Say, /derp*, /derp.*, 1, day)')
+            l = limits.Limiter.parse_limits('(get, *, .*, 20, minute);'
+                                            '(PUT, /foo*, /foo.*, 10, hour);'
+                                            '(POST, /bar*, /bar.*, 5, second);'
+                                            '(Say, /derp*, /derp.*, 1, day)')
         except ValueError as e:
-            assert False, str(e)
+            assert False, six.text_types(e)
 
         # Make sure the number of returned limits are correct
-        self.assertEqual(4, len(lim))
+        self.assertEqual(len(l), 4)
 
         # Check all the verbs...
         expected = ['GET', 'PUT', 'POST', 'SAY']
-        self.assertEqual(expected, [t.verb for t in lim])
+        self.assertEqual([t.verb for t in l], expected)
 
         # ...the URIs...
         expected = ['*', '/foo*', '/bar*', '/derp*']
-        self.assertEqual(expected, [t.uri for t in lim])
+        self.assertEqual([t.uri for t in l], expected)
 
         # ...the regexes...
         expected = ['.*', '/foo.*', '/bar.*', '/derp.*']
-        self.assertEqual(expected, [t.regex for t in lim])
+        self.assertEqual([t.regex for t in l], expected)
 
         # ...the values...
         expected = [20, 10, 5, 1]
-        self.assertEqual(expected, [t.value for t in lim])
+        self.assertEqual([t.value for t in l], expected)
 
         # ...and the units...
         expected = [limits.PER_MINUTE, limits.PER_HOUR,
                     limits.PER_SECOND, limits.PER_DAY]
-        self.assertEqual(expected, [t.unit for t in lim])
+        self.assertEqual([t.unit for t in l], expected)
 
 
 class LimiterTest(BaseLimitTestSuite):
@@ -432,7 +385,7 @@ class LimiterTest(BaseLimitTestSuite):
 
     def _check(self, num, verb, url, username=None):
         """Check and yield results from checks."""
-        for x in range(num):
+        for x in moves.range(num):
             yield self.limiter.check_for_delay(verb, url, username)[0]
 
     def _check_sum(self, num, verb, url, username=None):
@@ -447,7 +400,7 @@ class LimiterTest(BaseLimitTestSuite):
         didn"t set.
         """
         delay = self.limiter.check_for_delay("GET", "/anything")
-        self.assertEqual((None, None), delay)
+        self.assertEqual(delay, (None, None))
 
     def test_no_delay_PUT(self):
         """Test no delay on single call.
@@ -455,7 +408,7 @@ class LimiterTest(BaseLimitTestSuite):
         Simple test to ensure no delay on a single call for a known limit.
         """
         delay = self.limiter.check_for_delay("PUT", "/anything")
-        self.assertEqual((None, None), delay)
+        self.assertEqual(delay, (None, None))
 
     def test_delay_PUT(self):
         """Ensure 11th PUT will be delayed.
@@ -480,7 +433,7 @@ class LimiterTest(BaseLimitTestSuite):
 
         expected = 60.0 / 7.0
         results = self._check_sum(1, "POST", "/anything")
-        self.assertAlmostEqual(expected, results, 8)
+        self.failUnlessAlmostEqual(expected, results, 8)
 
     def test_delay_GET(self):
         """Ensure the 11th GET will result in NO delay."""
@@ -498,7 +451,7 @@ class LimiterTest(BaseLimitTestSuite):
         """
         # First 6 requests on PUT /volumes
         expected = [None] * 5 + [12.0]
-        results = list(self._check(6, "PUT", "/shares"))
+        results = list(self._check(6, "PUT", "/volumes"))
         self.assertEqual(expected, results)
 
         # Next 5 request on PUT /anything
@@ -537,7 +490,7 @@ class LimiterTest(BaseLimitTestSuite):
 
     def test_user_limit(self):
         """Test user-specific limits."""
-        self.assertEqual([], self.limiter.levels['user3'])
+        self.assertEqual(self.limiter.levels['user3'], [])
 
     def test_multiple_users(self):
         """Tests involving multiple users."""
@@ -581,7 +534,7 @@ class WsgiLimiterTest(BaseLimitTestSuite):
 
     def _request_data(self, verb, path):
         """Get data describing a limit request verb/path."""
-        return jsonutils.dumps({"verb": verb, "path": path}).encode("utf-8")
+        return jsonutils.dumps({"verb": verb, "path": path})
 
     def _request(self, verb, url, username=None):
         """Send request.
@@ -601,61 +554,61 @@ class WsgiLimiterTest(BaseLimitTestSuite):
         response = request.get_response(self.app)
 
         if "X-Wait-Seconds" in response.headers:
-            self.assertEqual(403, response.status_int)
+            self.assertEqual(response.status_int, 403)
             return response.headers["X-Wait-Seconds"]
 
-        self.assertEqual(204, response.status_int)
+        self.assertEqual(response.status_int, 204)
 
     def test_invalid_methods(self):
         """Only POSTs should work."""
         for method in ["GET", "PUT", "DELETE", "HEAD", "OPTIONS"]:
             request = webob.Request.blank("/", method=method)
             response = request.get_response(self.app)
-            self.assertEqual(405, response.status_int)
+            self.assertEqual(response.status_int, 405)
 
     def test_good_url(self):
         delay = self._request("GET", "/something")
-        self.assertIsNone(delay)
+        self.assertEqual(delay, None)
 
     def test_escaping(self):
         delay = self._request("GET", "/something/jump%20up")
-        self.assertIsNone(delay)
+        self.assertEqual(delay, None)
 
     def test_response_to_delays(self):
         delay = self._request("GET", "/delayed")
-        self.assertIsNone(delay)
+        self.assertEqual(delay, None)
 
         delay = self._request("GET", "/delayed")
-        self.assertEqual('60.00', delay)
+        self.assertEqual(delay, '60.00')
 
     def test_response_to_delays_usernames(self):
         delay = self._request("GET", "/delayed", "user1")
-        self.assertIsNone(delay)
+        self.assertEqual(delay, None)
 
         delay = self._request("GET", "/delayed", "user2")
-        self.assertIsNone(delay)
+        self.assertEqual(delay, None)
 
         delay = self._request("GET", "/delayed", "user1")
-        self.assertEqual('60.00', delay)
+        self.assertEqual(delay, '60.00')
 
         delay = self._request("GET", "/delayed", "user2")
-        self.assertEqual('60.00', delay)
+        self.assertEqual(delay, '60.00')
 
 
 class FakeHttplibSocket(object):
-    """Fake `http_client.HTTPResponse` replacement."""
+    """Fake `httplib.HTTPResponse` replacement."""
 
     def __init__(self, response_string):
         """Initialize new `FakeHttplibSocket`."""
-        self._buffer = io.BytesIO(response_string.encode("utf-8"))
+        self._buffer = six.StringIO(response_string)
 
-    def makefile(self, _mode, _other=None):
+    def makefile(self, _mode, _other):
         """Returns the socket's internal buffer."""
         return self._buffer
 
 
 class FakeHttplibConnection(object):
-    """Fake `http_client.HTTPConnection`."""
+    """Fake `httplib.HTTPConnection`."""
 
     def __init__(self, app, host):
         """Initialize `FakeHttplibConnection`."""
@@ -667,7 +620,7 @@ class FakeHttplibConnection(object):
 
         Requests made via this connection actually get translated and routed
         into our WSGI app, we then wait for the response and turn it back into
-        an `http_client.HTTPResponse`.
+        an `httplib.HTTPResponse`.
         """
         if not headers:
             headers = {}
@@ -676,12 +629,12 @@ class FakeHttplibConnection(object):
         req.method = method
         req.headers = headers
         req.host = self.host
-        req.body = body.encode("utf-8")
+        req.body = body
 
         resp = str(req.get_response(self.app))
         resp = "HTTP/1.0 %s" % resp
         sock = FakeHttplibSocket(resp)
-        self.http_response = http_client.HTTPResponse(sock)
+        self.http_response = httplib.HTTPResponse(sock)
         self.http_response.begin()
 
     def getresponse(self):
@@ -697,7 +650,7 @@ def wire_HTTPConnection_to_WSGI(host, app):
 
     After calling this method, when any code calls
 
-    http_client.HTTPConnection(host)
+    httplib.HTTPConnection(host)
 
     the connection object will be a fake.  Its requests will be sent directly
     to the given WSGI app rather than through a socket.
@@ -727,9 +680,8 @@ def wire_HTTPConnection_to_WSGI(host, app):
             else:
                 return self.wrapped(connection_host, *args, **kwargs)
 
-    oldHTTPConnection = http_client.HTTPConnection
-    http_client.HTTPConnection = HTTPConnectionDecorator(
-        http_client.HTTPConnection)
+    oldHTTPConnection = httplib.HTTPConnection
+    httplib.HTTPConnection = HTTPConnectionDecorator(httplib.HTTPConnection)
     return oldHTTPConnection
 
 
@@ -740,7 +692,7 @@ class WsgiLimiterProxyTest(BaseLimitTestSuite):
         """Set up HTTP/WSGI magic.
 
         Do some nifty HTTP/WSGI magic which allows for WSGI to be called
-        directly by something like the `http_client` library.
+        directly by something like the `httplib` library.
         """
         super(WsgiLimiterProxyTest, self).setUp()
         self.app = limits.WsgiLimiter(TEST_LIMITS)
@@ -751,24 +703,24 @@ class WsgiLimiterProxyTest(BaseLimitTestSuite):
     def test_200(self):
         """Successful request test."""
         delay = self.proxy.check_for_delay("GET", "/anything")
-        self.assertEqual((None, None), delay)
+        self.assertEqual(delay, (None, None))
 
     def test_403(self):
         """Forbidden request test."""
         delay = self.proxy.check_for_delay("GET", "/delayed")
-        self.assertEqual((None, None), delay)
+        self.assertEqual(delay, (None, None))
+
         delay, error = self.proxy.check_for_delay("GET", "/delayed")
         error = error.strip()
 
-        expected = ("60.00", (
-            "403 Forbidden\n\nOnly 1 GET request(s) can be made to /delayed "
-            "every minute.").encode("utf-8"))
+        expected = ("60.00", "403 Forbidden\n\nOnly 1 GET request(s) can be "
+                    "made to /delayed every minute.")
 
-        self.assertEqual(expected, (delay, error))
+        self.assertEqual((delay, error), expected)
 
     def tearDown(self):
         # restore original HTTPConnection object
-        http_client.HTTPConnection = self.oldHTTPConnection
+        httplib.HTTPConnection = self.oldHTTPConnection
         super(WsgiLimiterProxyTest, self).tearDown()
 
 
@@ -783,77 +735,47 @@ class LimitsViewBuilderTest(test.TestCase):
                              "remaining": 2,
                              "unit": "MINUTE",
                              "resetTime": 1311272226},
-                            {"URI": "*/shares",
-                             "regex": "^/shares",
+                            {"URI": "*/volumes",
+                             "regex": "^/volumes",
                              "value": 50,
                              "verb": "POST",
                              "remaining": 10,
                              "unit": "DAY",
                              "resetTime": 1311272226}]
-        self.absolute_limits = {
-            "limit": {
-                "shares": 111,
-                "gigabytes": 222,
-                "snapshots": 333,
-                "snapshot_gigabytes": 444,
-                "share_networks": 555,
-            },
-            "in_use": {
-                "shares": 65,
-                "gigabytes": 76,
-                "snapshots": 87,
-                "snapshot_gigabytes": 98,
-                "share_networks": 107,
-            },
-        }
+        self.absolute_limits = {"shares": 1,
+                                "gigabytes": 5,
+                                "snapshots": 5}
 
     def test_build_limits(self):
-        request = fakes.HTTPRequest.blank('/')
         tdate = "2011-07-21T18:17:06Z"
-        expected_limits = {
-            "limits": {
-                "rate": [
-                    {"uri": "*",
-                     "regex": ".*",
-                     "limit": [{"value": 10,
-                                "verb": "POST",
-                                "remaining": 2,
-                                "unit": "MINUTE",
-                                "next-available": tdate}]},
-                    {"uri": "*/shares",
-                     "regex": "^/shares",
-                     "limit": [{"value": 50,
-                                "verb": "POST",
-                                "remaining": 10,
-                                "unit": "DAY",
-                                "next-available": tdate}]}
-                ],
-                "absolute": {
-                    "totalSharesUsed": 65,
-                    "totalShareGigabytesUsed": 76,
-                    "totalShareSnapshotsUsed": 87,
-                    "totalSnapshotGigabytesUsed": 98,
-                    "totalShareNetworksUsed": 107,
-                    "maxTotalShares": 111,
-                    "maxTotalShareGigabytes": 222,
-                    "maxTotalShareSnapshots": 333,
-                    "maxTotalSnapshotGigabytes": 444,
-                    "maxTotalShareNetworks": 555,
-                }
-            }
-        }
+        expected_limits = \
+            {"limits": {"rate": [{"uri": "*",
+                                  "regex": ".*",
+                                  "limit": [{"value": 10,
+                                             "verb": "POST",
+                                             "remaining": 2,
+                                             "unit": "MINUTE",
+                                             "next-available": tdate}]},
+                                 {"uri": "*/volumes",
+                                  "regex": "^/volumes",
+                                  "limit": [{"value": 50,
+                                             "verb": "POST",
+                                             "remaining": 10,
+                                             "unit": "DAY",
+                                             "next-available": tdate}]}],
+                        "absolute": {"maxTotalShareGigabytes": 5,
+                                     "maxTotalShares": 1,
+                                     "maxTotalShareSnapshots": 5}}}
 
-        output = self.view_builder.build(request,
-                                         self.rate_limits,
+        output = self.view_builder.build(self.rate_limits,
                                          self.absolute_limits)
-        self.assertDictEqual(expected_limits, output)
+        self.assertDictMatch(output, expected_limits)
 
     def test_build_limits_empty_limits(self):
-        request = fakes.HTTPRequest.blank('/')
-        expected_limits = {"limits": {"rate": [], "absolute": {}}}
+        expected_limits = {"limits": {"rate": [],
+                           "absolute": {}}}
+
         abs_limits = {}
         rate_limits = []
-
-        output = self.view_builder.build(request, rate_limits, abs_limits)
-
-        self.assertDictEqual(expected_limits, output)
+        output = self.view_builder.build(rate_limits, abs_limits)
+        self.assertDictMatch(output, expected_limits)
