@@ -13,10 +13,8 @@
 #    License for the specific language governing permissions and limitations
 #    under the License.
 
-from unittest import mock
-from urllib import parse
-
-import ddt
+import mock
+from six.moves.urllib import parse
 import webob
 
 from manila.api.v1 import security_service
@@ -27,7 +25,6 @@ from manila import test
 from manila.tests.api import fakes
 
 
-@ddt.ddt
 class ShareApiTest(test.TestCase):
     """Share Api Test."""
     def setUp(self):
@@ -46,7 +43,7 @@ class ShareApiTest(test.TestCase):
             "domain": "fake-domain",
             "user": "fake-user",
             "password": "fake-password",
-            "status": constants.STATUS_NEW,
+            "status": "new",
             "project_id": "fake",
         }
         self.ss_ldap = {
@@ -69,6 +66,7 @@ class ShareApiTest(test.TestCase):
             'server': 'fake-server',
             'dns_ip': '1.1.1.1',
             'domain': 'fake-domain',
+            'status': 'new',
             'type': constants.SECURITY_SERVICES_ALLOWED_TYPES[0],
         }
         self.check_policy_patcher = mock.patch(
@@ -84,21 +82,6 @@ class ShareApiTest(test.TestCase):
             }, ]
         }
 
-        self.fake_share_network_list_with_share_servers = [{
-            'id': 'fake_sn_id',
-            'share_network_subnets': [{
-                'id': 'fake_sns_id',
-                'share_servers': [{'id': 'fake_ss_id'}]
-            }]
-        }]
-        self.fake_share_network_list_without_share_servers = [{
-            'id': 'fake_sn_id',
-            'share_network_subnets': [{
-                'id': 'fake_sns_id',
-                'share_servers': []
-            }]
-        }]
-
     def _stop_started_patcher(self, patcher):
         if hasattr(patcher, 'is_local'):
             patcher.stop()
@@ -110,8 +93,8 @@ class ShareApiTest(test.TestCase):
         res_dict = self.controller.show(req, '1')
         expected = self.ss_active_directory.copy()
         expected.update()
-        self.assertEqual({'security_service': self.ss_active_directory},
-                         res_dict)
+        self.assertEqual(res_dict,
+                         {'security_service': self.ss_active_directory})
 
     def test_security_service_show_not_found(self):
         db.security_service_get = mock.Mock(side_effect=exception.NotFound)
@@ -130,7 +113,7 @@ class ShareApiTest(test.TestCase):
         res_dict = self.controller.create(
             req, {"security_service": sec_service})
         expected = self.ss_active_directory.copy()
-        self.assertEqual({'security_service': expected}, res_dict)
+        self.assertEqual(res_dict, {'security_service': expected})
 
     def test_security_service_create_invalid_types(self):
         sec_service = self.ss_active_directory.copy()
@@ -156,7 +139,7 @@ class ShareApiTest(test.TestCase):
         resp = self.controller.delete(req, 1)
         db.security_service_delete.assert_called_once_with(
             req.environ['manila.context'], 1)
-        self.assertEqual(202, resp.status_int)
+        self.assertEqual(resp.status_int, 202)
 
     def test_security_service_delete_not_found(self):
         db.security_service_get = mock.Mock(side_effect=exception.NotFound)
@@ -178,62 +161,47 @@ class ShareApiTest(test.TestCase):
         new = self.ss_active_directory.copy()
         updated = self.ss_active_directory.copy()
         updated['name'] = 'new'
-        self.mock_object(security_service.policy, 'check_policy')
         db.security_service_get = mock.Mock(return_value=new)
         db.security_service_update = mock.Mock(return_value=updated)
-        fake_sns = {'id': 'fake_sns_id', 'share_servers': ['fake_ss']}
         db.share_network_get_all_by_security_service = mock.Mock(
             return_value=[{
                 'id': 'fake_id',
-                'share_network_subnets': [fake_sns]
+                'share_servers': 'fake_share_server'
             }])
         body = {"security_service": {"name": "new"}}
         req = fakes.HTTPRequest.blank('/security_service/1')
         res_dict = self.controller.update(req, 1, body)['security_service']
-        self.assertEqual(updated['name'], res_dict['name'])
+        self.assertEqual(res_dict['name'], updated['name'])
         db.share_network_get_all_by_security_service.assert_called_once_with(
             req.environ['manila.context'], 1)
-        self.assertEqual(2, security_service.policy.check_policy.call_count)
-        security_service.policy.check_policy.assert_has_calls([
-            mock.call(req.environ['manila.context'],
-                      security_service.RESOURCE_NAME, 'update', new)
-        ])
 
     def test_security_service_update_description(self):
         new = self.ss_active_directory.copy()
         updated = self.ss_active_directory.copy()
         updated['description'] = 'new'
-        self.mock_object(security_service.policy, 'check_policy')
         db.security_service_get = mock.Mock(return_value=new)
         db.security_service_update = mock.Mock(return_value=updated)
-        fake_sns = {'id': 'fake_sns_id', 'share_servers': ['fake_ss']}
         db.share_network_get_all_by_security_service = mock.Mock(
             return_value=[{
                 'id': 'fake_id',
-                'share_network_subnets': [fake_sns]
+                'share_servers': 'fake_share_server'
             }])
         body = {"security_service": {"description": "new"}}
         req = fakes.HTTPRequest.blank('/security_service/1')
         res_dict = self.controller.update(req, 1, body)['security_service']
-        self.assertEqual(updated['description'], res_dict['description'])
+        self.assertEqual(res_dict['description'], updated['description'])
         db.share_network_get_all_by_security_service.assert_called_once_with(
             req.environ['manila.context'], 1)
-        self.assertEqual(2, security_service.policy.check_policy.call_count)
-        security_service.policy.check_policy.assert_has_calls([
-            mock.call(req.environ['manila.context'],
-                      security_service.RESOURCE_NAME, 'update', new)
-        ])
 
     @mock.patch.object(db, 'security_service_get', mock.Mock())
     @mock.patch.object(db, 'share_network_get_all_by_security_service',
                        mock.Mock())
     def test_security_service_update_invalid_keys_sh_server_exists(self):
-        self.mock_object(security_service.policy, 'check_policy')
-        fake_sns = {'id': 'fake_sns_id', 'share_servers': ['fake_ss']}
         db.share_network_get_all_by_security_service.return_value = [
-            {'id': 'fake_id', 'share_network_subnets': [fake_sns]},
+            {'id': 'fake_id', 'share_servers': 'fake_share_servers'},
         ]
-        db.security_service_get.return_value = self.ss_active_directory.copy()
+        security_service = self.ss_active_directory.copy()
+        db.security_service_get.return_value = security_service
         body = {'security_service': {'user_id': 'new_user'}}
         req = fakes.HTTPRequest.blank('/security_services/1')
         self.assertRaises(webob.exc.HTTPForbidden, self.controller.update,
@@ -242,22 +210,14 @@ class ShareApiTest(test.TestCase):
             req.environ['manila.context'], 1)
         db.share_network_get_all_by_security_service.assert_called_once_with(
             req.environ['manila.context'], 1)
-        self.assertEqual(1, security_service.policy.check_policy.call_count)
-        security_service.policy.check_policy.assert_has_calls([
-            mock.call(req.environ['manila.context'],
-                      security_service.RESOURCE_NAME, 'update',
-                      db.security_service_get.return_value)
-        ])
 
     @mock.patch.object(db, 'security_service_get', mock.Mock())
     @mock.patch.object(db, 'security_service_update', mock.Mock())
     @mock.patch.object(db, 'share_network_get_all_by_security_service',
                        mock.Mock())
     def test_security_service_update_valid_keys_sh_server_exists(self):
-        self.mock_object(security_service.policy, 'check_policy')
-        fake_sns = {'id': 'fake_sns_id', 'share_servers': ['fake_ss']}
         db.share_network_get_all_by_security_service.return_value = [
-            {'id': 'fake_id', 'share_network_subnets': [fake_sns]},
+            {'id': 'fake_id', 'share_servers': 'fake_share_servers'},
         ]
         old = self.ss_active_directory.copy()
         updated = self.ss_active_directory.copy()
@@ -273,49 +233,14 @@ class ShareApiTest(test.TestCase):
         }
         req = fakes.HTTPRequest.blank('/security_services/1')
         res_dict = self.controller.update(req, 1, body)['security_service']
-        self.assertEqual(updated['description'], res_dict['description'])
-        self.assertEqual(updated['name'], res_dict['name'])
+        self.assertEqual(res_dict['description'], updated['description'])
+        self.assertEqual(res_dict['name'], updated['name'])
         db.security_service_get.assert_called_once_with(
             req.environ['manila.context'], 1)
         db.share_network_get_all_by_security_service.assert_called_once_with(
             req.environ['manila.context'], 1)
         db.security_service_update.assert_called_once_with(
             req.environ['manila.context'], 1, body['security_service'])
-        self.assertEqual(2, security_service.policy.check_policy.call_count)
-        security_service.policy.check_policy.assert_has_calls([
-            mock.call(req.environ['manila.context'],
-                      security_service.RESOURCE_NAME, 'update', old)
-        ])
-
-    @mock.patch.object(db, 'security_service_get', mock.Mock())
-    def test_security_service_update_has_share_servers(self):
-        db.security_service_get = mock.Mock()
-        self.mock_object(
-            self.controller, '_share_servers_dependent_on_sn_exist',
-            mock.Mock(return_value=True))
-        body = {"security_service": {"type": "ldap"}}
-
-        req = fakes.HTTPRequest.blank('/security_services/1')
-        self.assertRaises(webob.exc.HTTPForbidden,
-                          self.controller.update,
-                          req,
-                          1,
-                          body)
-
-    @ddt.data(True, False)
-    def test_security_service_update_share_server_dependent_exists(self,
-                                                                   expected):
-        req = fakes.HTTPRequest.blank('/security_services/1')
-        context = req.environ['manila.context']
-        db.security_service_get = mock.Mock()
-        network = (self.fake_share_network_list_with_share_servers if expected
-                   else self.fake_share_network_list_without_share_servers)
-        db.share_network_get_all_by_security_service = mock.Mock(
-            return_value=network)
-
-        result = self.controller._share_servers_dependent_on_sn_exist(
-            context, 'fake_id')
-        self.assertEqual(expected, result)
 
     def test_security_service_list(self):
         db.security_service_get_all_by_project = mock.Mock(
@@ -354,35 +279,18 @@ class ShareApiTest(test.TestCase):
         db.security_service_get_all.assert_called_once_with(
             req.environ['manila.context'])
 
-    @mock.patch.object(db, 'security_service_get_all_by_project', mock.Mock())
+    @mock.patch.object(db, 'security_service_get_all', mock.Mock())
     def test_security_services_list_all_tenants_non_admin_context(self):
-        db.security_service_get_all_by_project.return_value = []
+        self.check_policy_patcher.stop()
+        db.security_service_get_all.return_value = [
+            self.ss_active_directory,
+            self.ss_ldap,
+        ]
         req = fakes.HTTPRequest.blank(
             '/security-services?all_tenants=1')
-        fake_context = req.environ['manila.context']
-        self.controller.index(req)
-        db.security_service_get_all_by_project.assert_called_once_with(
-            fake_context, fake_context.project_id
-        )
-
-    @mock.patch.object(db, 'security_service_get_all', mock.Mock())
-    def test_security_services_list_all_tenants_with_invalid_value(self):
-        req = fakes.HTTPRequest.blank(
-            '/security-services?all_tenants=nerd',
-            use_admin_context=True)
-        self.assertRaises(exception.InvalidInput, self.controller.index, req)
-
-    @mock.patch.object(db, 'security_service_get_all_by_project', mock.Mock())
-    def test_security_services_list_all_tenants_with_value_zero(self):
-        db.security_service_get_all_by_project.return_value = []
-        req = fakes.HTTPRequest.blank(
-            '/security-services?all_tenants=0',
-            use_admin_context=True)
-        res_dict = self.controller.index(req)
-        self.assertEqual({'security_services': []}, res_dict)
-        db.security_service_get_all_by_project.assert_called_once_with(
-            req.environ['manila.context'],
-            req.environ['manila.context'].project_id)
+        self.assertRaises(exception.PolicyNotAuthorized, self.controller.index,
+                          req)
+        self.assertFalse(db.security_service_get_all.called)
 
     @mock.patch.object(db, 'security_service_get_all_by_project', mock.Mock())
     def test_security_services_list_admin_context_invalid_opts(self):
