@@ -206,7 +206,7 @@ class ShareNetworkAPITest(test.TestCase):
         share_nw['share_servers'] = ['foo', 'bar']
         self.mock_object(db_api, 'share_network_get',
                          mock.Mock(return_value=share_nw))
-        self.mock_object(db_api, 'share_instances_get_all_by_share_network',
+        self.mock_object(db_api, 'share_get_all_by_share_network',
                          mock.Mock(return_value=[]))
         self.mock_object(self.controller.share_rpcapi, 'delete_share_server')
         self.mock_object(db_api, 'share_network_delete')
@@ -215,9 +215,8 @@ class ShareNetworkAPITest(test.TestCase):
 
         db_api.share_network_get.assert_called_once_with(
             self.req.environ['manila.context'], share_nw['id'])
-        db_api.share_instances_get_all_by_share_network.\
-            assert_called_once_with(self.req.environ['manila.context'],
-                                    share_nw['id'])
+        db_api.share_get_all_by_share_network.assert_called_once_with(
+            self.req.environ['manila.context'], share_nw['id'])
         self.controller.share_rpcapi.delete_share_server.assert_has_calls([
             mock.call(self.req.environ['manila.context'], 'foo'),
             mock.call(self.req.environ['manila.context'], 'bar')])
@@ -240,7 +239,7 @@ class ShareNetworkAPITest(test.TestCase):
         share_nw['share_servers'] = ['foo', 'bar']
         self.mock_object(db_api, 'share_network_get',
                          mock.Mock(return_value=share_nw))
-        self.mock_object(db_api, 'share_instances_get_all_by_share_network',
+        self.mock_object(db_api, 'share_get_all_by_share_network',
                          mock.Mock(return_value=[]))
         self.mock_object(self.controller.share_rpcapi, 'delete_share_server')
         self.mock_object(db_api, 'share_network_delete')
@@ -252,11 +251,8 @@ class ShareNetworkAPITest(test.TestCase):
 
         db_api.share_network_get.assert_called_once_with(
             self.req.environ['manila.context'], share_nw['id'])
-
-        db_api.share_instances_get_all_by_share_network.\
-            assert_called_once_with(self.req.environ['manila.context'],
-                                    share_nw['id'])
-
+        db_api.share_get_all_by_share_network.assert_called_once_with(
+            self.req.environ['manila.context'], share_nw['id'])
         self.controller.share_rpcapi.delete_share_server.assert_has_calls([
             mock.call(self.req.environ['manila.context'], 'foo'),
             mock.call(self.req.environ['manila.context'], 'bar')])
@@ -265,11 +261,11 @@ class ShareNetworkAPITest(test.TestCase):
         self.assertTrue(share_networks.QUOTAS.reserve.called)
         self.assertFalse(share_networks.QUOTAS.commit.called)
 
-    def test_delete_in_use_by_share(self):
+    def test_delete_in_use(self):
         share_nw = fake_share_network.copy()
         self.mock_object(db_api, 'share_network_get',
                          mock.Mock(return_value=share_nw))
-        self.mock_object(db_api, 'share_instances_get_all_by_share_network',
+        self.mock_object(db_api, 'share_get_all_by_share_network',
                          mock.Mock(return_value=['foo', 'bar']))
 
         self.assertRaises(webob_exc.HTTPConflict,
@@ -279,23 +275,7 @@ class ShareNetworkAPITest(test.TestCase):
 
         db_api.share_network_get.assert_called_once_with(
             self.req.environ['manila.context'], share_nw['id'])
-        db_api.share_instances_get_all_by_share_network.\
-            assert_called_once_with(self.req.environ['manila.context'],
-                                    share_nw['id'])
-
-    def test_delete_in_use_by_consistency_group(self):
-        share_nw = fake_share_network.copy()
-        self.mock_object(db_api, 'share_network_get',
-                         mock.Mock(return_value=share_nw))
-        self.mock_object(db_api, 'count_consistency_groups_in_share_network',
-                         mock.Mock(return_value=2))
-
-        self.assertRaises(webob_exc.HTTPConflict,
-                          self.controller.delete,
-                          self.req,
-                          share_nw['id'])
-
-        db_api.share_network_get.assert_called_once_with(
+        db_api.share_get_all_by_share_network.assert_called_once_with(
             self.req.environ['manila.context'], share_nw['id'])
 
     def test_show_nominal(self):
