@@ -13,47 +13,35 @@
 #    License for the specific language governing permissions and limitations
 #    under the License.
 
+import mock
 from oslo_log import log
+import six
 
-from manila.common import constants
 from manila.share import driver
-from manila.tests import fake_service_instance
 
 LOG = log.getLogger(__name__)
 
 
 class FakeShareDriver(driver.ShareDriver):
-    """Fake share driver.
-
-    This fake driver can be also used as a test driver within a real
-    running manila-share instance. To activate it use this in manila.conf::
-
-        enabled_share_backends = fake
-
-        [fake]
-        driver_handles_share_servers = True
-        share_backend_name = fake
-        share_driver = manila.tests.fake_driver.FakeShareDriver
-
-    With it you basically mocked all backend driver calls but e.g. networking
-    will still be activated.
-    """
+    """Fake share driver."""
 
     def __init__(self, *args, **kwargs):
-        self._setup_service_instance_manager()
         super(FakeShareDriver, self).__init__([True, False], *args, **kwargs)
+        self.db = mock.Mock()
 
-    def _setup_service_instance_manager(self):
-        self.service_instance_manager = (
-            fake_service_instance.FakeServiceInstanceManager())
+        def share_network_update(*args, **kwargs):
+            pass
 
-    def manage_existing(self, share, driver_options, share_server=None):
+        self.db.share_network_update = mock.Mock(
+            side_effect=share_network_update)
+
+    def manage_existing(self, share, driver_options):
         LOG.debug("Fake share driver: manage")
         LOG.debug("Fake share driver: driver options: %s",
-                  str(driver_options))
+                  six.text_type(driver_options))
         return {'size': 1}
 
-    def unmanage(self, share, share_server=None):
+    def unmanage(self, share):
         LOG.debug("Fake share driver: unmanage")
 
     @property
@@ -74,11 +62,8 @@ class FakeShareDriver(driver.ShareDriver):
         return ['/fake/path', '/fake/path2']
 
     def create_share_from_snapshot(self, context, share, snapshot,
-                                   share_server=None, parent_share=None):
-        return {
-            'export_locations': ['/fake/path', '/fake/path2'],
-            'status': constants.STATUS_AVAILABLE,
-        }
+                                   share_server=None):
+        return ['/fake/path', '/fake/path2']
 
     def delete_share(self, context, share, share_server=None):
         pass
@@ -92,6 +77,9 @@ class FakeShareDriver(driver.ShareDriver):
     def deny_access(self, context, share, access, share_server=None):
         pass
 
+    def check_for_setup_error(self):
+        pass
+
     def get_share_stats(self, refresh=False):
         return None
 
@@ -112,15 +100,3 @@ class FakeShareDriver(driver.ShareDriver):
     def _verify_share_server_handling(self, driver_handles_share_servers):
         return super(FakeShareDriver, self)._verify_share_server_handling(
             driver_handles_share_servers)
-
-    def create_share_group(self, context, group_id, share_server=None):
-        pass
-
-    def delete_share_group(self, context, group_id, share_server=None):
-        pass
-
-    def get_share_status(self, share, share_server=None):
-        return {
-            'export_locations': ['/fake/path', '/fake/path2'],
-            'status': constants.STATUS_AVAILABLE,
-        }
