@@ -15,8 +15,10 @@
 
 
 from oslo_config import cfg
+from oslo_log import log
 
 CONF = cfg.CONF
+LOG = log.getLogger(__name__)
 
 
 class FakeVolume(object):
@@ -44,7 +46,7 @@ class FakeVolumeSnapshot(object):
 
 class API(object):
     """Fake Volume API."""
-    def get(self, *args, **kwargs):
+    def get(self, volume_id):
         pass
 
     def create_snapshot_force(self, *args, **kwargs):
@@ -59,9 +61,6 @@ class API(object):
     def create(self, *args, **kwargs):
         pass
 
-    def extend(self, *args, **kwargs):
-        pass
-
     def get_all(self, search_opts):
         pass
 
