@@ -20,7 +20,7 @@ def example_function_b():
     return 'Example function'
 
 
-class ExampleClassB(object):
+class ExampleClassB():
     def example_method(self):
         return 'Example method'
 
