@@ -42,8 +42,6 @@ class NovaNetworkPluginTest(test.TestCase):
             self.fake_context, self.share_server, share_network, count=0)
 
         self.assertEqual([], allocations)
-        self.assertTrue(hasattr(self.instance, 'label'))
-        self.assertEqual('user', self.instance.label)
 
     @ddt.data('flat', 'vlan')
     def test_allocate_network_get_one(self, net_type):
@@ -61,7 +59,7 @@ class NovaNetworkPluginTest(test.TestCase):
             gateway='20.0.0.1', gateway_v6=None,
             dhcp_server='20.0.0.2', broadcast='20.0.0.255',
             vpn_private_address='20.0.0.3', vpn_public_address='20.0.0.4',
-            dns1='20.0.0.5', dns2='20.0.0.6', vlan=None, mtu=1509)
+            dns1='20.0.0.5', dns2='20.0.0.6', vlan=None)
         if net_type == 'vlan':
             nova_net['vlan'] = 100
         self.mock_object(self.instance.nova_api, 'fixed_ip_reserve')
@@ -90,9 +88,8 @@ class NovaNetworkPluginTest(test.TestCase):
             self.instance.admin_context, expected_ip_address)
         self.instance.db.share_network_update.assert_called_once_with(
             self.fake_context, share_network['id'],
-            dict(cidr=nova_net['cidr'], gateway=nova_net['gateway'],
-                 ip_version=4, segmentation_id=nova_net['vlan'],
-                 network_type=net_type, mtu=1509))
+            dict(cidr=nova_net['cidr'], ip_version=4,
+                 segmentation_id=nova_net['vlan'], network_type=net_type))
         self.instance.db.network_allocations_get_by_ip_address.\
             assert_has_calls([
                 mock.call(self.fake_context, '20.0.0.7'),
@@ -117,7 +114,7 @@ class NovaNetworkPluginTest(test.TestCase):
             gateway='20.0.0.1', gateway_v6=None,
             dhcp_server='20.0.0.254', broadcast='20.0.0.255',
             vpn_private_address='20.0.0.3', vpn_public_address='20.0.0.4',
-            dns1='20.0.0.5', dns2='20.0.0.6', vlan=None, mtu=1509)
+            dns1='20.0.0.5', dns2='20.0.0.6', vlan=None)
         if net_type == 'vlan':
             nova_net['vlan'] = 100
         self.mock_object(self.instance.nova_api, 'fixed_ip_reserve')
@@ -150,9 +147,8 @@ class NovaNetworkPluginTest(test.TestCase):
             mock.call(self.instance.admin_context, expected_ip_address2)])
         self.instance.db.share_network_update.assert_called_once_with(
             self.fake_context, self.share_network['id'],
-            dict(cidr=nova_net['cidr'], gateway=nova_net['gateway'],
-                 ip_version=4, segmentation_id=nova_net['vlan'],
-                 network_type=net_type, mtu=1509))
+            dict(cidr=nova_net['cidr'], ip_version=4,
+                 segmentation_id=nova_net['vlan'], network_type=net_type))
         self.instance.db.network_allocations_get_by_ip_address.\
             assert_has_calls([
                 mock.call(self.fake_context, '20.0.0.2'),
@@ -170,7 +166,7 @@ class NovaNetworkPluginTest(test.TestCase):
             gateway='20.0.0.1', gateway_v6=None,
             dhcp_server='20.0.0.2', broadcast='20.0.0.255',
             vpn_private_address='20.0.0.3', vpn_public_address='20.0.0.4',
-            dns1='20.0.0.5', dns2='20.0.0.6', vlan=100, mtu=1509)
+            dns1='20.0.0.5', dns2='20.0.0.6', vlan=100)
         self.mock_object(
             self.instance.nova_api, 'network_get',
             mock.Mock(return_value=nova_net))
@@ -188,9 +184,8 @@ class NovaNetworkPluginTest(test.TestCase):
             self.instance.admin_context, self.share_network['nova_net_id'])
         self.instance.db.share_network_update.assert_called_once_with(
             self.fake_context, self.share_network['id'],
-            dict(cidr=nova_net['cidr'], gateway=nova_net['gateway'],
-                 ip_version=4, segmentation_id=nova_net['vlan'],
-                 network_type='vlan', mtu=1509))
+            dict(cidr=nova_net['cidr'], ip_version=4,
+                 segmentation_id=nova_net['vlan'], network_type='vlan'))
         self.assertEqual(
             248,
             self.instance.db.network_allocations_get_by_ip_address.call_count)
@@ -231,12 +226,12 @@ class NovaSingleNetworkPluginTest(test.TestCase):
         self.context = context.RequestContext(
             user_id='fake user', project_id='fake project', is_admin=False)
 
-    def _get_instance(self, label=None):
+    def _get_instance(self):
         nova_net_id = 'fake_nova_net_id'
         config_data = dict(
             DEFAULT=dict(nova_single_network_plugin_net_id=nova_net_id))
         with test_utils.create_temp_config_with_opts(config_data):
-            return plugin.NovaSingleNetworkPlugin(label=label)
+            return plugin.NovaSingleNetworkPlugin()
 
     def test_init_valid(self):
         nova_net_id = 'fake_nova_net_id'
@@ -292,24 +287,6 @@ class NovaSingleNetworkPluginTest(test.TestCase):
         instance._allocate_network.assert_called_once_with(
             self.context, self.share_server, share_network, count=2)
 
-    def test_allocate_network_with_admin_label(self):
-        instance = self._get_instance(label='admin')
-        allocations = ['foo', 'bar']
-        self.mock_object(instance.db, 'share_network_update')
-        self.mock_object(
-            instance, '_allocate_network', mock.Mock(return_value=allocations))
-        fake_share_network = {'nova_net_id': 'fake_nova_net_id'}
-
-        result = instance.allocate_network(
-            self.context, self.share_server, fake_share_network, count=2)
-
-        self.assertTrue(hasattr(instance, 'label'))
-        self.assertEqual('admin', instance.label)
-        self.assertEqual(allocations, result)
-        instance.db.share_network_update.assert_has_calls([])
-        instance._allocate_network.assert_called_once_with(
-            self.context, self.share_server, fake_share_network, count=2)
-
     def test_allocate_network_different_nova_net_id_is_set(self):
         instance = self._get_instance()
         share_network = dict(
