@@ -13,22 +13,16 @@
 # License for the specific language governing permissions and limitations
 # under the License.
 
-import ddt
 import mock
 from oslo_log import log
-from oslo_utils import units
-import six
 
-from manila.common import constants as const
 from manila import exception
 from manila.share.drivers.emc.plugins.isilon import isilon
-from manila.share.drivers.emc.plugins.isilon.isilon_api import SmbPermission
 from manila import test
 
 LOG = log.getLogger(__name__)
 
 
-@ddt.ddt
 class IsilonTest(test.TestCase):
     """Integration test for the Isilon Manila driver."""
 
@@ -53,7 +47,7 @@ class IsilonTest(test.TestCase):
                 return 'admin'
             elif value == 'emc_nas_password':
                 return 'a'
-            elif value == 'emc_nas_root_dir':
+            elif value == 'isilon_share_root_dir':
                 return '/ifs/manila-test'
             else:
                 return None
@@ -77,17 +71,16 @@ class IsilonTest(test.TestCase):
     def test_allow_access_single_ip_nfs(self):
         # setup
         share = {'name': self.SHARE_NAME, 'share_proto': 'NFS'}
-        access = {'access_type': 'ip', 'access_to': '10.1.1.10',
-                  'access_level': const.ACCESS_LEVEL_RW}
+        access = {'access_type': 'ip', 'access_to': '10.1.1.10'}
         share_server = None
         fake_export_id = 1
         self._mock_isilon_api.lookup_nfs_export.return_value = fake_export_id
-        self._mock_isilon_api.get_nfs_export.return_value = {
-            'clients': []}
+        self._mock_isilon_api.get_nfs_export.return_value = {'clients': []}
         self.assertFalse(self._mock_isilon_api.request.called)
 
         # call method under test
-        self.storage_connection.allow_access(self.mock_context, share, access,
+        self.storage_connection.allow_access(self.mock_emc_driver,
+                                             self.mock_context, share, access,
                                              share_server)
 
         # verify expected REST API call is executed
@@ -97,59 +90,7 @@ class IsilonTest(test.TestCase):
         self._mock_isilon_api.request.assert_called_once_with(
             'PUT', expected_url, data=expected_data)
 
-    def test_allow_access_with_nfs_readonly(self):
-        # setup
-        share = {'name': self.SHARE_NAME, 'share_proto': 'NFS'}
-        access = {'access_type': 'ip', 'access_to': '10.1.1.10',
-                  'access_level': const.ACCESS_LEVEL_RO}
-        fake_export_id = 70
-        self._mock_isilon_api.lookup_nfs_export.return_value = fake_export_id
-        self._mock_isilon_api.get_nfs_export.return_value = {
-            'read_only_clients': []}
-        self.assertFalse(self._mock_isilon_api.request.called)
-
-        self.storage_connection.allow_access(
-            self.mock_context, share, access, None)
-
-        # verify expected REST API call is executed
-        expected_url = (self.API_URL + '/platform/1/protocols/nfs/exports/' +
-                        six.text_type(fake_export_id))
-        expected_data = {'read_only_clients': ['10.1.1.10']}
-        self._mock_isilon_api.request.assert_called_once_with(
-            'PUT', expected_url, data=expected_data)
-
-    def test_allow_access_with_nfs_readwrite(self):
-        # setup
-        share = {'name': self.SHARE_NAME, 'share_proto': 'NFS'}
-        access = {'access_type': 'ip', 'access_to': '10.1.1.10',
-                  'access_level': const.ACCESS_LEVEL_RW}
-        fake_export_id = 70
-        self._mock_isilon_api.lookup_nfs_export.return_value = fake_export_id
-        self._mock_isilon_api.get_nfs_export.return_value = {
-            'clients': []}
-        self.assertFalse(self._mock_isilon_api.request.called)
-
-        self.storage_connection.allow_access(
-            self.mock_context, share, access, None)
-
-        # verify expected REST API call is executed
-        expected_url = (self.API_URL + '/platform/1/protocols/nfs/exports/' +
-                        six.text_type(fake_export_id))
-        expected_data = {'clients': ['10.1.1.10']}
-        self._mock_isilon_api.request.assert_called_once_with(
-            'PUT', expected_url, data=expected_data)
-
-    def test_allow_access_with_cifs_ip_readonly(self):
-        # Note: Driver does not currently support readonly access for "ip" type
-        share = {'name': self.SHARE_NAME, 'share_proto': 'CIFS'}
-        access = {'access_type': 'ip', 'access_to': '10.1.1.10',
-                  'access_level': const.ACCESS_LEVEL_RO}
-
-        self.assertRaises(
-            exception.InvalidShareAccess, self.storage_connection.allow_access,
-            self.mock_context, share, access, None)
-
-    def test_deny_access__ip_nfs_readwrite(self):
+    def test_deny_access_ip_nfs(self):
         """Verifies that an IP will be remove from a whitelist."""
         fake_export_id = 1
         self._mock_isilon_api.lookup_nfs_export.return_value = fake_export_id
@@ -159,13 +100,13 @@ class IsilonTest(test.TestCase):
             'clients': [ip_addr]}
 
         share = {'name': self.SHARE_NAME, 'share_proto': 'NFS'}
-        access = {'access_type': 'ip', 'access_to': ip_addr,
-                  'access_level': const.ACCESS_LEVEL_RW}
+        access = {'access_type': 'ip', 'access_to': ip_addr}
         share_server = None
 
         # call method under test
         self.assertFalse(self._mock_isilon_api.request.called)
-        self.storage_connection.deny_access(self.mock_context, share, access,
+        self.storage_connection.deny_access(self.mock_emc_driver,
+                                            self.mock_context, share, access,
                                             share_server)
 
         # verify that a call is made to remove an existing IP from the list
@@ -176,32 +117,6 @@ class IsilonTest(test.TestCase):
             'PUT', expected_url, data=expected_data
         )
 
-    def test_deny_access__nfs_ip_readonly(self):
-        fake_export_id = 1
-        self._mock_isilon_api.lookup_nfs_export.return_value = fake_export_id
-        # simulate an IP added to the whitelist
-        ip_addr = '10.0.0.4'
-        self._mock_isilon_api.get_nfs_export.return_value = {
-            'read_only_clients': [ip_addr]}
-
-        share = {'name': self.SHARE_NAME, 'share_proto': 'NFS'}
-        access = {'access_type': 'ip', 'access_to': ip_addr,
-                  'access_level': const.ACCESS_LEVEL_RO}
-        share_server = None
-
-        # call method under test
-        self.assertFalse(self._mock_isilon_api.request.called)
-        self.storage_connection.deny_access(self.mock_context, share, access,
-                                            share_server)
-
-        # verify that a call is made to remove an existing IP from the list
-        expected_url = (self.API_URL + '/platform/1/protocols/nfs/exports/' +
-                        six.text_type(fake_export_id))
-        expected_data = {'read_only_clients': []}
-        self._mock_isilon_api.request.assert_called_once_with(
-            'PUT', expected_url, data=expected_data
-        )
-
     def test_deny_access_ip_cifs(self):
         """Verifies that an IP will be remove from a whitelist.
 
@@ -217,10 +132,10 @@ class IsilonTest(test.TestCase):
         self.assertFalse(self._mock_isilon_api.request.called)
 
         # call method under test
-        access = {'access_type': 'ip', 'access_to': ip_addr,
-                  'access_level': const.ACCESS_LEVEL_RW}
+        access = {'access_type': 'ip', 'access_to': ip_addr}
         share_server = None
-        self.storage_connection.deny_access(self.mock_context, share, access,
+        self.storage_connection.deny_access(self.mock_emc_driver,
+                                            self.mock_context, share, access,
                                             share_server)
 
         # verify API call is made to remove IP is removed from whitelist
@@ -230,67 +145,44 @@ class IsilonTest(test.TestCase):
         self._mock_isilon_api.request.assert_called_once_with(
             'PUT', expected_url, data=expected_data)
 
-    def test_deny_access_nfs_invalid_access_type(self):
+    def test_deny_access_invalid_access_type(self):
         share = {'name': self.SHARE_NAME, 'share_proto': 'NFS'}
         access = {'access_type': 'foo_access_type', 'access_to': '10.0.0.1'}
 
         # This operation should return silently
         self.storage_connection.deny_access(
-            self.mock_context, share, access, None)
-
-    def test_deny_access_cifs_invalid_access_type(self):
-        share = {'name': self.SHARE_NAME, 'share_proto': 'CIFS'}
-        access = {'access_type': 'foo_access_type', 'access_to': '10.0.0.1'}
-
-        # This operation should return silently
-        self.storage_connection.deny_access(self.mock_context, share, access,
-                                            None)
+            self.mock_emc_driver, self.mock_context, share, access, None)
 
     def test_deny_access_invalid_share_protocol(self):
         share = {'name': self.SHARE_NAME, 'share_proto': 'FOO'}
-        access = {'access_type': 'ip', 'access_to': '10.0.0.1',
-                  'access_level': const.ACCESS_LEVEL_RW}
+        access = {'access_type': 'ip', 'access_to': '10.0.0.1'}
 
         # This operation should return silently
         self.storage_connection.deny_access(
-            self.mock_context, share, access, None)
+            self.mock_emc_driver, self.mock_context, share, access, None)
 
     def test_deny_access_nfs_export_does_not_exist(self):
         share = {'name': self.SHARE_NAME, 'share_proto': 'NFS'}
-        access = {'access_type': 'ip', 'access_to': '10.0.0.1',
-                  'access_level': const.ACCESS_LEVEL_RW}
+        access = {'access_type': 'ip', 'access_to': '10.0.0.1'}
         self._mock_isilon_api.lookup_nfs_export.return_value = 1
         self._mock_isilon_api.get_nfs_export.return_value = None
 
         self.assertRaises(
             exception.ShareBackendException,
-            self.storage_connection.deny_access,
+            self.storage_connection.deny_access, self.mock_emc_driver,
             self.mock_context, share, access, None
         )
 
     def test_deny_access_nfs_share_does_not_exist(self):
         share = {'name': self.SHARE_NAME, 'share_proto': 'NFS'}
-        access = {'access_type': 'ip', 'access_to': '10.0.0.1',
-                  'access_level': const.ACCESS_LEVEL_RW}
+        access = {'access_type': 'ip', 'access_to': '10.0.0.1'}
         self._mock_isilon_api.lookup_nfs_export.return_value = None
 
         self.assertRaises(
             exception.ShareBackendException,
-            self.storage_connection.deny_access,
+            self.storage_connection.deny_access, self.mock_emc_driver,
             self.mock_context, share, access, None)
 
-    def test_deny_access_nfs_share_does_not_contain_required_key(self):
-        share = {'name': self.SHARE_NAME, 'share_proto': 'NFS'}
-        access = {
-            'access_type': 'ip',
-            'access_to': '10.0.0.1',
-            'access_level': const.ACCESS_LEVEL_RW,
-        }
-        self._mock_isilon_api.get_nfs_export.return_value = {}
-        self.assertRaises(exception.ShareBackendException,
-                          self.storage_connection.deny_access,
-                          self.mock_context, share, access, None)
-
     def test_allow_access_multiple_ip_nfs(self):
         """Verifies adding an IP to a whitelist with pre-existing ips.
 
@@ -304,20 +196,18 @@ class IsilonTest(test.TestCase):
         new_allowed_ip = '10.7.7.8'
         self._mock_isilon_api.lookup_nfs_export.return_value = fake_export_id
         existing_ips = ['10.0.0.1', '10.1.1.1', '10.0.0.2']
-        export_json = {
-            'clients': existing_ips,
-            'access_level': const.ACCESS_LEVEL_RW,
-        }
+        export_json = {'clients': existing_ips}
         self._mock_isilon_api.get_nfs_export.return_value = export_json
         self.assertFalse(self._mock_isilon_api.request.called)
 
         # call method under test
         share = {'name': self.SHARE_NAME, 'share_proto': 'NFS'}
-        access = {'access_type': 'ip', 'access_to': new_allowed_ip,
-                  'access_level': const.ACCESS_LEVEL_RW}
+        access = {'access_type': 'ip', 'access_to': new_allowed_ip}
         share_server = None
-        self.storage_connection.allow_access(
-            self.mock_context, share, access, share_server)
+        self.storage_connection.allow_access(self.mock_emc_driver,
+                                             self.mock_context, share,
+                                             access,
+                                             share_server)
 
         # verify access rule is applied
         expected_url = (self.API_URL + '/platform/1/protocols/nfs/exports/' +
@@ -352,10 +242,10 @@ class IsilonTest(test.TestCase):
 
         # call method under test
         share = {'name': share_name, 'share_proto': 'CIFS'}
-        access = {'access_type': 'ip', 'access_to': new_allowed_ip,
-                  'access_level': const.ACCESS_LEVEL_RW}
+        access = {'access_type': 'ip', 'access_to': new_allowed_ip}
         share_server = None
-        self.storage_connection.allow_access(self.mock_context, share,
+        self.storage_connection.allow_access(self.mock_emc_driver,
+                                             self.mock_context, share,
                                              access,
                                              share_server)
 
@@ -379,15 +269,15 @@ class IsilonTest(test.TestCase):
         share_name = self.SHARE_NAME
         share = {'name': share_name, 'share_proto': 'CIFS'}
         allow_ip = '10.1.1.10'
-        access = {'access_type': 'ip', 'access_to': allow_ip,
-                  'access_level': const.ACCESS_LEVEL_RW}
+        access = {'access_type': 'ip', 'access_to': allow_ip}
         share_server = None
         self._mock_isilon_api.lookup_smb_share.return_value = {
             'name': share_name, 'host_acl': []}
         self.assertFalse(self._mock_isilon_api.request.called)
 
         # call method under test
-        self.storage_connection.allow_access(self.mock_context, share, access,
+        self.storage_connection.allow_access(self.mock_emc_driver,
+                                             self.mock_context, share, access,
                                              share_server)
 
         # verify access rule is applied
@@ -397,63 +287,6 @@ class IsilonTest(test.TestCase):
         self._mock_isilon_api.request.assert_called_once_with(
             'PUT', expected_url, data=expected_data)
 
-    @ddt.data(
-        ('foo', const.ACCESS_LEVEL_RW, SmbPermission.rw),
-        ('testuser', const.ACCESS_LEVEL_RO, SmbPermission.ro),
-    )
-    def test_allow_access_with_cifs_user(self, data):
-        # setup
-        share_name = self.SHARE_NAME
-        user, access_level, expected_smb_perm = data
-        share = {'name': share_name, 'share_proto': 'CIFS'}
-        access = {'access_type': 'user',
-                  'access_to': user,
-                  'access_level': access_level}
-
-        self.storage_connection.allow_access(self.mock_context, share,
-                                             access, None)
-
-        self._mock_isilon_api.smb_permissions_add.assert_called_once_with(
-            share_name, user, expected_smb_perm)
-
-    def test_allow_access_with_cifs_user_invalid_access_level(self):
-        share = {'name': self.SHARE_NAME, 'share_proto': 'CIFS'}
-        access = {
-            'access_type': 'user',
-            'access_to': 'foo',
-            'access_level': 'everything',
-        }
-
-        self.assertRaises(exception.InvalidShareAccess,
-                          self.storage_connection.allow_access,
-                          self.mock_context, share, access, None)
-
-    def test_allow_access_with_cifs_invalid_access_type(self):
-        share_name = self.SHARE_NAME
-        share = {'name': share_name, 'share_proto': 'CIFS'}
-        access = {'access_type': 'fooaccesstype',
-                  'access_to': 'testuser',
-                  'access_level': const.ACCESS_LEVEL_RW}
-
-        self.assertRaises(exception.InvalidShareAccess,
-                          self.storage_connection.allow_access,
-                          self.mock_context, share, access, None)
-
-    def test_deny_access_with_cifs_user(self):
-        share_name = self.SHARE_NAME
-        user_to_remove = 'testuser'
-        share = {'name': share_name, 'share_proto': 'CIFS'}
-        access = {'access_type': 'user',
-                  'access_to': user_to_remove,
-                  'access_level': const.ACCESS_LEVEL_RW}
-        self.assertFalse(self._mock_isilon_api.smb_permissions_remove.called)
-
-        self.storage_connection.deny_access(self.mock_context, share, access,
-                                            None)
-
-        self._mock_isilon_api.smb_permissions_remove.assert_called_with(
-            share_name, user_to_remove)
-
     def test_allow_access_invalid_access_type(self):
         # setup
         share_name = self.SHARE_NAME
@@ -463,8 +296,8 @@ class IsilonTest(test.TestCase):
 
         # verify method under test throws the expected exception
         self.assertRaises(
-            exception.InvalidShareAccess,
-            self.storage_connection.allow_access,
+            exception.ShareBackendException,
+            self.storage_connection.allow_access, self.mock_emc_driver,
             self.mock_context, share, access, None)
 
     def test_allow_access_invalid_share_protocol(self):
@@ -477,7 +310,7 @@ class IsilonTest(test.TestCase):
         # verify method under test throws the expected exception
         self.assertRaises(
             exception.InvalidShare, self.storage_connection.allow_access,
-            self.mock_context, share, access, None)
+            self.mock_emc_driver, self.mock_context, share, access, None)
 
     def test_create_share_nfs(self):
         share_path = self.SHARE_DIR
@@ -485,8 +318,9 @@ class IsilonTest(test.TestCase):
         self.assertFalse(self._mock_isilon_api.create_nfs_export.called)
 
         # create the share
-        share = {"name": self.SHARE_NAME, "share_proto": 'NFS', "size": 8}
-        location = self.storage_connection.create_share(self.mock_context,
+        share = {"name": self.SHARE_NAME, "share_proto": 'NFS'}
+        location = self.storage_connection.create_share(self.mock_emc_driver,
+                                                        self.mock_context,
                                                         share, None)
 
         # verify location and API call made
@@ -495,17 +329,14 @@ class IsilonTest(test.TestCase):
         self._mock_isilon_api.create_directory.assert_called_with(share_path)
         self._mock_isilon_api.create_nfs_export.assert_called_with(share_path)
 
-        # verify directory quota call made
-        self._mock_isilon_api.quota_create.assert_called_with(
-            share_path, 'directory', 8 * units.Gi)
-
     def test_create_share_cifs(self):
         self.assertFalse(self._mock_isilon_api.create_directory.called)
         self.assertFalse(self._mock_isilon_api.create_smb_share.called)
 
         # create the share
-        share = {"name": self.SHARE_NAME, "share_proto": 'CIFS', "size": 8}
-        location = self.storage_connection.create_share(self.mock_context,
+        share = {"name": self.SHARE_NAME, "share_proto": 'CIFS'}
+        location = self.storage_connection.create_share(self.mock_emc_driver,
+                                                        self.mock_context,
                                                         share, None)
 
         expected_location = '\\\\{0}\\{1}'.format(
@@ -516,16 +347,12 @@ class IsilonTest(test.TestCase):
         self._mock_isilon_api.create_smb_share.assert_called_once_with(
             self.SHARE_NAME, self.SHARE_DIR)
 
-        # verify directory quota call made
-        self._mock_isilon_api.quota_create.assert_called_with(
-            self.SHARE_DIR, 'directory', 8 * units.Gi)
-
     def test_create_share_invalid_share_protocol(self):
         share = {"name": self.SHARE_NAME, "share_proto": 'FOO_PROTOCOL'}
 
         self.assertRaises(
             exception.InvalidShare, self.storage_connection.create_share,
-            self.mock_context, share, share_server=None)
+            self.mock_emc_driver, self.mock_context, share, share_server=None)
 
     def test_create_share_nfs_backend_failure(self):
         share = {"name": self.SHARE_NAME, "share_proto": 'NFS'}
@@ -533,7 +360,7 @@ class IsilonTest(test.TestCase):
 
         self.assertRaises(
             exception.ShareBackendException,
-            self.storage_connection.create_share,
+            self.storage_connection.create_share, self.mock_emc_driver,
             self.mock_context, share, share_server=None)
 
     def test_create_snapshot(self):
@@ -542,7 +369,8 @@ class IsilonTest(test.TestCase):
         snapshot_name = "snapshot01"
         snapshot_path = '/ifs/home/admin'
         snapshot = {'name': snapshot_name, 'share_name': snapshot_path}
-        self.storage_connection.create_snapshot(self.mock_context, snapshot,
+        self.storage_connection.create_snapshot(self.mock_emc_driver,
+                                                self.mock_context, snapshot,
                                                 None)
 
         # verify the create snapshot API call is executed
@@ -559,9 +387,12 @@ class IsilonTest(test.TestCase):
 
         # execute method under test
         snapshot = {'name': snapshot_name, 'share_name': snapshot_path}
-        share = {"name": self.SHARE_NAME, "share_proto": 'NFS', 'size': 5}
+        share = {"name": self.SHARE_NAME, "share_proto": 'NFS'}
         location = self.storage_connection.create_share_from_snapshot(
-            self.mock_context, share, snapshot, None)
+            self.mock_emc_driver,
+            self.mock_context,
+            share, snapshot,
+            None)
 
         # verify NFS export created at expected location
         self._mock_isilon_api.create_nfs_export.assert_called_with(
@@ -574,10 +405,6 @@ class IsilonTest(test.TestCase):
             self.ISILON_ADDR, self.SHARE_DIR)
         self.assertEqual(expected_location, location)
 
-        # verify directory quota call made
-        self._mock_isilon_api.quota_create.assert_called_with(
-            self.SHARE_DIR, 'directory', 5 * units.Gi)
-
     def test_create_share_from_snapshot_cifs(self):
         # assertions
         self.assertFalse(self._mock_isilon_api.create_smb_share.called)
@@ -589,9 +416,10 @@ class IsilonTest(test.TestCase):
 
         # execute method under test
         snapshot = {'name': snapshot_name, 'share_name': snapshot_path}
-        share = {"name": new_share_name, "share_proto": 'CIFS', "size": 2}
+        share = {"name": new_share_name, "share_proto": 'CIFS'}
         location = self.storage_connection.create_share_from_snapshot(
-            self.mock_context, share, snapshot, None)
+            self.mock_emc_driver, self.mock_context, share, snapshot,
+            None)
 
         # verify call made to create new CIFS share
         self._mock_isilon_api.create_smb_share.assert_called_once_with(
@@ -602,11 +430,6 @@ class IsilonTest(test.TestCase):
                                                   new_share_name)
         self.assertEqual(expected_location, location)
 
-        # verify directory quota call made
-        expected_share_path = '{0}/{1}'.format(self.ROOT_DIR, new_share_name)
-        self._mock_isilon_api.quota_create.assert_called_with(
-            expected_share_path, 'directory', 2 * units.Gi)
-
     def test_delete_share_nfs(self):
         share = {"name": self.SHARE_NAME, "share_proto": 'NFS'}
         fake_share_num = 42
@@ -614,7 +437,8 @@ class IsilonTest(test.TestCase):
         self.assertFalse(self._mock_isilon_api.delete_nfs_share.called)
 
         # delete the share
-        self.storage_connection.delete_share(self.mock_context, share, None)
+        self.storage_connection.delete_share(self.mock_emc_driver,
+                                             self.mock_context, share, None)
 
         # verify share delete
         self._mock_isilon_api.delete_nfs_share.assert_called_with(
@@ -625,7 +449,8 @@ class IsilonTest(test.TestCase):
 
         # delete the share
         share = {"name": self.SHARE_NAME, "share_proto": 'CIFS'}
-        self.storage_connection.delete_share(self.mock_context, share, None)
+        self.storage_connection.delete_share(self.mock_emc_driver,
+                                             self.mock_context, share, None)
 
         # verify share deleted
         self._mock_isilon_api.delete_smb_share.assert_called_with(
@@ -635,7 +460,7 @@ class IsilonTest(test.TestCase):
         share = {"name": self.SHARE_NAME, "share_proto": 'FOO_PROTOCOL'}
         self.assertRaises(
             exception.InvalidShare, self.storage_connection.delete_share,
-            self.mock_context, share, None
+            self.mock_emc_driver, self.mock_context, share, None
         )
 
     def test_delete_nfs_share_backend_failure(self):
@@ -645,7 +470,7 @@ class IsilonTest(test.TestCase):
         self.assertRaises(
             exception.ShareBackendException,
             self.storage_connection.delete_share,
-            self.mock_context, share, None
+            self.mock_emc_driver, self.mock_context, share, None
         )
 
     def test_delete_nfs_share_share_does_not_exist(self):
@@ -654,7 +479,8 @@ class IsilonTest(test.TestCase):
 
         # verify the calling delete on a non-existent share returns and does
         # not throw exception
-        self.storage_connection.delete_share(self.mock_context, share, None)
+        self.storage_connection.delete_share(
+            self.mock_emc_driver, self.mock_context, share, None)
 
     def test_delete_cifs_share_backend_failure(self):
         share = {"name": self.SHARE_NAME, "share_proto": 'CIFS'}
@@ -663,7 +489,7 @@ class IsilonTest(test.TestCase):
         self.assertRaises(
             exception.ShareBackendException,
             self.storage_connection.delete_share,
-            self.mock_context, share, None
+            self.mock_emc_driver, self.mock_context, share, None
         )
 
     def test_delete_cifs_share_share_does_not_exist(self):
@@ -672,7 +498,8 @@ class IsilonTest(test.TestCase):
 
         # verify the calling delete on a non-existent share returns and does
         # not throw exception
-        self.storage_connection.delete_share(self.mock_context, share, None)
+        self.storage_connection.delete_share(
+            self.mock_emc_driver, self.mock_context, share, None)
 
     def test_delete_snapshot(self):
         # create a snapshot
@@ -682,7 +509,8 @@ class IsilonTest(test.TestCase):
         self.assertFalse(self._mock_isilon_api.delete_snapshot.called)
 
         # delete the created snapshot
-        self.storage_connection.delete_snapshot(self.mock_context, snapshot,
+        self.storage_connection.delete_snapshot(self.mock_emc_driver,
+                                                self.mock_context, snapshot,
                                                 None)
 
         # verify the API call was made to delete the snapshot
@@ -691,7 +519,8 @@ class IsilonTest(test.TestCase):
 
     def test_ensure_share(self):
         share = {"name": self.SHARE_NAME, "share_proto": 'CIFS'}
-        self.storage_connection.ensure_share(self.mock_context, share, None)
+        self.storage_connection.ensure_share(self.mock_emc_driver,
+                                             self.mock_context, share, None)
 
     @mock.patch(
         'manila.share.drivers.emc.plugins.isilon.isilon.isilon_api.IsilonApi',
@@ -743,21 +572,3 @@ class IsilonTest(test.TestCase):
         num = self.storage_connection.get_network_allocations_number()
 
         self.assertEqual(0, num)
-
-    def test_extend_share(self):
-        quota_id = 'abcdef'
-        new_share_size = 8
-        share = {
-            "name": self.SHARE_NAME,
-            "share_proto": 'NFS',
-            "size": new_share_size
-        }
-        self._mock_isilon_api.quota_get.return_value = {'id': quota_id}
-        self.assertFalse(self._mock_isilon_api.quota_set.called)
-
-        self.storage_connection.extend_share(share, new_share_size)
-
-        share_path = '{0}/{1}'.format(self.ROOT_DIR, self.SHARE_NAME)
-        expected_quota_size = new_share_size * units.Gi
-        self._mock_isilon_api.quota_set.assert_called_once_with(
-            share_path, 'directory', expected_quota_size)
