@@ -14,14 +14,17 @@
 #    under the License.
 
 import mock
+from oslo_log import log
 from stevedore import extension
 
-from manila import network
 from manila.share import configuration as conf
+from manila.share import driver
 from manila.share.drivers.emc import driver as emcdriver
 from manila.share.drivers.emc.plugins import base
 from manila import test
 
+LOG = log.getLogger(__name__)
+
 
 class FakeConnection(base.StorageConnection):
     def __init__(self, logger):
@@ -31,32 +34,41 @@ class FakeConnection(base.StorageConnection):
     def driver_handles_share_servers(self):
         return True
 
-    def create_share(self, context, share, share_server):
+    def create_share(self, emc_share_driver, context, share, share_server):
         """Is called to create share."""
+        pass
 
-    def create_snapshot(self, context, snapshot, share_server):
+    def create_snapshot(self, emc_share_driver, context,
+                        snapshot, share_server):
         """Is called to create snapshot."""
+        pass
 
-    def delete_share(self, context, share, share_server):
+    def delete_share(self, emc_share_driver, context, share, share_server):
         """Is called to remove share."""
+        pass
 
-    def extend_share(self, share, new_size, share_server):
-        """Is called to extend share."""
-
-    def delete_snapshot(self, context, snapshot, share_server):
+    def delete_snapshot(self, emc_share_driver, context,
+                        snapshot, share_server):
         """Is called to remove snapshot."""
+        pass
 
-    def ensure_share(self, context, share, share_server):
+    def ensure_share(self, emc_share_driver, context, share, share_server):
         """Invoked to sure that share is exported."""
+        pass
 
-    def allow_access(self, context, share, access, share_server):
+    def allow_access(self, emc_share_driver, context, share,
+                     access, share_server):
         """Allow access to the share."""
+        pass
 
-    def deny_access(self, context, share, access, share_server):
+    def deny_access(self, emc_share_driver, context, share,
+                    access, share_server):
         """Deny access to the share."""
+        pass
 
-    def raise_connect_error(self):
+    def raise_connect_error(self, emc_share_driver):
         """Check for setup error."""
+        pass
 
     def connect(self, emc_share_driver, context):
         """Any initialization the share driver does while starting."""
@@ -64,6 +76,7 @@ class FakeConnection(base.StorageConnection):
 
     def update_share_stats(self, stats_dict):
         """Add key/values to stats_dict."""
+        pass
 
     def get_network_allocations_number(self):
         """Returns number of network allocations for creating VIFs."""
@@ -71,14 +84,16 @@ class FakeConnection(base.StorageConnection):
 
     def setup_server(self, network_info, metadata=None):
         """Set up and configures share server with given network parameters."""
+        pass
 
     def teardown_server(self, server_details, security_services=None):
         """Teardown share server."""
+        pass
 
 FAKE_BACKEND = 'fake_backend'
 
 
-class FakeEMCExtensionManager(object):
+class FakeEMCExtensionManager():
     def __init__(self):
         self.extensions = []
         self.extensions.append(
@@ -98,7 +113,7 @@ class EMCShareFrameworkTestCase(test.TestCase):
         self.configuration.append_config_values = mock.Mock(return_value=0)
         self.configuration.share_backend_name = FAKE_BACKEND
         self.mock_object(self.configuration, 'safe_get', self._fake_safe_get)
-        self.mock_object(network, 'API')
+        self.mock_object(driver.ShareDriver, '__init__')
         self.driver = emcdriver.EMCShareDriver(
             configuration=self.configuration)
 
@@ -118,15 +133,10 @@ class EMCShareFrameworkTestCase(test.TestCase):
         data["vendor_name"] = 'EMC'
         data["driver_version"] = '1.0'
         data["storage_protocol"] = 'NFS_CIFS'
-        data['total_capacity_gb'] = 'unknown'
-        data['free_capacity_gb'] = 'unknown'
+        data['total_capacity_gb'] = 'infinite'
+        data['free_capacity_gb'] = 'infinite'
         data['reserved_percentage'] = 0
-        data['qos'] = False
-        data['pools'] = None
-        data['snapshot_support'] = True
-        data['replication_domain'] = None
-        data['filter_function'] = None
-        data['goodness_function'] = None
+        data['QoS_support'] = False
         self.assertEqual(data, self.driver._stats)
 
     def _fake_safe_get(self, value):
