@@ -25,10 +25,6 @@ from manila import test
 from manila.tests.share.drivers.hp import test_hp_3par_constants as constants
 
 from oslo_utils import units
-import six
-
-CLIENT_VERSION_MIN_OK = hp3parmediator.MIN_CLIENT_VERSION
-TEST_WSAPI_VERSION_STR = '30201292'
 
 
 @ddt.ddt
@@ -42,7 +38,6 @@ class HP3ParMediatorTestCase(test.TestCase):
 
         # Take over the hp3parclient module and stub the constructor.
         hp3parclient = sys.modules['hp3parclient']
-        hp3parclient.version_tuple = CLIENT_VERSION_MIN_OK
 
         # Need a fake constructor to return the fake client.
         # This is also be used for constructor error tests.
@@ -64,14 +59,6 @@ class HP3ParMediatorTestCase(test.TestCase):
             hp3par_san_ssh_port=constants.PORT,
             ssh_conn_timeout=constants.TIMEOUT)
 
-    def test_mediator_no_client(self):
-        """Test missing hp3parclient error."""
-
-        self.mock_object(hp3parmediator.HP3ParMediator, 'no_client', None)
-
-        self.assertRaises(exception.HP3ParInvalidClient,
-                          self.mediator.do_setup)
-
     def test_mediator_setup_client_init_error(self):
         """Any client init exceptions should result in a ManilaException."""
 
@@ -98,7 +85,7 @@ class HP3ParMediatorTestCase(test.TestCase):
     def test_mediator_vfs_exception(self):
         """Backend exception during get_vfs_name."""
 
-        self.init_mediator()
+        self.mediator.do_setup()
         self.mock_client.getvfs.side_effect = Exception('non-manila-except')
         self.assertRaises(exception.ManilaException,
                           self.mediator.get_vfs_name,
@@ -110,7 +97,7 @@ class HP3ParMediatorTestCase(test.TestCase):
 
     def test_mediator_vfs_not_found(self):
         """VFS not found."""
-        self.init_mediator()
+        self.mediator.do_setup()
         self.mock_client.getvfs.return_value = {'total': 0}
         self.assertRaises(exception.ManilaException,
                           self.mediator.get_vfs_name,
@@ -123,10 +110,6 @@ class HP3ParMediatorTestCase(test.TestCase):
     def init_mediator(self):
         """Basic mediator setup for re-use with tests that need one."""
 
-        self.mock_client.getWsApiVersion.return_value = {
-            'build': TEST_WSAPI_VERSION_STR,
-        }
-
         self.mock_client.getvfs.return_value = {
             'total': 1,
             'members': [{'vfsname': constants.EXPECTED_VFS}]
@@ -153,117 +136,22 @@ class HP3ParMediatorTestCase(test.TestCase):
                                     constants.SAN_PASSWORD,
                                     port=constants.PORT,
                                     conn_timeout=constants.TIMEOUT),
-            mock.call.getWsApiVersion(),
-            mock.call.debug_rest(constants.EXPECTED_HP_DEBUG)
+            mock.call.ssh.set_debug_flag(constants.EXPECTED_HP_DEBUG)
         ]
         self.mock_client.assert_has_calls(expected_calls)
 
-    def test_mediator_client_login_error(self):
-        """Test exception during login."""
-        self.init_mediator()
-
-        self.mock_client.login.side_effect = constants.FAKE_EXCEPTION
-
-        self.assertRaises(exception.ShareBackendException,
-                          self.mediator._wsapi_login)
-
-        expected_calls = [mock.call.login(constants.USERNAME,
-                                          constants.PASSWORD)]
-        self.mock_client.assert_has_calls(expected_calls)
-
-    def test_mediator_client_logout_error(self):
-        """Test exception during logout."""
-        self.init_mediator()
-
-        mock_log = self.mock_object(hp3parmediator, 'LOG')
-        fake_exception = constants.FAKE_EXCEPTION
-        self.mock_client.http.unauthenticate.side_effect = fake_exception
-
-        self.mediator._wsapi_logout()
-
-        # Warning is logged (no exception thrown).
-        self.assertTrue(mock_log.warning.called)
-        expected_calls = [mock.call.http.unauthenticate()]
-        self.mock_client.assert_has_calls(expected_calls)
-
-    def test_mediator_client_version_unsupported(self):
-        """Try a client with version less than minimum."""
-
-        self.hp3parclient = sys.modules['hp3parclient']
-        self.hp3parclient.version_tuple = (CLIENT_VERSION_MIN_OK[0],
-                                           CLIENT_VERSION_MIN_OK[1],
-                                           CLIENT_VERSION_MIN_OK[2] - 1)
-        self.assertRaises(exception.HP3ParInvalidClient,
-                          self.init_mediator)
-
-    def test_mediator_client_version_supported(self):
-        """Try a client with a version greater than the minimum."""
-
-        # The setup success already tests the min version.  Try version > min.
-        self.hp3parclient = sys.modules['hp3parclient']
-        self.hp3parclient.version_tuple = (CLIENT_VERSION_MIN_OK[0],
-                                           CLIENT_VERSION_MIN_OK[1],
-                                           CLIENT_VERSION_MIN_OK[2] + 1)
-        self.init_mediator()
-        expected_calls = [
-            mock.call.setSSHOptions(constants.EXPECTED_IP_1234,
-                                    constants.SAN_LOGIN,
-                                    constants.SAN_PASSWORD,
-                                    port=constants.PORT,
-                                    conn_timeout=constants.TIMEOUT),
-            mock.call.getWsApiVersion(),
-            mock.call.debug_rest(constants.EXPECTED_HP_DEBUG)
-        ]
-        self.mock_client.assert_has_calls(expected_calls)
-
-    def test_mediator_client_version_exception(self):
-        """Test the getWsApiVersion exception handling."""
-
-        self.mock_client.getWsApiVersion.side_effect = constants.FAKE_EXCEPTION
-        self.assertRaises(exception.ShareBackendException,
-                          self.init_mediator)
-
-    def test_mediator_client_version_bad_return_value(self):
-        """Test the getWsApiVersion exception handling with bad value."""
-
-        # Expecting a dict with 'build' in it.  This would fail badly.
-        self.mock_client.getWsApiVersion.return_value = 'bogus'
-        self.assertRaises(exception.ShareBackendException,
-                          self.mediator.do_setup)
-
     def get_expected_calls_for_create_share(self,
-                                            client_version,
                                             expected_fpg,
                                             expected_vfsname,
                                             expected_protocol,
-                                            extra_specs,
                                             expected_project_id,
                                             expected_share_id):
         expected_sharedir = expected_share_id
 
-        createfshare_kwargs = dict(comment=mock.ANY,
-                                   fpg=expected_fpg,
-                                   sharedir=expected_sharedir,
-                                   fstore=expected_project_id)
-
         if expected_protocol == constants.NFS_LOWER:
-
-            createfshare_kwargs['clientip'] = '127.0.0.1'
-
-            # Options from extra-specs.
-            opt_string = extra_specs.get('hp3par:nfs_options', [])
-            opt_list = opt_string.split(',')
-            # Options that the mediator adds.
-            nfs_options = ['rw', 'no_root_squash', 'insecure']
-            nfs_options += opt_list
-            expected_options = ','.join(nfs_options)
-
-            createfshare_kwargs['options'] = OptionMatcher(
-                self.assertListEqual, expected_options)
-
             expected_calls = [
                 mock.call.createfstore(expected_vfsname, expected_project_id,
-                                       comment=mock.ANY,
+                                       comment='OpenStack Manila fstore',
                                        fpg=expected_fpg),
                 mock.call.getfsquota(fpg=expected_fpg,
                                      vfs=expected_vfsname,
@@ -275,30 +163,19 @@ class HP3ParMediatorTestCase(test.TestCase):
                                      fstore=expected_project_id),
                 mock.call.createfshare(expected_protocol, expected_vfsname,
                                        expected_share_id,
-                                       **createfshare_kwargs),
+                                       comment='OpenStack Manila fshare',
+                                       fpg=expected_fpg,
+                                       sharedir=expected_sharedir,
+                                       clientip='127.0.0.1',
+                                       options='rw,no_root_squash,insecure',
+                                       fstore=expected_project_id),
                 mock.call.getfshare(expected_protocol, expected_share_id,
                                     fpg=expected_fpg, vfs=expected_vfsname,
                                     fstore=expected_project_id)]
         else:
-            createfshare_kwargs['allowip'] = '127.0.0.1'
-
-            if client_version < hp3parmediator.MIN_SMB_CA_VERSION:
-                smb_opts = (hp3parmediator.ACCESS_BASED_ENUM,
-                            hp3parmediator.CACHE)
-            else:
-                smb_opts = (hp3parmediator.ACCESS_BASED_ENUM,
-                            hp3parmediator.CONTINUOUS_AVAIL,
-                            hp3parmediator.CACHE)
-
-            for smb_opt in smb_opts:
-                opt_value = extra_specs.get('hp3par:smb_%s' % smb_opt)
-                if opt_value:
-                    opt_key = hp3parmediator.SMB_EXTRA_SPECS_MAP[smb_opt]
-                    createfshare_kwargs[opt_key] = opt_value
-
             expected_calls = [
                 mock.call.createfstore(expected_vfsname, expected_project_id,
-                                       comment=mock.ANY,
+                                       comment='OpenStack Manila fstore',
                                        fpg=expected_fpg),
                 mock.call.getfsquota(fpg=expected_fpg,
                                      vfs=expected_vfsname,
@@ -310,35 +187,17 @@ class HP3ParMediatorTestCase(test.TestCase):
                                      fstore=expected_project_id),
                 mock.call.createfshare(expected_protocol, expected_vfsname,
                                        expected_share_id,
-                                       **createfshare_kwargs),
+                                       comment='OpenStack Manila fshare',
+                                       fpg=expected_fpg,
+                                       sharedir=expected_sharedir,
+                                       allowip='127.0.0.1',
+                                       fstore=expected_project_id),
                 mock.call.getfshare(expected_protocol, expected_share_id,
                                     fpg=expected_fpg, vfs=expected_vfsname,
                                     fstore=expected_project_id)]
         return expected_calls
 
-    @staticmethod
-    def _build_smb_extra_specs(**kwargs):
-        extra_specs = {'driver_handles_share_servers': False}
-        for k, v in kwargs.items():
-            extra_specs['hp3par:smb_%s' % k] = v
-        return extra_specs
-
-    @ddt.data(((3, 2, 1), None, None, None),
-              ((3, 2, 1), 'true', None, None),
-              ((3, 2, 1), None, 'false', None),
-              ((3, 2, 1), None, 'false', None),
-              ((3, 2, 1), None, None, 'optimized'),
-              ((3, 2, 1), 'true', 'false', 'optimized'),
-              ((3, 2, 2), None, None, None),
-              ((3, 2, 2), 'true', None, None),
-              ((3, 2, 2), None, 'false', None),
-              ((3, 2, 2), None, 'false', None),
-              ((3, 2, 2), None, None, 'optimized'),
-              ((3, 2, 2), 'true', 'false', 'optimized'))
-    @ddt.unpack
-    def test_mediator_create_cifs_share(self, client_version, abe, ca, cache):
-        self.hp3parclient = sys.modules['hp3parclient']
-        self.hp3parclient.version_tuple = client_version
+    def test_mediator_create_cifs_share(self):
         self.init_mediator()
 
         self.mock_client.getfshare.return_value = {
@@ -347,16 +206,15 @@ class HP3ParMediatorTestCase(test.TestCase):
             'members': [{'shareName': constants.EXPECTED_SHARE_NAME}]
         }
 
-        self.mock_client.getfsquota.return_value = constants.GET_FSQUOTA
-
-        extra_specs = self._build_smb_extra_specs(access_based_enum=abe,
-                                                  continuous_avail=ca,
-                                                  cache=cache)
+        self.mock_client.getfsquota.return_value = {
+            'message': None,
+            'total': 1,
+            'members': [{'hardBlock': '1024', 'softBlock': '1024'}]
+        }
 
         location = self.mediator.create_share(constants.EXPECTED_PROJECT_ID,
                                               constants.EXPECTED_SHARE_ID,
                                               constants.CIFS,
-                                              extra_specs,
                                               constants.EXPECTED_FPG,
                                               constants.EXPECTED_VFS,
                                               size=constants.EXPECTED_SIZE_1)
@@ -364,43 +222,15 @@ class HP3ParMediatorTestCase(test.TestCase):
         self.assertEqual(constants.EXPECTED_SHARE_NAME, location)
 
         expected_calls = self.get_expected_calls_for_create_share(
-            client_version,
             constants.EXPECTED_FPG,
             constants.EXPECTED_VFS,
             constants.SMB_LOWER,
-            extra_specs,
             constants.EXPECTED_PROJECT_ID,
             constants.EXPECTED_SHARE_ID)
 
         self.mock_client.assert_has_calls(expected_calls)
 
-    @ddt.data('ro',
-              'rw',
-              'no_root_squash',
-              'root_squash',
-              'secure',
-              'insecure',
-              'hide,insecure,no_wdelay,ro,bogus,root_squash,test')
-    def test_mediator_create_nfs_share_bad_options(self, nfs_options):
-        self.init_mediator()
-
-        extra_specs = {'hp3par:nfs_options': nfs_options}
-
-        self.assertRaises(exception.InvalidInput,
-                          self.mediator.create_share,
-                          constants.EXPECTED_PROJECT_ID,
-                          constants.EXPECTED_SHARE_ID,
-                          constants.NFS.lower(),
-                          extra_specs,
-                          constants.EXPECTED_FPG,
-                          constants.EXPECTED_VFS,
-                          size=constants.EXPECTED_SIZE_1)
-
-        self.assertFalse(self.mock_client.createfshare.called)
-
-    @ddt.data('sync',
-              'no_wdelay,sec=sys,hide,sync')
-    def test_mediator_create_nfs_share(self, nfs_options):
+    def test_mediator_create_nfs_share(self):
         self.init_mediator()
 
         self.mock_client.getfshare.return_value = {
@@ -409,14 +239,15 @@ class HP3ParMediatorTestCase(test.TestCase):
             'members': [{'sharePath': constants.EXPECTED_SHARE_PATH}]
         }
 
-        self.mock_client.getfsquota.return_value = constants.GET_FSQUOTA
-
-        extra_specs = {'hp3par:nfs_options': nfs_options}
+        self.mock_client.getfsquota.return_value = {
+            'message': None,
+            'total': 1,
+            'members': [{'hardBlock': '1024', 'softBlock': '1024'}]
+        }
 
         location = self.mediator.create_share(constants.EXPECTED_PROJECT_ID,
                                               constants.EXPECTED_SHARE_ID,
                                               constants.NFS.lower(),
-                                              extra_specs,
                                               constants.EXPECTED_FPG,
                                               constants.EXPECTED_VFS,
                                               size=constants.EXPECTED_SIZE_1)
@@ -424,49 +255,14 @@ class HP3ParMediatorTestCase(test.TestCase):
         self.assertEqual(constants.EXPECTED_SHARE_PATH, location)
 
         expected_calls = self.get_expected_calls_for_create_share(
-            hp3parmediator.MIN_CLIENT_VERSION,
             constants.EXPECTED_FPG,
             constants.EXPECTED_VFS,
             constants.NFS.lower(),
-            extra_specs,
             constants.EXPECTED_PROJECT_ID,
             constants.EXPECTED_SHARE_ID)
 
         self.mock_client.assert_has_calls(expected_calls)
 
-    def test_mediator_create_nfs_share_get_exception(self):
-        self.init_mediator()
-
-        self.mock_client.getfshare.side_effect = constants.FAKE_EXCEPTION
-        self.mock_client.getfsquota.return_value = constants.GET_FSQUOTA
-
-        self.assertRaises(exception.ShareBackendException,
-                          self.mediator.create_share,
-                          constants.EXPECTED_PROJECT_ID,
-                          constants.EXPECTED_SHARE_ID,
-                          constants.NFS.lower(),
-                          constants.EXPECTED_EXTRA_SPECS,
-                          constants.EXPECTED_FPG,
-                          constants.EXPECTED_VFS,
-                          size=constants.EXPECTED_SIZE_1)
-
-    @ddt.data(0, 2)
-    def test_mediator_create_nfs_share_get_fail(self, count):
-        self.init_mediator()
-
-        self.mock_client.getfshare.return_value = {'total': count}
-        self.mock_client.getfsquota.return_value = constants.GET_FSQUOTA
-
-        self.assertRaises(exception.ShareBackendException,
-                          self.mediator.create_share,
-                          constants.EXPECTED_PROJECT_ID,
-                          constants.EXPECTED_SHARE_ID,
-                          constants.NFS.lower(),
-                          constants.EXPECTED_EXTRA_SPECS,
-                          constants.EXPECTED_FPG,
-                          constants.EXPECTED_VFS,
-                          size=constants.EXPECTED_SIZE_1)
-
     def test_mediator_create_cifs_share_from_snapshot(self):
         self.init_mediator()
 
@@ -480,9 +276,9 @@ class HP3ParMediatorTestCase(test.TestCase):
         location = self.mediator.create_share_from_snapshot(
             constants.EXPECTED_SHARE_ID,
             constants.CIFS,
-            constants.EXPECTED_EXTRA_SPECS,
             constants.EXPECTED_PROJECT_ID,
             constants.EXPECTED_SHARE_ID,
+            constants.NFS,
             constants.EXPECTED_SNAP_ID,
             constants.EXPECTED_FPG,
             constants.EXPECTED_VFS)
@@ -526,9 +322,9 @@ class HP3ParMediatorTestCase(test.TestCase):
         location = self.mediator.create_share_from_snapshot(
             constants.EXPECTED_SHARE_ID,
             constants.NFS,
-            constants.EXPECTED_EXTRA_SPECS,
             constants.EXPECTED_PROJECT_ID,
             constants.EXPECTED_SHARE_ID,
+            constants.NFS,
             constants.EXPECTED_SNAP_ID,
             constants.EXPECTED_FPG,
             constants.EXPECTED_VFS)
@@ -573,9 +369,9 @@ class HP3ParMediatorTestCase(test.TestCase):
                           self.mediator.create_share_from_snapshot,
                           constants.EXPECTED_SHARE_ID,
                           constants.NFS,
-                          constants.EXPECTED_EXTRA_SPECS,
                           constants.EXPECTED_PROJECT_ID,
                           constants.EXPECTED_SHARE_ID,
+                          constants.NFS,
                           constants.EXPECTED_SNAP_ID,
                           constants.EXPECTED_FPG,
                           constants.EXPECTED_VFS)
@@ -881,11 +677,9 @@ class HP3ParMediatorTestCase(test.TestCase):
                                       reclaimStrategy='maxspeed'),
         ]
         self.mock_client.assert_has_calls(expected_calls)
-        self.assertTrue(mock_log.debug.called)
-        self.assertTrue(mock_log.exception.called)
+        mock_log.assert_has_calls(mock.call.exception(mock.ANY))
 
-    @ddt.data(six.text_type('volname.1'), ['volname.2', 'volname.3'])
-    def test_mediator_get_fpg_status(self, volume_name_or_list):
+    def test_mediator_get_capacity(self):
         """Mediator converts client stats to capacity result."""
         expected_capacity = constants.EXPECTED_SIZE_2
         expected_free = constants.EXPECTED_SIZE_1
@@ -896,120 +690,24 @@ class HP3ParMediatorTestCase(test.TestCase):
             'members': [
                 {
                     'capacityKiB': str(expected_capacity * units.Mi),
-                    'availCapacityKiB': str(expected_free * units.Mi),
-                    'vvs': volume_name_or_list,
+                    'availCapacityKiB': str(expected_free * units.Mi)
                 }
             ],
             'message': None,
         }
 
-        self.mock_client.getfsquota.return_value = {
-            'total': 3,
-            'members': [
-                {'hardBlock': 1 * units.Ki},
-                {'hardBlock': 2 * units.Ki},
-                {'hardBlock': 3 * units.Ki},
-            ],
-            'message': None,
-        }
-
-        self.mock_client.getVolume.return_value = {
-            'provisioningType': hp3parmediator.DEDUPE}
-
         expected_result = {
             'free_capacity_gb': expected_free,
-            'hp3par_flash_cache': False,
-            'dedupe': True,
-            'thin_provisioning': True,
             'total_capacity_gb': expected_capacity,
-            'provisioned_capacity_gb': 6,
         }
 
-        result = self.mediator.get_fpg_status(constants.EXPECTED_FPG)
+        result = self.mediator.get_capacity(constants.EXPECTED_FPG)
         self.assertEqual(expected_result, result)
         expected_calls = [
             mock.call.getfpg(constants.EXPECTED_FPG)
         ]
         self.mock_client.assert_has_calls(expected_calls)
 
-    def test_mediator_get_fpg_status_exception(self):
-        """Exception during get_fpg_status call to getfpg."""
-        self.init_mediator()
-
-        self.mock_client.getfpg.side_effect = constants.FAKE_EXCEPTION
-
-        self.assertRaises(exception.ShareBackendException,
-                          self.mediator.get_fpg_status,
-                          constants.EXPECTED_FPG)
-
-        expected_calls = [mock.call.getfpg(constants.EXPECTED_FPG)]
-        self.mock_client.assert_has_calls(expected_calls)
-
-    def test_mediator_get_fpg_status_error(self):
-        """Unexpected result from getfpg during get_fpg_status."""
-        self.init_mediator()
-
-        self.mock_client.getfpg.return_value = {'total': 0}
-
-        self.assertRaises(exception.ShareBackendException,
-                          self.mediator.get_fpg_status,
-                          constants.EXPECTED_FPG)
-
-        expected_calls = [mock.call.getfpg(constants.EXPECTED_FPG)]
-        self.mock_client.assert_has_calls(expected_calls)
-
-    def test_mediator_get_fpg_status_bad_prov_type(self):
-        """Test get_fpg_status handling of unexpected provisioning type."""
-        self.init_mediator()
-
-        self.mock_client.getfpg.return_value = {
-            'total': 1,
-            'members': [
-                {
-                    'capacityKiB': '1',
-                    'availCapacityKiB': '1',
-                    'vvs': 'foo',
-                }
-            ],
-            'message': None,
-        }
-        self.mock_client.getVolume.return_value = {
-            'provisioningType': 'BOGUS'}
-
-        self.assertRaises(exception.ShareBackendException,
-                          self.mediator.get_fpg_status,
-                          constants.EXPECTED_FPG)
-
-        expected_calls = [mock.call.getfpg(constants.EXPECTED_FPG)]
-        self.mock_client.assert_has_calls(expected_calls)
-
-    def test_mediator_get_provisioned_error(self):
-        """Test error during get provisioned GB."""
-        self.init_mediator()
-
-        error_return = {'message': 'Some error happened.'}
-        self.mock_client.getfsquota.return_value = error_return
-
-        self.assertRaises(exception.ShareBackendException,
-                          self.mediator.get_provisioned_gb,
-                          constants.EXPECTED_FPG)
-
-        expected_calls = [mock.call.getfsquota(fpg=constants.EXPECTED_FPG)]
-        self.mock_client.assert_has_calls(expected_calls)
-
-    def test_mediator_get_provisioned_exception(self):
-        """Test exception during get provisioned GB."""
-        self.init_mediator()
-
-        self.mock_client.getfsquota.side_effect = constants.FAKE_EXCEPTION
-
-        self.assertRaises(exception.ShareBackendException,
-                          self.mediator.get_provisioned_gb,
-                          constants.EXPECTED_FPG)
-
-        expected_calls = [mock.call.getfsquota(fpg=constants.EXPECTED_FPG)]
-        self.mock_client.assert_has_calls(expected_calls)
-
     def test_mediator_allow_user_access_cifs(self):
         """"Allow user access to cifs share."""
         self.init_mediator()
@@ -1428,217 +1126,3 @@ class HP3ParMediatorTestCase(test.TestCase):
             fstore=constants.EXPECTED_PROJECT_ID)
 
         self.assertEqual(expected_result, result)
-
-    def test_fsip_exists(self):
-        self.init_mediator()
-
-        # Make the result member a superset of the fsip items.
-        fsip_plus = constants.EXPECTED_FSIP.copy()
-        fsip_plus.update({'k': 'v', 'k2': 'v2'})
-
-        self.mock_client.getfsip.return_value = {
-            'total': 3,
-            'members': [{'bogus1': 1}, fsip_plus, {'bogus2': '2'}]
-        }
-
-        self.assertTrue(self.mediator.fsip_exists(constants.EXPECTED_FSIP))
-
-        self.mock_client.getfsip.assert_called_once_with(
-            constants.EXPECTED_VFS,
-            fpg=constants.EXPECTED_FPG)
-
-    def test_fsip_does_not_exist(self):
-        self.init_mediator()
-
-        self.mock_client.getfsip.return_value = {
-            'total': 3,
-            'members': [{'bogus1': 1}, constants.OTHER_FSIP, {'bogus2': '2'}]
-        }
-
-        self.assertFalse(self.mediator.fsip_exists(constants.EXPECTED_FSIP))
-
-        self.mock_client.getfsip.assert_called_once_with(
-            constants.EXPECTED_VFS,
-            fpg=constants.EXPECTED_FPG)
-
-    def test_fsip_exists_exception(self):
-        self.init_mediator()
-
-        class FakeException(Exception):
-            pass
-
-        self.mock_client.getfsip.side_effect = FakeException()
-
-        self.assertRaises(exception.ShareBackendException,
-                          self.mediator.fsip_exists,
-                          constants.EXPECTED_FSIP)
-
-        self.mock_client.getfsip.assert_called_once_with(
-            constants.EXPECTED_VFS,
-            fpg=constants.EXPECTED_FPG)
-
-    def test_create_fsip_success(self):
-        self.init_mediator()
-
-        # Make the result member a superset of the fsip items.
-        fsip_plus = constants.EXPECTED_FSIP.copy()
-        fsip_plus.update({'k': 'v', 'k2': 'v2'})
-
-        self.mock_client.getfsip.return_value = {
-            'total': 3,
-            'members': [{'bogus1': 1}, fsip_plus, {'bogus2': '2'}]
-        }
-
-        self.mediator.create_fsip(constants.EXPECTED_IP_1234,
-                                  constants.EXPECTED_SUBNET,
-                                  constants.EXPECTED_VLAN_TAG,
-                                  constants.EXPECTED_FPG,
-                                  constants.EXPECTED_VFS)
-
-        self.mock_client.getfsip.assert_called_once_with(
-            constants.EXPECTED_VFS,
-            fpg=constants.EXPECTED_FPG)
-
-        expected_calls = [
-            mock.call.createfsip(constants.EXPECTED_IP_1234,
-                                 constants.EXPECTED_SUBNET,
-                                 constants.EXPECTED_VFS,
-                                 fpg=constants.EXPECTED_FPG,
-                                 vlantag=constants.EXPECTED_VLAN_TAG),
-            mock.call.getfsip(constants.EXPECTED_VFS,
-                              fpg=constants.EXPECTED_FPG),
-        ]
-        self.mock_client.assert_has_calls(expected_calls)
-
-    def test_create_fsip_exception(self):
-        self.init_mediator()
-
-        class FakeException(Exception):
-            pass
-
-        self.mock_client.createfsip.side_effect = FakeException()
-
-        self.assertRaises(exception.ShareBackendException,
-                          self.mediator.create_fsip,
-                          constants.EXPECTED_IP_1234,
-                          constants.EXPECTED_SUBNET,
-                          constants.EXPECTED_VLAN_TAG,
-                          constants.EXPECTED_FPG,
-                          constants.EXPECTED_VFS)
-
-        self.mock_client.createfsip.assert_called_once_with(
-            constants.EXPECTED_IP_1234,
-            constants.EXPECTED_SUBNET,
-            constants.EXPECTED_VFS,
-            fpg=constants.EXPECTED_FPG,
-            vlantag=constants.EXPECTED_VLAN_TAG)
-
-    def test_create_fsip_get_none(self):
-        self.init_mediator()
-
-        self.mock_client.getfsip.return_value = {'members': []}
-
-        self.assertRaises(exception.ShareBackendException,
-                          self.mediator.create_fsip,
-                          constants.EXPECTED_IP_1234,
-                          constants.EXPECTED_SUBNET,
-                          constants.EXPECTED_VLAN_TAG,
-                          constants.EXPECTED_FPG,
-                          constants.EXPECTED_VFS)
-
-        expected_calls = [
-            mock.call.createfsip(constants.EXPECTED_IP_1234,
-                                 constants.EXPECTED_SUBNET,
-                                 constants.EXPECTED_VFS,
-                                 fpg=constants.EXPECTED_FPG,
-                                 vlantag=constants.EXPECTED_VLAN_TAG),
-            mock.call.getfsip(constants.EXPECTED_VFS,
-                              fpg=constants.EXPECTED_FPG),
-        ]
-        self.mock_client.assert_has_calls(expected_calls)
-
-    def test_remove_fsip_success(self):
-        self.init_mediator()
-
-        self.mock_client.getfsip.return_value = {
-            'members': [constants.OTHER_FSIP]
-        }
-
-        self.mediator.remove_fsip(constants.EXPECTED_IP_1234,
-                                  constants.EXPECTED_FPG,
-                                  constants.EXPECTED_VFS)
-
-        expected_calls = [
-            mock.call.removefsip(constants.EXPECTED_VFS,
-                                 constants.EXPECTED_IP_1234,
-                                 fpg=constants.EXPECTED_FPG),
-            mock.call.getfsip(constants.EXPECTED_VFS,
-                              fpg=constants.EXPECTED_FPG),
-        ]
-        self.mock_client.assert_has_calls(expected_calls)
-
-    @ddt.data(('ip', None),
-              ('ip', ''),
-              (None, 'vfs'),
-              ('', 'vfs'),
-              (None, None),
-              ('', ''))
-    @ddt.unpack
-    def test_remove_fsip_without_ip_or_vfs(self, ip, vfs):
-        self.init_mediator()
-        self.mediator.remove_fsip(ip, constants.EXPECTED_FPG, vfs)
-        self.assertFalse(self.mock_client.removefsip.called)
-
-    def test_remove_fsip_not_gone(self):
-        self.init_mediator()
-
-        self.mock_client.getfsip.return_value = {
-            'members': [constants.EXPECTED_FSIP]
-        }
-
-        self.assertRaises(exception.ShareBackendException,
-                          self.mediator.remove_fsip,
-                          constants.EXPECTED_IP_1234,
-                          constants.EXPECTED_FPG,
-                          constants.EXPECTED_VFS)
-
-        expected_calls = [
-            mock.call.removefsip(constants.EXPECTED_VFS,
-                                 constants.EXPECTED_IP_1234,
-                                 fpg=constants.EXPECTED_FPG),
-            mock.call.getfsip(constants.EXPECTED_VFS,
-                              fpg=constants.EXPECTED_FPG),
-        ]
-        self.mock_client.assert_has_calls(expected_calls)
-
-    def test_remove_fsip_exception(self):
-        self.init_mediator()
-
-        class FakeException(Exception):
-            pass
-
-        self.mock_client.removefsip.side_effect = FakeException()
-
-        self.assertRaises(exception.ShareBackendException,
-                          self.mediator.remove_fsip,
-                          constants.EXPECTED_IP_1234,
-                          constants.EXPECTED_FPG,
-                          constants.EXPECTED_VFS)
-
-        self.mock_client.removefsip.assert_called_once_with(
-            constants.EXPECTED_VFS,
-            constants.EXPECTED_IP_1234,
-            fpg=constants.EXPECTED_FPG)
-
-
-class OptionMatcher(object):
-    """Options string order can vary. Compare as lists."""
-
-    def __init__(self, assert_func, expected_string):
-        self.assert_func = assert_func
-        self.expected = expected_string.split(',')
-
-    def __eq__(self, actual_string):
-        actual = actual_string.split(',')
-        self.assert_func(sorted(self.expected), sorted(actual))
-        return True
