@@ -23,10 +23,8 @@ SHARE_ADDRESS_2 = '10.10.10.20'
 CLIENT_ADDRESS_1 = '20.20.20.10'
 CLIENT_ADDRESS_2 = '20.20.20.20'
 
-CIFS_SHARE_PATH = '/%s' % SHARE_NAME
-CIFS_SHARE_PATH_PARSED = '\\%s' % SHARE_NAME
 CIFS_SHARE = {
-    'export_location': r'\\%s%s' % (SHARE_ADDRESS_1, CIFS_SHARE_PATH_PARSED),
+    'export_location': r'\\%s\%s' % (SHARE_ADDRESS_1, SHARE_NAME),
     'id': SHARE_ID
 }
 
@@ -47,30 +45,3 @@ USER_ACCESS = {
     'access_to': 'fake_user',
     'access_level': constants.ACCESS_LEVEL_RW,
 }
-
-VOLUME = {
-    'name': SHARE_NAME,
-}
-
-NEW_NFS_RULES = {
-    '10.10.10.0/30': constants.ACCESS_LEVEL_RW,
-    '10.10.10.0/24': constants.ACCESS_LEVEL_RO,
-    '10.10.10.10': constants.ACCESS_LEVEL_RW,
-    '10.10.20.0/24': constants.ACCESS_LEVEL_RW,
-    '10.10.20.10': constants.ACCESS_LEVEL_RW,
-}
-
-EXISTING_CIFS_RULES = {
-    'user1': constants.ACCESS_LEVEL_RW,
-    'user2': constants.ACCESS_LEVEL_RO,
-    'user3': constants.ACCESS_LEVEL_RW,
-    'user4': constants.ACCESS_LEVEL_RO,
-}
-
-NEW_CIFS_RULES = {
-    'user1': constants.ACCESS_LEVEL_RW,
-    'user2': constants.ACCESS_LEVEL_RW,
-    'user3': constants.ACCESS_LEVEL_RO,
-    'user5': constants.ACCESS_LEVEL_RW,
-    'user6': constants.ACCESS_LEVEL_RO,
-}
