@@ -12,7 +12,8 @@
 #    License for the specific language governing permissions and limitations
 #    under the License.
 
-from unittest import mock
+import mock
+import six
 
 from manila import exception
 from manila.share.drivers.netapp import common as na_common
@@ -24,6 +25,9 @@ from manila.tests.share.drivers.netapp import fakes as na_fakes
 
 class NetAppDriverFactoryTestCase(test.TestCase):
 
+    def setUp(self):
+        super(NetAppDriverFactoryTestCase, self).setUp()
+
     def test_new(self):
 
         self.mock_object(na_utils.OpenStackInfo, 'info',
@@ -110,21 +114,18 @@ class NetAppDriverFactoryTestCase(test.TestCase):
             return obj.__module__ + '.' + obj.__class__.__name__
 
         registry = na_common.NETAPP_UNIFIED_DRIVER_REGISTRY
+        mock_db = mock.Mock()
 
-        for family in iter(registry.keys()):
-            for mode, full_class_name in registry[family].items():
+        for family in six.iterkeys(registry):
+            for mode, full_class_name in six.iteritems(registry[family]):
 
                 config = na_fakes.create_configuration()
                 config.local_conf.set_override('driver_handles_share_servers',
                                                mode == na_common.MULTI_SVM)
-                kwargs = {
-                    'configuration': config,
-                    'private_storage': mock.Mock(),
-                    'app_version': 'fake_info'
-                }
+                kwargs = {'configuration': config, 'app_version': 'fake_info'}
 
                 driver = na_common.NetAppDriver._create_driver(
-                    family, mode, **kwargs)
+                    family, mode, mock_db, **kwargs)
 
                 self.assertEqual(full_class_name, get_full_class_name(driver))
 
@@ -133,14 +134,12 @@ class NetAppDriverFactoryTestCase(test.TestCase):
         config = na_fakes.create_configuration()
         config.local_conf.set_override('driver_handles_share_servers', True)
 
-        kwargs = {
-            'configuration': config,
-            'private_storage': mock.Mock(),
-            'app_version': 'fake_info'
-        }
+        kwargs = {'configuration': config, 'app_version': 'fake_info'}
+        mock_db = mock.Mock()
 
         driver = na_common.NetAppDriver._create_driver('ONTAP_CLUSTER',
                                                        na_common.MULTI_SVM,
+                                                       mock_db,
                                                        **kwargs)
 
         self.assertIsInstance(driver,
@@ -152,11 +151,12 @@ class NetAppDriverFactoryTestCase(test.TestCase):
             'configuration': na_fakes.create_configuration(),
             'app_version': 'fake_info',
         }
+        mock_db = mock.Mock()
 
         self.assertRaises(exception.InvalidInput,
                           na_common.NetAppDriver._create_driver,
                           'fake_family', na_common.MULTI_SVM,
-                          **kwargs)
+                          mock_db, **kwargs)
 
     def test_create_driver_invalid_mode(self):
 
@@ -164,7 +164,8 @@ class NetAppDriverFactoryTestCase(test.TestCase):
             'configuration': na_fakes.create_configuration(),
             'app_version': 'fake_info',
         }
+        mock_db = mock.Mock()
 
         self.assertRaises(exception.InvalidInput,
                           na_common.NetAppDriver._create_driver,
-                          'ontap_cluster', 'fake_mode', **kwargs)
+                          'ontap_cluster', 'fake_mode', mock_db, **kwargs)
