@@ -28,23 +28,26 @@ CONF.register_opt(cfg.StrOpt('conf_unittest',
 
 class ConfigTestCase(test.TestCase):
 
+    def setUp(self):
+        super(ConfigTestCase, self).setUp()
+
     def test_declare(self):
         self.assertNotIn('answer', CONF)
         CONF.import_opt('answer', 'manila.tests.declare_conf')
         self.assertIn('answer', CONF)
-        self.assertEqual(42, CONF.answer)
+        self.assertEqual(CONF.answer, 42)
 
         # Make sure we don't overwrite anything
         CONF.set_override('answer', 256)
-        self.assertEqual(256, CONF.answer)
+        self.assertEqual(CONF.answer, 256)
         CONF.import_opt('answer', 'manila.tests.declare_conf')
-        self.assertEqual(256, CONF.answer)
+        self.assertEqual(CONF.answer, 256)
 
     def test_runtime_and_unknown_flags(self):
         self.assertNotIn('runtime_answer', CONF)
         import manila.tests.runtime_conf  # noqa
         self.assertIn('runtime_answer', CONF)
-        self.assertEqual(54, CONF.runtime_answer)
+        self.assertEqual(CONF.runtime_answer, 54)
 
     def test_long_vs_short_flags(self):
         CONF.clear()
@@ -57,22 +60,22 @@ class ConfigTestCase(test.TestCase):
 
         argv = ['--duplicate_answer=60']
         CONF(argv, default_config_files=[])
-        self.assertEqual(60, CONF.duplicate_answer)
-        self.assertEqual('val', CONF.duplicate_answer_long)
+        self.assertEqual(CONF.duplicate_answer, 60)
+        self.assertEqual(CONF.duplicate_answer_long, 'val')
 
     def test_flag_leak_left(self):
-        self.assertEqual('foo', CONF.conf_unittest)
+        self.assertEqual(CONF.conf_unittest, 'foo')
         self.flags(conf_unittest='bar')
-        self.assertEqual('bar', CONF.conf_unittest)
+        self.assertEqual(CONF.conf_unittest, 'bar')
 
     def test_flag_leak_right(self):
-        self.assertEqual('foo', CONF.conf_unittest)
+        self.assertEqual(CONF.conf_unittest, 'foo')
         self.flags(conf_unittest='bar')
-        self.assertEqual('bar', CONF.conf_unittest)
+        self.assertEqual(CONF.conf_unittest, 'bar')
 
     def test_flag_overrides(self):
-        self.assertEqual('foo', CONF.conf_unittest)
+        self.assertEqual(CONF.conf_unittest, 'foo')
         self.flags(conf_unittest='bar')
-        self.assertEqual('bar', CONF.conf_unittest)
+        self.assertEqual(CONF.conf_unittest, 'bar')
         CONF.reset()
-        self.assertEqual('foo', CONF.conf_unittest)
+        self.assertEqual(CONF.conf_unittest, 'foo')
