@@ -20,42 +20,34 @@ class ContextTestCase(test.TestCase):
 
     def test_request_context_elevated(self):
         user_context = context.RequestContext(
-            'fake_user', 'fake_project', is_admin=False)
+            'fake_user', 'fake_project', admin=False)
         self.assertFalse(user_context.is_admin)
-        self.assertEqual([], user_context.roles)
         admin_context = user_context.elevated()
         self.assertFalse(user_context.is_admin)
         self.assertTrue(admin_context.is_admin)
-        self.assertNotIn('admin', user_context.roles)
-        self.assertIn('admin', admin_context.roles)
+        self.assertFalse('admin' in user_context.roles)
+        self.assertTrue('admin' in admin_context.roles)
 
     def test_request_context_sets_is_admin(self):
         ctxt = context.RequestContext('111',
                                       '222',
                                       roles=['admin', 'weasel'])
-        self.assertTrue(ctxt.is_admin)
-
-    def test_request_context_sets_is_service(self):
-        ctxt = context.RequestContext('111',
-                                      '222',
-                                      roles=['service', 'admin'],
-                                      service_roles=['service'])
-        self.assertTrue(ctxt.is_service)
+        self.assertEqual(ctxt.is_admin, True)
 
     def test_request_context_sets_is_admin_upcase(self):
         ctxt = context.RequestContext('111',
                                       '222',
                                       roles=['Admin', 'weasel'])
-        self.assertTrue(ctxt.is_admin)
+        self.assertEqual(ctxt.is_admin, True)
 
     def test_request_context_read_deleted(self):
         ctxt = context.RequestContext('111',
                                       '222',
                                       read_deleted='yes')
-        self.assertEqual('yes', ctxt.read_deleted)
+        self.assertEqual(ctxt.read_deleted, 'yes')
 
         ctxt.read_deleted = 'no'
-        self.assertEqual('no', ctxt.read_deleted)
+        self.assertEqual(ctxt.read_deleted, 'no')
 
     def test_request_context_read_deleted_invalid(self):
         self.assertRaises(ValueError,
@@ -70,3 +62,19 @@ class ContextTestCase(test.TestCase):
                           ctxt,
                           'read_deleted',
                           True)
+
+    def test_extra_args_to_context_get_logged(self):
+        info = {}
+
+        def fake_warn(log_msg, other_args):
+            info['log_msg'] = log_msg % other_args
+
+        self.mock_object(context.LOG, 'warn', fake_warn)
+
+        c = context.RequestContext('user',
+                                   'project',
+                                   extra_arg1='meow',
+                                   extra_arg2='wuff')
+        self.assertTrue(c)
+        self.assertIn("'extra_arg1': 'meow'", info['log_msg'])
+        self.assertIn("'extra_arg2': 'wuff'", info['log_msg'])
