@@ -18,76 +18,103 @@ Handles all requests relating to volumes + cinder.
 """
 
 import copy
+import sys
 
 from cinderclient import exceptions as cinder_exception
-from cinderclient.v3 import client as cinder_client
-from keystoneauth1 import loading as ks_loading
+from cinderclient import service_catalog
+from cinderclient.v2 import client as cinder_client
 from oslo_config import cfg
-import six
+from oslo_log import log
 
-from manila.common import client_auth
-from manila.common.config import core_opts
 import manila.context as ctxt
 from manila.db import base
 from manila import exception
 from manila.i18n import _
 
-CINDER_GROUP = 'cinder'
-AUTH_OBJ = None
 
 cinder_opts = [
-    cfg.BoolOpt('cross_az_attach',
+    cfg.StrOpt('cinder_catalog_info',
+               default='volume:cinder:publicURL',
+               help='Info to match when looking for cinder in the service '
+                    'catalog. Format is separated values of the form: '
+                    '<service_type>:<service_name>:<endpoint_type>'),
+    cfg.StrOpt('os_region_name',
+               help='Region name of this node.'),
+    cfg.StrOpt('cinder_ca_certificates_file',
+               help='Location of CA certificates file to use for cinder '
+                    'client requests.'),
+    cfg.IntOpt('cinder_http_retries',
+               default=3,
+               help='Number of cinderclient retries on failed HTTP calls.'),
+    cfg.BoolOpt('cinder_api_insecure',
+                default=False,
+                help='Allow to perform insecure SSL requests to cinder.'),
+    cfg.BoolOpt('cinder_cross_az_attach',
                 default=True,
-                deprecated_group="DEFAULT",
-                deprecated_name="cinder_cross_az_attach",
                 help='Allow attaching between instances and volumes in '
                      'different availability zones.'),
-    cfg.StrOpt('ca_certificates_file',
-               help='Location of CA certificates file to use for cinder '
-                    'client requests.',
-               deprecated_group='DEFAULT',
-               deprecated_name="cinder_ca_certificates_file"),
-    cfg.IntOpt('http_retries',
-               default=3,
-               help='Number of cinderclient retries on failed HTTP calls.',
-               deprecated_group='DEFAULT',
-               deprecated_name="cinder_http_retries"),
-    cfg.BoolOpt('api_insecure',
-                default=False,
-                help='Allow to perform insecure SSL requests to cinder.',
-                deprecated_group='DEFAULT',
-                deprecated_name="cinder_api_insecure"),
-    cfg.StrOpt('endpoint_type',
-               default='publicURL',
-               help='Endpoint type to be used with cinder client calls.'),
-    cfg.StrOpt('region_name',
-               help='Region name for connecting to cinder.'),
-    ]
+    cfg.StrOpt('cinder_admin_username',
+               default='cinder',
+               help='Cinder admin username.'),
+    cfg.StrOpt('cinder_admin_password',
+               help='Cinder admin password.'),
+    cfg.StrOpt('cinder_admin_tenant_name',
+               default='service',
+               help='Cinder admin tenant name.'),
+    cfg.StrOpt('cinder_admin_auth_url',
+               default='http://localhost:5000/v2.0',
+               help='Identity service URL.')
+]
 
 CONF = cfg.CONF
-CONF.register_opts(core_opts)
-CONF.register_opts(cinder_opts, CINDER_GROUP)
-ks_loading.register_session_conf_options(CONF, CINDER_GROUP)
-ks_loading.register_auth_conf_options(CONF, CINDER_GROUP)
+CONF.register_opts(cinder_opts)
 
-
-def list_opts():
-    return client_auth.AuthClientLoader.list_opts(CINDER_GROUP)
+LOG = log.getLogger(__name__)
 
 
 def cinderclient(context):
-    global AUTH_OBJ
-    if not AUTH_OBJ:
-        AUTH_OBJ = client_auth.AuthClientLoader(
-            client_class=cinder_client.Client,
-            exception_module=cinder_exception,
-            cfg_group=CINDER_GROUP)
-    return AUTH_OBJ.get_client(context,
-                               insecure=CONF[CINDER_GROUP].api_insecure,
-                               cacert=CONF[CINDER_GROUP].ca_certificates_file,
-                               retries=CONF[CINDER_GROUP].http_retries,
-                               endpoint_type=CONF[CINDER_GROUP].endpoint_type,
-                               region_name=CONF[CINDER_GROUP].region_name)
+    if context.is_admin and context.project_id is None:
+        c = cinder_client.Client(CONF.cinder_admin_username,
+                                 CONF.cinder_admin_password,
+                                 CONF.cinder_admin_tenant_name,
+                                 CONF.cinder_admin_auth_url,
+                                 retries=CONF.cinder_http_retries,)
+        c.authenticate()
+        return c
+
+    compat_catalog = {
+        'access': {'serviceCatalog': context.service_catalog or []}
+    }
+    sc = service_catalog.ServiceCatalog(compat_catalog)
+    info = CONF.cinder_catalog_info
+    service_type, service_name, endpoint_type = info.split(':')
+    # extract the region if set in configuration
+    if CONF.os_region_name:
+        attr = 'region'
+        filter_value = CONF.os_region_name
+    else:
+        attr = None
+        filter_value = None
+    url = sc.url_for(attr=attr,
+                     filter_value=filter_value,
+                     service_type=service_type,
+                     service_name=service_name,
+                     endpoint_type=endpoint_type)
+
+    LOG.debug('Cinderclient connection created using URL: %s', url)
+
+    c = cinder_client.Client(context.user_id,
+                             context.auth_token,
+                             project_id=context.project_id,
+                             auth_url=url,
+                             insecure=CONF.cinder_api_insecure,
+                             retries=CONF.cinder_http_retries,
+                             cacert=CONF.cinder_ca_certificates_file)
+    # noauth extracts user_id:project_id from auth_token
+    c.client.auth_token = context.auth_token or '%s:%s' % (context.user_id,
+                                                           context.project_id)
+    c.client.management_url = url
+    return c
 
 
 def _untranslate_volume_summary_view(context, vol):
@@ -149,11 +176,13 @@ def translate_volume_exception(method):
     def wrapper(self, ctx, volume_id, *args, **kwargs):
         try:
             res = method(self, ctx, volume_id, *args, **kwargs)
-        except cinder_exception.ClientException as e:
-            if isinstance(e, cinder_exception.NotFound):
-                raise exception.VolumeNotFound(volume_id=volume_id)
-            elif isinstance(e, cinder_exception.BadRequest):
-                raise exception.InvalidInput(reason=six.text_type(e))
+        except cinder_exception.ClientException:
+            exc_type, exc_value, exc_trace = sys.exc_info()
+            if isinstance(exc_value, cinder_exception.NotFound):
+                exc_value = exception.VolumeNotFound(volume_id=volume_id)
+            elif isinstance(exc_value, cinder_exception.BadRequest):
+                exc_value = exception.InvalidInput(reason=exc_value.message)
+            raise exc_value, None, exc_trace
         return res
     return wrapper
 
@@ -166,9 +195,12 @@ def translate_snapshot_exception(method):
     def wrapper(self, ctx, snapshot_id, *args, **kwargs):
         try:
             res = method(self, ctx, snapshot_id, *args, **kwargs)
-        except cinder_exception.ClientException as e:
-            if isinstance(e, cinder_exception.NotFound):
-                raise exception.VolumeSnapshotNotFound(snapshot_id=snapshot_id)
+        except cinder_exception.ClientException:
+            exc_type, exc_value, exc_trace = sys.exc_info()
+            if isinstance(exc_value, cinder_exception.NotFound):
+                exc_value = (
+                    exception.VolumeSnapshotNotFound(snapshot_id=snapshot_id))
+            raise exc_value, None, exc_trace
         return res
     return wrapper
 
@@ -203,7 +235,7 @@ class API(base.Base):
         if volume['attach_status'] == "attached":
             msg = _("already attached")
             raise exception.InvalidVolume(reason=msg)
-        if instance and not CONF[CINDER_GROUP].cross_az_attach:
+        if instance and not CONF.cinder_cross_az_attach:
             if instance['availability_zone'] != volume['availability_zone']:
                 msg = _("Instance and volume not in same availability_zone")
                 raise exception.InvalidVolume(reason=msg)
@@ -271,18 +303,14 @@ class API(base.Base):
             item = cinderclient(context).volumes.create(size, **kwargs)
             return _untranslate_volume_summary_view(context, item)
         except cinder_exception.BadRequest as e:
-            raise exception.InvalidInput(reason=six.text_type(e))
+            raise exception.InvalidInput(reason=e.message)
         except cinder_exception.NotFound:
             raise exception.NotFound(
                 _("Error in creating cinder "
                   "volume. Cinder volume type %s not exist. Check parameter "
                   "cinder_volume_type in configuration file.") % volume_type)
         except Exception as e:
-            raise exception.ManilaException(e)
-
-    @translate_volume_exception
-    def extend(self, context, volume_id, new_size):
-        cinderclient(context).volumes.extend(volume_id, new_size)
+            raise exception.ManilaException(e.message)
 
     @translate_volume_exception
     def delete(self, context, volume_id):
