@@ -19,12 +19,11 @@
 
 from __future__ import print_function
 
+import cStringIO as StringIO
 import json
 import re
 import sys
 
-import six
-
 from pylint import lint
 from pylint.reporters import text
 
@@ -61,8 +60,6 @@ class LintOutput(object):
     @classmethod
     def from_line(cls, line):
         m = re.search(r"(\S+):(\d+): \[(\S+)(, \S+)?] (.*)", line)
-        if m is None:
-            return None
         matched = m.groups()
         filename, lineno, code, message = (matched[0], int(matched[1]),
                                            matched[2], matched[-1])
@@ -84,7 +81,7 @@ class LintOutput(object):
         result = {}
         for line in msg.splitlines():
             obj = cls.from_line(line)
-            if obj is None or obj.is_ignored():
+            if obj.is_ignored():
                 continue
             key = obj.key()
             if key not in result:
@@ -113,11 +110,8 @@ class LintOutput(object):
         return json.dumps(self.__dict__)
 
     def review_str(self):
-        return ("File %(filename)s\nLine %(lineno)d:"
-                "%(line_content)s\n%(code)s: %(message)s" %
-                {'filename': self.filename, 'lineno': self.lineno,
-                 'line_content': self.line_content, 'code': self.code,
-                 'message': self.message})
+        return ("File %(filename)s\nLine %(lineno)d:%(line_content)s\n"
+                "%(code)s: %(message)s" % self.__dict__)
 
 
 class ErrorKeys(object):
@@ -139,11 +133,9 @@ class ErrorKeys(object):
 
 
 def run_pylint():
-    buff = six.StringIO()
-    reporter = text.TextReporter(output=buff)
-    args = [
-        "--msg-template='{path}:{line}: [{msg_id}i({symbol}), {obj}] {msg}'",
-        "-E", "manila"]
+    buff = StringIO.StringIO()
+    reporter = text.ParseableTextReporter(output=buff)
+    args = ["--include-ids=y", "-E", "manila"]
     lint.Run(args, reporter=reporter, exit=False)
     val = buff.getvalue()
     buff.close()
